# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: multi_photography_options.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from video_pb2 import *

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x1fmulti_photography_options.proto\x12\x11insta360.messages\x1a\x0bvideo.proto"\x9e\x05\n\x17MultiPhotographyOptions\x12<\n\x10recordResolution\x18\x01 \x01(\x0e\x32".insta360.messages.VideoResolution\x12\x1f\n\x17\x65nableInternalFlowstate\x18\x02 \x01(\x08\x12P\n\x0e\x64imentsionType\x18\x03 \x01(\x0e\x32\x38.insta360.messages.MultiPhotographyOptions.DimensionType\x12I\n\nvisionType\x18\x04 \x01(\x0e\x32\x35.insta360.messages.MultiPhotographyOptions.VisionType"K\n\rDimensionType\x12\x1d\n\x19\x44IMENSION_TYPE_HORIZONTAL\x10\x00\x12\x1b\n\x17\x44IMENSION_TYPE_VERTICAL\x10\x01"\xb9\x02\n\nVisionType\x12\x14\n\x10VISION_TYPE_WIDE\x10\x00\x12\x16\n\x12VISION_TYPE_LINEAR\x10\x01\x12\x19\n\x15VISION_TYPE_ULTRAWIDE\x10\x02\x12\x16\n\x12VISION_TYPE_NARROW\x10\x03\x12\x13\n\x0fVISION_TYPE_POV\x10\x04\x12\x1b\n\x17VISION_TYPE_LINEAR_PLUS\x10\x05\x12\x1e\n\x1aVISION_TYPE_LINEAR_HORIZON\x10\x06\x12\x18\n\x14VISION_TYPE_TYPE_FPV\x10\x07\x12\x1a\n\x16VISION_TYPE_TYPE_SUPER\x10\x08\x12\x1f\n\x1bVISION_TYPE_TYPE_TINYPLANET\x10\t\x12!\n\x1dVISION_TYPE_TYPE_INFINITYWIDE\x10\n*\xc4\x01\n\x1bMultiPhotographyOptionsType\x12$\n MULTI_PHOTOGRAPHY_OPTION_UNKNOWN\x10\x00\x12\x0e\n\nRESOLUTION\x10\x01\x12"\n\x1ePHOTOGRAPHY_INTERNAL_FLOWSTATE\x10\x02\x12\x12\n\x0e\x44IMENSION_TYPE\x10\x03\x12\x0f\n\x0bVISION_TYPE\x10\x04\x12&\n"MULTI_PHOTOGRAPHY_OPTIONS_TYPE_NUM\x10\x05\x42\x08\xa2\x02\x05INSPBP\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(
    DESCRIPTOR, "multi_photography_options_pb2", _globals
)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"\242\002\005INSPB"
    _globals["_MULTIPHOTOGRAPHYOPTIONSTYPE"]._serialized_start = 741
    _globals["_MULTIPHOTOGRAPHYOPTIONSTYPE"]._serialized_end = 937
    _globals["_MULTIPHOTOGRAPHYOPTIONS"]._serialized_start = 68
    _globals["_MULTIPHOTOGRAPHYOPTIONS"]._serialized_end = 738
    _globals["_MULTIPHOTOGRAPHYOPTIONS_DIMENSIONTYPE"]._serialized_start = 347
    _globals["_MULTIPHOTOGRAPHYOPTIONS_DIMENSIONTYPE"]._serialized_end = 422
    _globals["_MULTIPHOTOGRAPHYOPTIONS_VISIONTYPE"]._serialized_start = 425
    _globals["_MULTIPHOTOGRAPHYOPTIONS_VISIONTYPE"]._serialized_end = 738
# @@protoc_insertion_point(module_scope)
