# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: support_take_photo_on_rec.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x1fsupport_take_photo_on_rec.proto\x12\x11insta360.messages"\xaa\x01\n!NotificationSupportTakePhotoInREC\x12U\n\x06status\x18\x01 \x01(\x0e\x32\x45.insta360.messages.NotificationSupportTakePhotoInREC.SupportTakephoto".\n\x10SupportTakephoto\x12\r\n\tNosupport\x10\x00\x12\x0b\n\x07Support\x10\x01\x42\x08\xa2\x02\x05INSPBb\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(
    DESCRIPTOR, "support_take_photo_on_rec_pb2", _globals
)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"\242\002\005INSPB"
    _globals["_NOTIFICATIONSUPPORTTAKEPHOTOINREC"]._serialized_start = 55
    _globals["_NOTIFICATIONSUPPORTTAKEPHOTOINREC"]._serialized_end = 225
    _globals[
        "_NOTIFICATIONSUPPORTTAKEPHOTOINREC_SUPPORTTAKEPHOTO"
    ]._serialized_start = 179
    _globals[
        "_NOTIFICATIONSUPPORTTAKEPHOTOINREC_SUPPORTTAKEPHOTO"
    ]._serialized_end = 225
# @@protoc_insertion_point(module_scope)
