# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: get_current_capture_status.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from capture_state_pb2 import *
from capture_trigger_source_pb2 import *
from interval_rec_info_pb2 import *

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n get_current_capture_status.proto\x12\x11insta360.messages\x1a\x13\x63\x61pture_state.proto\x1a\x1c\x63\x61pture_trigger_source.proto\x1a\x17interval_rec_info.proto"\xce\x03\n\x13\x43\x61meraCaptureStatus\x12\x34\n\x05state\x18\x01 \x01(\x0e\x32%.insta360.messages.CameraCaptureState\x12\x14\n\x0c\x63\x61pture_time\x18\x02 \x01(\r\x12\x14\n\x0c\x63\x61pture_nums\x18\x03 \x01(\r\x12\x1a\n\x12keyTimePointDetail\x18\x04 \x01(\t\x12\x45\n\x0etrigger_source\x18\x05 \x01(\x0e\x32-.insta360.messages.CameraCaptureTriggerSource\x12\x15\n\rinterval_time\x18\x06 \x01(\r\x12\x15\n\rexposure_mode\x18\x07 \x01(\r\x12\x17\n\x0fmax_record_time\x18\x08 \x01(\x05\x12\x18\n\x10max_pre_rec_time\x18\t \x01(\r\x12\x41\n\x0f\x63\x61pture_submode\x18\n \x01(\x0e\x32(.insta360.messages.CameraCaptureSubState\x12<\n\x10interval_recInfo\x18\x0b \x01(\x0b\x32".insta360.messages.IntervalRecInfo\x12\x10\n\x08\x64uration\x18\x0c \x01(\r"U\n\x1bGetCurrentCaptureStatusResp\x12\x36\n\x06status\x18\x01 \x01(\x0b\x32&.insta360.messages.CameraCaptureStatusB\x08\xa2\x02\x05INSPBP\x00P\x01P\x02\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(
    DESCRIPTOR, "get_current_capture_status_pb2", _globals
)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"\242\002\005INSPB"
    _globals["_CAMERACAPTURESTATUS"]._serialized_start = 132
    _globals["_CAMERACAPTURESTATUS"]._serialized_end = 594
    _globals["_GETCURRENTCAPTURESTATUSRESP"]._serialized_start = 596
    _globals["_GETCURRENTCAPTURESTATUSRESP"]._serialized_end = 681
# @@protoc_insertion_point(module_scope)
