# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: start_capture.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from options_pb2 import *

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x13start_capture.proto\x12\x11insta360.messages\x1a\roptions.proto"<\n\x0cStartCapture\x12,\n\x04mode\x18\x01 \x01(\x0e\x32\x1e.insta360.messages.CaptureMode"\x12\n\x10StartCaptureRespB\x08\xa2\x02\x05INSPBP\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "start_capture_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"\242\002\005INSPB"
    _globals["_STARTCAPTURE"]._serialized_start = 57
    _globals["_STARTCAPTURE"]._serialized_end = 117
    _globals["_STARTCAPTURERESP"]._serialized_start = 119
    _globals["_STARTCAPTURERESP"]._serialized_end = 137
# @@protoc_insertion_point(module_scope)
