# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: get_file_list.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from media_pb2 import *

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x13get_file_list.proto\x12\x11insta360.messages\x1a\x0bmedia.proto"]\n\x0bGetFileList\x12\x30\n\nmedia_type\x18\x01 \x01(\x0e\x32\x1c.insta360.messages.MediaType\x12\r\n\x05start\x18\x02 \x01(\r\x12\r\n\x05limit\x18\x03 \x01(\r"3\n\x0fGetFileListResp\x12\x0b\n\x03uri\x18\x01 \x03(\t\x12\x13\n\x0btotal_count\x18\x02 \x01(\rB\x08\xa2\x02\x05INSPBP\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "get_file_list_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"\242\002\005INSPB"
    _globals["_GETFILELIST"]._serialized_start = 55
    _globals["_GETFILELIST"]._serialized_end = 148
    _globals["_GETFILELISTRESP"]._serialized_start = 150
    _globals["_GETFILELISTRESP"]._serialized_end = 201
# @@protoc_insertion_point(module_scope)
