# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: camera_wifi_connection_result.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from wifi_connection_info_pb2 import *

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n#camera_wifi_connection_result.proto\x12\x11insta360.messages\x1a\x1awifi_connection_info.proto"\x91\x02\n\x1a\x43\x61meraWifiConnectionResult\x12\x62\n\x16wifi_connection_result\x18\x01 \x01(\x0e\x32\x42.insta360.messages.CameraWifiConnectionResult.WifiConnectionResult\x12\x43\n\x14wifi_connection_info\x18\x02 \x01(\x0b\x32%.insta360.messages.WifiConnectionInfo"J\n\x14WifiConnectionResult\x12\x0b\n\x07SUCCESS\x10\x00\x12\x0b\n\x07TIMEOUT\x10\x01\x12\x18\n\x14\x45RROR_CONNECT_FAILED\x10\x02\x42\x08\xa2\x02\x05INSPBP\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(
    DESCRIPTOR, "camera_wifi_connection_result_pb2", _globals
)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"\242\002\005INSPB"
    _globals["_CAMERAWIFICONNECTIONRESULT"]._serialized_start = 87
    _globals["_CAMERAWIFICONNECTIONRESULT"]._serialized_end = 360
    _globals["_CAMERAWIFICONNECTIONRESULT_WIFICONNECTIONRESULT"]._serialized_start = 286
    _globals["_CAMERAWIFICONNECTIONRESULT_WIFICONNECTIONRESULT"]._serialized_end = 360
# @@protoc_insertion_point(module_scope)
