# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: take_picture.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from photo_pb2 import *
from media_pb2 import *
from sensor_pb2 import *
from extra_info_pb2 import *

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x12take_picture.proto\x12\x11insta360.messages\x1a\x0bphoto.proto\x1a\x0bmedia.proto\x1a\x0csensor.proto\x1a\x10\x65xtra_info.proto"\xe8\x02\n\x0bTakePicture\x12\x31\n\x04mode\x18\x01 \x01(\x0e\x32#.insta360.messages.TakePicture.Mode\x12\x38\n\x0e\x65xtra_metadata\x18\x02 \x01(\x0b\x32 .insta360.messages.ExtraMetadata\x12\x13\n\x0b\x61\x65\x62_ev_bias\x18\x03 \x03(\x11\x12;\n\x10raw_capture_type\x18\x04 \x01(\x0e\x32!.insta360.messages.RawCaptureType\x12\x1a\n\x12isInstaPanoEnabled\x18\x05 \x01(\x08\x12\x34\n\x0b\x66ocusSensor\x18\x06 \x01(\x0e\x32\x1f.insta360.messages.SensorDevice\x12\x11\n\tselfTimer\x18\x07 \x01(\r"5\n\x04Mode\x12\n\n\x06NORMAL\x10\x00\x12\x07\n\x03\x41\x45\x42\x10\x01\x12\t\n\x05\x42URST\x10\x03\x12\r\n\tAEB_NIGHT\x10\x04"\x9c\x01\n\x13TakePictureResponse\x12\'\n\x05image\x18\x01 \x01(\x0b\x32\x18.insta360.messages.Photo\x12,\n\naeb_images\x18\x02 \x03(\x0b\x32\x18.insta360.messages.Photo\x12.\n\x0c\x62urst_images\x18\x03 \x03(\x0b\x32\x18.insta360.messages.PhotoB\x08\xa2\x02\x05INSPBP\x00P\x01P\x02P\x03\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "take_picture_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"\242\002\005INSPB"
    _globals["_TAKEPICTURE"]._serialized_start = 100
    _globals["_TAKEPICTURE"]._serialized_end = 460
    _globals["_TAKEPICTURE_MODE"]._serialized_start = 407
    _globals["_TAKEPICTURE_MODE"]._serialized_end = 460
    _globals["_TAKEPICTURERESPONSE"]._serialized_start = 463
    _globals["_TAKEPICTURERESPONSE"]._serialized_end = 619
# @@protoc_insertion_point(module_scope)
