# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: take_picture_state_update.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x1ftake_picture_state_update.proto\x12\x11insta360.messages"\xba\x01\n"NotificationTakePictureStateUpdate\x12U\n\x05state\x18\x01 \x01(\x0e\x32\x46.insta360.messages.NotificationTakePictureStateUpdate.TakePictureState"=\n\x10TakePictureState\x12\x0b\n\x07SHUTTER\x10\x00\x12\x0c\n\x08\x43OMPRESS\x10\x01\x12\x0e\n\nWRITE_FILE\x10\x02\x42\x08\xa2\x02\x05INSPBb\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(
    DESCRIPTOR, "take_picture_state_update_pb2", _globals
)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"\242\002\005INSPB"
    _globals["_NOTIFICATIONTAKEPICTURESTATEUPDATE"]._serialized_start = 55
    _globals["_NOTIFICATIONTAKEPICTURESTATEUPDATE"]._serialized_end = 241
    _globals[
        "_NOTIFICATIONTAKEPICTURESTATEUPDATE_TAKEPICTURESTATE"
    ]._serialized_start = 180
    _globals[
        "_NOTIFICATIONTAKEPICTURESTATEUPDATE_TAKEPICTURESTATE"
    ]._serialized_end = 241
# @@protoc_insertion_point(module_scope)
