# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: key_pressed.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x11key_pressed.proto\x12\x11insta360.messages"\xa0\x01\n\x16NotificatoinKeyPressed\x12?\n\x06key_id\x18\x01 \x01(\x0e\x32/.insta360.messages.NotificatoinKeyPressed.KeyId"E\n\x05KeyId\x12\x12\n\x0e\x46\x30_SHORT_PRESS\x10\x00\x12\x13\n\x0f\x46\x30_DOUBLE_PRESS\x10\x01\x12\x13\n\x0f\x46\x30_TRIPLE_PRESS\x10\x02\x42\x08\xa2\x02\x05INSPBb\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "key_pressed_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"\242\002\005INSPB"
    _globals["_NOTIFICATOINKEYPRESSED"]._serialized_start = 41
    _globals["_NOTIFICATOINKEYPRESSED"]._serialized_end = 201
    _globals["_NOTIFICATOINKEYPRESSED_KEYID"]._serialized_start = 132
    _globals["_NOTIFICATOINKEYPRESSED_KEYID"]._serialized_end = 201
# @@protoc_insertion_point(module_scope)
