# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: check_authorization.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x19\x63heck_authorization.proto\x12\x11insta360.messages" \n\x12\x43heckAuthorization\x12\n\n\x02id\x18\x01 \x01(\t"\xbe\x01\n\x16\x43heckAuthorizationResp\x12[\n\x14\x61uthorization_status\x18\x01 \x01(\x0e\x32=.insta360.messages.CheckAuthorizationResp.AuthorizationStatus"G\n\x13\x41uthorizationStatus\x12\x0e\n\nAUTHORIZED\x10\x00\x12\x10\n\x0cUNAUTHORIZED\x10\x01\x12\x0e\n\nSYSTEMBUSY\x10\x02\x42\x08\xa2\x02\x05INSPBb\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "check_authorization_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"\242\002\005INSPB"
    _globals["_CHECKAUTHORIZATION"]._serialized_start = 48
    _globals["_CHECKAUTHORIZATION"]._serialized_end = 80
    _globals["_CHECKAUTHORIZATIONRESP"]._serialized_start = 83
    _globals["_CHECKAUTHORIZATIONRESP"]._serialized_end = 273
    _globals["_CHECKAUTHORIZATIONRESP_AUTHORIZATIONSTATUS"]._serialized_start = 202
    _globals["_CHECKAUTHORIZATIONRESP_AUTHORIZATIONSTATUS"]._serialized_end = 273
# @@protoc_insertion_point(module_scope)
