# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: usbcard_status.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x14usbcard_status.proto\x12\x11insta360.messages"\xad\x01\n\rUsbCardStatus\x12.\n\x05state\x18\x01 \x01(\x0e\x32\x1f.insta360.messages.UsbCardState\x12\x18\n\x10tf_card_capacity\x18\x02 \x01(\r\x12\x1d\n\x15tf_card_used_capacity\x18\x03 \x01(\r\x12\x1a\n\x12\x62\x61\x63kup_total_files\x18\x04 \x01(\r\x12\x17\n\x0f\x62\x61\x63ked_up_files\x18\x05 \x01(\r*\xc5\x02\n\x0cUsbCardState\x12\x15\n\x11USBCARD_CONNECTED\x10\x00\x12\x18\n\x14USBCARD_DISCONNECTED\x10\x01\x12\x1b\n\x17USBCARD_CONNECTED_PHONE\x10\x02\x12\x16\n\x12USBCARD_NO_TF_CARD\x10\x03\x12\x13\n\x0fUSBCARD_TF_FULL\x10\x04\x12\x12\n\x0eUSBCARD_TF_ERR\x10\x05\x12\x17\n\x13USBCARD_BACKUP_SUCC\x10\x06\x12\x16\n\x12USBCARD_BACKUP_ERR\x10\x07\x12\x15\n\x11USBCARD_OTHER_ERR\x10\x08\x12\x15\n\x11USBCARD_BACKUPING\x10\t\x12\x16\n\x12USBCARD_BACKUP_END\x10\n\x12\x17\n\x13USBCARD_FORMAT_SUCC\x10\x0b\x12\x16\n\x12USBCARD_FORMAT_ERR\x10\x0c\x42\x08\xa2\x02\x05INSPBb\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "usbcard_status_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"\242\002\005INSPB"
    _globals["_USBCARDSTATE"]._serialized_start = 220
    _globals["_USBCARDSTATE"]._serialized_end = 545
    _globals["_USBCARDSTATUS"]._serialized_start = 44
    _globals["_USBCARDSTATUS"]._serialized_end = 217
# @@protoc_insertion_point(module_scope)
