# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: set_cloud_storage_status.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cloud_storage_pb2 import *

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x1eset_cloud_storage_status.proto\x12\x11insta360.messages\x1a\x13\x63loud_storage.proto"a\n\x1bSetCloudStorageUploadStatus\x12\x42\n\rupload_params\x18\x01 \x01(\x0b\x32+.insta360.messages.CloudStorageUploadParams"!\n\x1fSetCloudStorageUploadStatusResp"[\n\x19SetCloudStorageBindStatus\x12>\n\x0b\x62ind_params\x18\x01 \x01(\x0b\x32).insta360.messages.CloudStorageBindParams"\x9c\x01\n\x1dSetCloudStorageBindStatusResp\x12K\n\x06result\x18\x01 \x01(\x0e\x32;.insta360.messages.SetCloudStorageBindStatusResp.BindResult".\n\nBindResult\x12\x10\n\x0c\x42IND_SUCCESS\x10\x00\x12\x0e\n\nBIND_FAILD\x10\x01\x42\x08\xa2\x02\x05INSPBP\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(
    DESCRIPTOR, "set_cloud_storage_status_pb2", _globals
)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"\242\002\005INSPB"
    _globals["_SETCLOUDSTORAGEUPLOADSTATUS"]._serialized_start = 74
    _globals["_SETCLOUDSTORAGEUPLOADSTATUS"]._serialized_end = 171
    _globals["_SETCLOUDSTORAGEUPLOADSTATUSRESP"]._serialized_start = 173
    _globals["_SETCLOUDSTORAGEUPLOADSTATUSRESP"]._serialized_end = 206
    _globals["_SETCLOUDSTORAGEBINDSTATUS"]._serialized_start = 208
    _globals["_SETCLOUDSTORAGEBINDSTATUS"]._serialized_end = 299
    _globals["_SETCLOUDSTORAGEBINDSTATUSRESP"]._serialized_start = 302
    _globals["_SETCLOUDSTORAGEBINDSTATUSRESP"]._serialized_end = 458
    _globals["_SETCLOUDSTORAGEBINDSTATUSRESP_BINDRESULT"]._serialized_start = 412
    _globals["_SETCLOUDSTORAGEBINDSTATUSRESP_BINDRESULT"]._serialized_end = 458
# @@protoc_insertion_point(module_scope)
