# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: set_wifi_seize.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x14set_wifi_seize.proto\x12\x11insta360.messages"\x99\x01\n\x12SetWifiSeizeEnable\x12\x44\n\x05state\x18\x01 \x01(\x0e\x32\x35.insta360.messages.SetWifiSeizeEnable.ConnectionState"=\n\x0f\x43onnectionState\x12\x0b\n\x07unknown\x10\x00\x12\x0f\n\x0bmonopolized\x10\x01\x12\x0c\n\x08seizable\x10\x02"\x18\n\x16SetWifiSeizeEnableRespB\x08\xa2\x02\x05INSPBb\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "set_wifi_seize_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"\242\002\005INSPB"
    _globals["_SETWIFISEIZEENABLE"]._serialized_start = 44
    _globals["_SETWIFISEIZEENABLE"]._serialized_end = 197
    _globals["_SETWIFISEIZEENABLE_CONNECTIONSTATE"]._serialized_start = 136
    _globals["_SETWIFISEIZEENABLE_CONNECTIONSTATE"]._serialized_end = 197
    _globals["_SETWIFISEIZEENABLERESP"]._serialized_start = 199
    _globals["_SETWIFISEIZEENABLERESP"]._serialized_end = 223
# @@protoc_insertion_point(module_scope)
