# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: set_access_camera_file_state.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n"set_access_camera_file_state.proto\x12\x11insta360.messages"\xbf\x01\n\x18SetAccessCameraFileState\x12\x46\n\x05state\x18\x01 \x01(\x0e\x32\x37.insta360.messages.SetAccessCameraFileState.AccessState"[\n\x0b\x41\x63\x63\x65ssState\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x08\n\x04IDLE\x10\x01\x12\n\n\x06\x45XPORT\x10\x02\x12\x0c\n\x08\x44OWNLOAD\x10\x03\x12\x0c\n\x08PLAYBACK\x10\x04\x12\r\n\tLIVE_VIEW\x10\x05"\x1e\n\x1cSetAccessCameraFileStateRespB\x08\xa2\x02\x05INSPBb\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(
    DESCRIPTOR, "set_access_camera_file_state_pb2", _globals
)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"\242\002\005INSPB"
    _globals["_SETACCESSCAMERAFILESTATE"]._serialized_start = 58
    _globals["_SETACCESSCAMERAFILESTATE"]._serialized_end = 249
    _globals["_SETACCESSCAMERAFILESTATE_ACCESSSTATE"]._serialized_start = 158
    _globals["_SETACCESSCAMERAFILESTATE_ACCESSSTATE"]._serialized_end = 249
    _globals["_SETACCESSCAMERAFILESTATERESP"]._serialized_start = 251
    _globals["_SETACCESSCAMERAFILESTATERESP"]._serialized_end = 281
# @@protoc_insertion_point(module_scope)
