# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: get_timelapse_options.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from timelapse_pb2 import *

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x1bget_timelapse_options.proto\x12\x11insta360.messages\x1a\x0ftimelapse.proto"E\n\x13GetTimelapseOptions\x12.\n\x04mode\x18\x01 \x01(\x0e\x32 .insta360.messages.TimelapseMode"Y\n\x17GetTimelapseOptionsResp\x12>\n\x11timelapse_options\x18\x01 \x01(\x0b\x32#.insta360.messages.TimelapseOptionsB\x08\xa2\x02\x05INSPBP\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(
    DESCRIPTOR, "get_timelapse_options_pb2", _globals
)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"\242\002\005INSPB"
    _globals["_GETTIMELAPSEOPTIONS"]._serialized_start = 67
    _globals["_GETTIMELAPSEOPTIONS"]._serialized_end = 136
    _globals["_GETTIMELAPSEOPTIONSRESP"]._serialized_start = 138
    _globals["_GETTIMELAPSEOPTIONSRESP"]._serialized_end = 227
# @@protoc_insertion_point(module_scope)
