# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: get_cloud_storage_status.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cloud_storage_pb2 import *

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x1eget_cloud_storage_status.proto\x12\x11insta360.messages\x1a\x13\x63loud_storage.proto"\x1d\n\x1bGetCloudStorageUploadStatus"e\n\x1fGetCloudStorageUploadStatusResp\x12\x42\n\rupload_params\x18\x01 \x01(\x0b\x32+.insta360.messages.CloudStorageUploadParams"\x1b\n\x19GetCloudStorageBindStatus"_\n\x1dGetCloudStorageBindStatusResp\x12>\n\x0b\x62ind_params\x18\x01 \x01(\x0b\x32).insta360.messages.CloudStorageBindParamsB\x08\xa2\x02\x05INSPBP\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(
    DESCRIPTOR, "get_cloud_storage_status_pb2", _globals
)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"\242\002\005INSPB"
    _globals["_GETCLOUDSTORAGEUPLOADSTATUS"]._serialized_start = 74
    _globals["_GETCLOUDSTORAGEUPLOADSTATUS"]._serialized_end = 103
    _globals["_GETCLOUDSTORAGEUPLOADSTATUSRESP"]._serialized_start = 105
    _globals["_GETCLOUDSTORAGEUPLOADSTATUSRESP"]._serialized_end = 206
    _globals["_GETCLOUDSTORAGEBINDSTATUS"]._serialized_start = 208
    _globals["_GETCLOUDSTORAGEBINDSTATUS"]._serialized_end = 235
    _globals["_GETCLOUDSTORAGEBINDSTATUSRESP"]._serialized_start = 237
    _globals["_GETCLOUDSTORAGEBINDSTATUSRESP"]._serialized_end = 332
# @@protoc_insertion_point(module_scope)
