# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: exposure_update.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from options_pb2 import *
from exposure_pb2 import *

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x15\x65xposure_update.proto\x12\x11insta360.messages\x1a\roptions.proto\x1a\x0e\x65xposure.proto"\xcc\x01\n\x1aNotificationExposureUpdate\x12\x36\n\rfunction_mode\x18\x01 \x01(\x0e\x32\x1f.insta360.messages.FunctionMode\x12:\n\x0estill_exposure\x18\x02 \x01(\x0b\x32".insta360.messages.ExposureOptions\x12:\n\x0evideo_exposure\x18\x03 \x01(\x0b\x32".insta360.messages.ExposureOptionsB\x08\xa2\x02\x05INSPBP\x00P\x01\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "exposure_update_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"\242\002\005INSPB"
    _globals["_NOTIFICATIONEXPOSUREUPDATE"]._serialized_start = 76
    _globals["_NOTIFICATIONEXPOSUREUPDATE"]._serialized_end = 280
# @@protoc_insertion_point(module_scope)
