# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: detect_face.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x11\x64\x65tect_face.proto\x12\x11insta360.messages"\xe9\x01\n\x16NotificationDetectFace\x12\x15\n\rdetectFaceNum\x18\x01 \x01(\r\x12\x46\n\x06reason\x18\x02 \x01(\x0e\x32\x36.insta360.messages.NotificationDetectFace.ChangeReason\x12\x1c\n\x14isRecommendPorFilter\x18\x03 \x01(\x08"R\n\x0c\x43hangeReason\x12\x0e\n\nFPS_CHANGE\x10\x00\x12\x18\n\x14\x45XPOSURE_MODE_CHANGE\x10\x01\x12\x18\n\x14RECOMMEND_POR_FILTER\x10\x02\x42\x08\xa2\x02\x05INSPBb\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "detect_face_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"\242\002\005INSPB"
    _globals["_NOTIFICATIONDETECTFACE"]._serialized_start = 41
    _globals["_NOTIFICATIONDETECTFACE"]._serialized_end = 274
    _globals["_NOTIFICATIONDETECTFACE_CHANGEREASON"]._serialized_start = 192
    _globals["_NOTIFICATIONDETECTFACE_CHANGEREASON"]._serialized_end = 274
# @@protoc_insertion_point(module_scope)
