# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: active_sensor_device.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from sensor_pb2 import *

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x1a\x61\x63tive_sensor_device.proto\x12\x11insta360.messages\x1a\x0csensor.proto"\x17\n\x15GetActiveSensorDevice"b\n\x19GetActiveSensorDeviceResp\x12/\n\x06\x64\x65vice\x18\x01 \x01(\x0e\x32\x1f.insta360.messages.SensorDevice\x12\x14\n\x0cmedia_offset\x18\x02 \x01(\t"H\n\x15SetActiveSensorDevice\x12/\n\x06\x64\x65vice\x18\x01 \x01(\x0e\x32\x1f.insta360.messages.SensorDevice"1\n\x19SetActiveSensorDeviceResp\x12\x14\n\x0cmedia_offset\x18\x01 \x01(\tB\x08\xa2\x02\x05INSPBP\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(
    DESCRIPTOR, "active_sensor_device_pb2", _globals
)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"\242\002\005INSPB"
    _globals["_GETACTIVESENSORDEVICE"]._serialized_start = 63
    _globals["_GETACTIVESENSORDEVICE"]._serialized_end = 86
    _globals["_GETACTIVESENSORDEVICERESP"]._serialized_start = 88
    _globals["_GETACTIVESENSORDEVICERESP"]._serialized_end = 186
    _globals["_SETACTIVESENSORDEVICE"]._serialized_start = 188
    _globals["_SETACTIVESENSORDEVICE"]._serialized_end = 260
    _globals["_SETACTIVESENSORDEVICERESP"]._serialized_start = 262
    _globals["_SETACTIVESENSORDEVICERESP"]._serialized_end = 311
# @@protoc_insertion_point(module_scope)
