# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: darkeis_status.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x14\x64\x61rkeis_status.proto\x12\x11insta360.messages"\x80\x02\n\x19NotificationDarkEisStatus\x12R\n\x0e\x64\x61rkeis_status\x18\x01 \x01(\x0e\x32:.insta360.messages.NotificationDarkEisStatus.DarkEisStatus"\x8e\x01\n\rDarkEisStatus\x12\x17\n\x13\x44\x41RKEIS_ENABLE_SHOW\x10\x00\x12\x17\n\x13\x44\x41RKEIS_ENABLE_HIDE\x10\x01\x12\x18\n\x14\x44\x41RKEIS_DISABLE_SHOW\x10\x02\x12\x18\n\x14\x44\x41RKEIS_DISABLE_HIDE\x10\x03\x12\x17\n\x13\x44\x41RKEIS_DARKEIS_NUM\x10\x04\x42\x08\xa2\x02\x05INSPBb\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "darkeis_status_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"\242\002\005INSPB"
    _globals["_NOTIFICATIONDARKEISSTATUS"]._serialized_start = 44
    _globals["_NOTIFICATIONDARKEISSTATUS"]._serialized_end = 300
    _globals["_NOTIFICATIONDARKEISSTATUS_DARKEISSTATUS"]._serialized_start = 158
    _globals["_NOTIFICATIONDARKEISSTATUS_DARKEISSTATUS"]._serialized_end = 300
# @@protoc_insertion_point(module_scope)
