# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: set_standby_mode.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x16set_standby_mode.proto\x12\x11insta360.messages"\xb5\x01\n\x0eSetStandbyMode\x12\x43\n\x0cstandby_mode\x18\x01 \x01(\x0e\x32-.insta360.messages.SetStandbyMode.StandbyMode"^\n\x0bStandbyMode\x12\x18\n\x14STANDBY_MODE_UNKNOWN\x10\x00\x12\x1b\n\x17STANDBY_MODE_LOW_ENERGY\x10\x01\x12\x18\n\x14STANDBY_MODE_WAKE_UP\x10\x02"\x14\n\x12SetStandbyModeRespB\x08\xa2\x02\x05INSPBb\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "set_standby_mode_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"\242\002\005INSPB"
    _globals["_SETSTANDBYMODE"]._serialized_start = 46
    _globals["_SETSTANDBYMODE"]._serialized_end = 227
    _globals["_SETSTANDBYMODE_STANDBYMODE"]._serialized_start = 133
    _globals["_SETSTANDBYMODE_STANDBYMODE"]._serialized_end = 227
    _globals["_SETSTANDBYMODERESP"]._serialized_start = 229
    _globals["_SETSTANDBYMODERESP"]._serialized_end = 249
# @@protoc_insertion_point(module_scope)
