# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: set_wifi_connect_list.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from wifi_connection_info_pb2 import *

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x1bset_wifi_connect_list.proto\x12\x11insta360.messages\x1a\x1awifi_connection_info.proto"4\n\x12SetWifiConnectList\x12\x0c\n\x04ssid\x18\x01 \x01(\t\x12\x10\n\x08password\x18\x02 \x01(\t"\xa0\x01\n\x16SetWifiConnectListResp\x12=\n\x03res\x18\x01 \x01(\x0e\x32\x30.insta360.messages.SetWifiConnectListResp.Result"G\n\x06Result\x12\x08\n\x04NONE\x10\x00\x12\x0b\n\x07SUCCESS\x10\x01\x12\x12\n\x0eSSID_NOT_FOUND\x10\x02\x12\x12\n\x0ePASSWORD_ERROR\x10\x03"%\n\x15\x44\x65leteWifiConnectList\x12\x0c\n\x04ssid\x18\x01 \x01(\t"\x92\x01\n\x19\x44\x65leteWifiConnectListResp\x12@\n\x03res\x18\x01 \x01(\x0e\x32\x33.insta360.messages.DeleteWifiConnectListResp.Result"3\n\x06Result\x12\x08\n\x04NONE\x10\x00\x12\x0b\n\x07SUCCESS\x10\x01\x12\x12\n\x0eSSID_NOT_FOUND\x10\x02\x42\x08\xa2\x02\x05INSPBP\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(
    DESCRIPTOR, "set_wifi_connect_list_pb2", _globals
)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"\242\002\005INSPB"
    _globals["_SETWIFICONNECTLIST"]._serialized_start = 78
    _globals["_SETWIFICONNECTLIST"]._serialized_end = 130
    _globals["_SETWIFICONNECTLISTRESP"]._serialized_start = 133
    _globals["_SETWIFICONNECTLISTRESP"]._serialized_end = 293
    _globals["_SETWIFICONNECTLISTRESP_RESULT"]._serialized_start = 222
    _globals["_SETWIFICONNECTLISTRESP_RESULT"]._serialized_end = 293
    _globals["_DELETEWIFICONNECTLIST"]._serialized_start = 295
    _globals["_DELETEWIFICONNECTLIST"]._serialized_end = 332
    _globals["_DELETEWIFICONNECTLISTRESP"]._serialized_start = 335
    _globals["_DELETEWIFICONNECTLISTRESP"]._serialized_end = 481
    _globals["_DELETEWIFICONNECTLISTRESP_RESULT"]._serialized_start = 222
    _globals["_DELETEWIFICONNECTLISTRESP_RESULT"]._serialized_end = 273
# @@protoc_insertion_point(module_scope)
