# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: offset_state.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b"\n\x12offset_state.proto\x12\x11insta360.messages*\x80\x01\n\x0bOffsetState\x12\n\n\x06\x43ommon\x10\x00\x12\x11\n\rSphereProtect\x10\x01\x12\x0f\n\x0b\x44ivingWater\x10\x02\x12\x11\n\rDivingWater23\x10\x03\x12\r\n\tProtect_A\x10\x04\x12\r\n\tProtect_S\x10\x05\x12\x10\n\x0cProtect_Auto\x10\x06*S\n\x12OffsetDetectedType\x12\n\n\x06Unkown\x10\x00\x12\n\n\x06\x41uto_A\x10\x01\x12\n\n\x06\x41uto_S\x10\x02\x12\x0c\n\x08\x41uto_off\x10\x03\x12\x0b\n\x07\x41uto_AS\x10\x04\x42\x08\xa2\x02\x05INSPBb\x06proto3"
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "offset_state_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"\242\002\005INSPB"
    _globals["_OFFSETSTATE"]._serialized_start = 42
    _globals["_OFFSETSTATE"]._serialized_end = 170
    _globals["_OFFSETDETECTEDTYPE"]._serialized_start = 172
    _globals["_OFFSETDETECTEDTYPE"]._serialized_end = 255
# @@protoc_insertion_point(module_scope)
