# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: start_live_stream.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from video_pb2 import *
from media_pb2 import *

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x17start_live_stream.proto\x12\x11insta360.messages\x1a\x0bvideo.proto\x1a\x0bmedia.proto"\x90\x03\n\x0fStartLiveStream\x12\x13\n\x0b\x65nableAudio\x18\x01 \x01(\x08\x12\x13\n\x0b\x65nableVideo\x18\x02 \x01(\x08\x12/\n\taudioType\x18\x03 \x01(\x0e\x32\x1c.insta360.messages.AACBSType\x12\x17\n\x0f\x61udioSampleRate\x18\x04 \x01(\r\x12\x14\n\x0c\x61udioBitrate\x18\x05 \x01(\r\x12\x14\n\x0cvideoBitrate\x18\x06 \x01(\r\x12\x36\n\nresolution\x18\x07 \x01(\x0e\x32".insta360.messages.VideoResolution\x12\x12\n\nenableGyro\x18\x08 \x01(\x08\x12\x15\n\rvideoBitrate1\x18\t \x01(\r\x12\x37\n\x0bresolution1\x18\n \x01(\x0e\x32".insta360.messages.VideoResolution\x12\x18\n\x10previewStreamNum\x18\x0b \x01(\r\x12\x14\n\x0c\x65nableRotate\x18\x0c \x01(\x08\x12\x11\n\tisForLive\x18\r \x01(\x08"\x15\n\x13StartLiveStreamRespB\x08\xa2\x02\x05INSPBP\x00P\x01\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "start_live_stream_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"\242\002\005INSPB"
    _globals["_STARTLIVESTREAM"]._serialized_start = 73
    _globals["_STARTLIVESTREAM"]._serialized_end = 473
    _globals["_STARTLIVESTREAMRESP"]._serialized_start = 475
    _globals["_STARTLIVESTREAMRESP"]._serialized_end = 496
# @@protoc_insertion_point(module_scope)
