# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sync_capture_mode.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b"\n\x17sync_capture_mode.proto\x12\x11insta360.messages*\xc8\x02\n\x0fSyncCaptureMode\x12\x15\n\x11SYNC_MODE_UNKNOWN\x10\x00\x12\x1a\n\x16SYNC_MODE_NORMAL_IMAGE\x10\x01\x12\x1a\n\x16SYNC_MODE_NORMAL_VIDEO\x10\x02\x12\x17\n\x13SYNC_MODE_HDR_IMAGE\x10\x03\x12\x17\n\x13SYNC_MODE_HDR_VIDEO\x10\x04\x12\x1c\n\x18SYNC_MODE_INTERVAL_IMAGE\x10\x05\x12\x1d\n\x19SYNC_MODE_TIMELAPSE_VIDEO\x10\x06\x12\x19\n\x15SYNC_MODE_BURST_PHOTO\x10\x07\x12\x1e\n\x1aSYNC_MODE_BULLETTIME_VIDEO\x10\x08\x12\x1d\n\x19SYNC_MODE_TIMESHIFT_VIDEO\x10\t\x12\x1d\n\x19SYNC_MODE_AEB_NIGHT_PHOTO\x10\nB\x08\xa2\x02\x05INSPBb\x06proto3"
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "sync_capture_mode_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"\242\002\005INSPB"
    _globals["_SYNCCAPTUREMODE"]._serialized_start = 47
    _globals["_SYNCCAPTUREMODE"]._serialized_end = 375
# @@protoc_insertion_point(module_scope)
