# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: exposure.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x0e\x65xposure.proto\x12\x11insta360.messages"\xd8\x01\n\x0f\x45xposureOptions\x12;\n\x07program\x18\x01 \x01(\x0e\x32*.insta360.messages.ExposureOptions.Program\x12\x0b\n\x03iso\x18\x02 \x01(\r\x12\x15\n\rshutter_speed\x18\x03 \x01(\x01"d\n\x07Program\x12\x08\n\x04\x41UTO\x10\x00\x12\x10\n\x0cISO_PRIORITY\x10\x01\x12\x14\n\x10SHUTTER_PRIORITY\x10\x02\x12\n\n\x06MANUAL\x10\x03\x12\x0c\n\x08\x41\x44\x41PTIVE\x10\x04\x12\r\n\tFULL_AUTO\x10\x05\x42\x08\xa2\x02\x05INSPBb\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "exposure_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"\242\002\005INSPB"
    _globals["_EXPOSUREOPTIONS"]._serialized_start = 38
    _globals["_EXPOSUREOPTIONS"]._serialized_end = 254
    _globals["_EXPOSUREOPTIONS_PROGRAM"]._serialized_start = 154
    _globals["_EXPOSUREOPTIONS_PROGRAM"]._serialized_end = 254
# @@protoc_insertion_point(module_scope)
