# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: set_options.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from options_pb2 import *

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x11set_options.proto\x12\x11insta360.messages\x1a\roptions.proto"l\n\nSetOptions\x12\x33\n\x0coption_types\x18\x01 \x03(\x0e\x32\x1d.insta360.messages.OptionType\x12)\n\x05value\x18\x02 \x01(\x0b\x32\x1a.insta360.messages.Options"E\n\x0eSetOptionsResp\x12\x33\n\x0coption_types\x18\x01 \x03(\x0e\x32\x1d.insta360.messages.OptionTypeB\x08\xa2\x02\x05INSPBP\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "set_options_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"\242\002\005INSPB"
    _globals["_SETOPTIONS"]._serialized_start = 55
    _globals["_SETOPTIONS"]._serialized_end = 163
    _globals["_SETOPTIONSRESP"]._serialized_start = 165
    _globals["_SETOPTIONSRESP"]._serialized_end = 234
# @@protoc_insertion_point(module_scope)
