# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: message_code.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x12message_code.proto\x12\x11insta360.messages*\xc2@\n\x0bMessageCode\x12\x17\n\x13PHONE_COMMAND_BEGIN\x10\x00\x12#\n\x1fPHONE_COMMAND_START_LIVE_STREAM\x10\x01\x12"\n\x1ePHONE_COMMAND_STOP_LIVE_STREAM\x10\x02\x12\x1e\n\x1aPHONE_COMMAND_TAKE_PICTURE\x10\x03\x12\x1f\n\x1bPHONE_COMMAND_START_CAPTURE\x10\x04\x12\x1e\n\x1aPHONE_COMMAND_STOP_CAPTURE\x10\x05\x12 \n\x1cPHONE_COMMAND_CANCEL_CAPTURE\x10\x06\x12\x1d\n\x19PHONE_COMMAND_SET_OPTIONS\x10\x07\x12\x1d\n\x19PHONE_COMMAND_GET_OPTIONS\x10\x08\x12)\n%PHONE_COMMAND_SET_PHOTOGRAPHY_OPTIONS\x10\t\x12)\n%PHONE_COMMAND_GET_PHOTOGRAPHY_OPTIONS\x10\n\x12 \n\x1cPHONE_COMMAND_GET_FILE_EXTRA\x10\x0b\x12\x1e\n\x1aPHONE_COMMAND_DELETE_FILES\x10\x0c\x12$\n\x1fPHONE_COMMAND_GET_EDITINFO_LIST\x10\xc9\x01\x12\x1f\n\x1bPHONE_COMMAND_GET_FILE_LIST\x10\r\x12.\n*PHONE_COMMAND_TAKE_PICTURE_WITHOUT_STORING\x10\x0e\x12,\n(PHONE_COMMAND_GET_CURRENT_CAPTURE_STATUS\x10\x0f\x12 \n\x1cPHONE_COMMAND_SET_FILE_EXTRA\x10\x10\x12\'\n#PHONE_COMMAND_GET_TIMELAPSE_OPTIONS\x10\x11\x12\'\n#PHONE_COMMAND_SET_TIMELAPSE_OPTIONS\x10\x12\x12\x1a\n\x16PHONE_COMMAND_GET_GYRO\x10\x13\x12!\n\x1dPHONE_COMMAND_START_TIMELAPSE\x10\x16\x12 \n\x1cPHONE_COMMAND_STOP_TIMELAPSE\x10\x17\x12\x1f\n\x1bPHONE_COMMAND_ERASE_SD_CARD\x10\x18\x12 \n\x1cPHONE_COMMAND_CALIBRATE_GYRO\x10\x19\x12$\n PHONE_COMMAND_SCAN_BT_PERIPHERAL\x10\x1a\x12*\n&PHONE_COMMAND_CONNECT_TO_BT_PERIPHERAL\x10\x1b\x12*\n&PHONE_COMMAND_DISCONNECT_BT_PERIPHERAL\x10\x1c\x12.\n*PHONE_COMMAND_GET_CONNECTED_BT_PERIPHERALS\x10\x1d\x12$\n PHONE_COMMAND_GET_MINI_THUMBNAIL\x10\x1e\x12$\n PHONE_COMMAND_TEST_SD_CARD_SPEED\x10\x1f\x12\x1f\n\x1bPHONE_COMMAND_REBOOT_CAMERA\x10 \x12"\n\x1ePHONE_COMMAND_OPEN_CAMERA_WIFI\x10!\x12#\n\x1fPHONE_COMMAND_CLOSE_CAMERA_WIFI\x10"\x12\x1c\n\x18PHONE_COMMAND_OPEN_IPERF\x10#\x12\x1d\n\x19PHONE_COMMAND_CLOSE_IPERF\x10$\x12#\n\x1fPHONE_COMMAND_GET_IPERF_AVERAGE\x10%\x12#\n\x1fPHONE_COMMAND_GET_FILEINFO_LIST\x10&\x12%\n!PHONE_COMMAND_CHECK_AUTHORIZATION\x10\'\x12&\n"PHONE_COMMAND_CANCEL_AUTHORIZATION\x10(\x12*\n&PHONE_COMMAND_START_BULLETTIME_CAPTURE\x10)\x12%\n!PHONE_COMMAND_SET_SUBMODE_OPTIONS\x10*\x12%\n!PHONE_COMMAND_GET_SUBMODE_OPTIONS\x10+\x12)\n%PHONE_COMMAND_STOP_BULLETTIME_CAPTURE\x10\x30\x12\x1b\n\x17PHONE_COMMAND_OPEN_OLED\x10\x31\x12\x1c\n\x18PHONE_COMMAND_CLOSE_OLED\x10\x32\x12#\n\x1fPHONE_COMMAND_START_HDR_CAPTURE\x10\x33\x12"\n\x1ePHONE_COMMAND_STOP_HDR_CAPTURE\x10\x34\x12\x1c\n\x18PHONE_COMMAND_UPLOAD_GPS\x10\x35\x12\'\n#PHONE_COMMAND_SET_SYNC_CAPTURE_MODE\x10\x36\x12\'\n#PHONE_COMMAND_GET_SYNC_CAPTURE_MODE\x10\x37\x12"\n\x1ePHONE_COMMAND_SET_STANDBY_MODE\x10\x38\x12*\n&PHONE_COMMAND_RESTORE_FACTORY_SETTINGS\x10\x39\x12.\n*PHONE_COMMAND_SET_TEMPORARY_OPTIONS_SWITCH\x10:\x12.\n*PHONE_COMMAND_GET_TEMPORARY_OPTIONS_SWITCH\x10;\x12$\n PHONE_COMMAND_SET_KEY_TIME_POINT\x10<\x12)\n%PHONE_COMMAND_START_TIMESHIFT_CAPTURE\x10=\x12(\n$PHONE_COMMAND_STOP_TIMESHIFT_CAPTURE\x10>\x12&\n"PHONE_COMMAND_SET_FLOWSTATE_ENABLE\x10?\x12&\n"PHONE_COMMAND_GET_FLOWSTATE_ENABLE\x10@\x12#\n\x1fPHONE_COMMAND_SET_ACTIVE_SENSOR\x10\x41\x12#\n\x1fPHONE_COMMAND_GET_ACTIVE_SENSOR\x10\x42\x12$\n PHONE_COMMAND_GET_RECORDING_FILE\x10G\x12/\n+PHONE_COMMAND_SET_MULTI_PHOTOGRAPHY_OPTIONS\x10\x43\x12/\n+PHONE_COMMAND_GET_MULTI_PHOTOGRAPHY_OPTIONS\x10\x44\x12*\n&PHONE_COMMAND_PREPARE_GET_FILE_PACKAGE\x10S\x12)\n%PHONE_COMMAND_GET_FILE_PACKAGE_FINISH\x10T\x12\'\n#PHONE_COMMAND_SET_WIFI_SEIZE_ENABLE\x10U\x12\'\n#PHONE_COMMAND_REQUEST_AUTHORIZATION\x10V\x12.\n*PHONE_COMMAND_CANCEL_REQUEST_AUTHORIZATION\x10W\x12(\n$PHONE_COMMAND_SET_BUTTON_PRESS_PARAM\x10g\x12(\n$PHONE_COMMAND_GET_BUTTON_PRESS_PARAM\x10h\x12 \n\x1cPHONE_COMMAND_IFRAME_REQUEST\x10i\x12*\n&PHONE_COMMAND_SET_WIFI_CONNECTION_INFO\x10p\x12*\n&PHONE_COMMAND_GET_WIFI_CONNECTION_INFO\x10q\x12.\n*PHONE_COMMAND_SET_ACCESS_CAMERA_FILE_STATE\x10v\x12\x1b\n\x17PHONE_COMMAND_SET_APPID\x10x\x12\x1c\n\x18PHONE_COMMAND_RESET_WIFI\x10}\x12\x30\n+PHONE_COMMAND_PREPARE_GET_FILE_SYNC_PACKAGE\x10\x97\x01\x12/\n*PHONE_COMMAND_GET_FILE_PACKAGE_SYNC_FINISH\x10\x98\x01\x12"\n\x1dPHONE_COMMAND_DARK_EIS_STATUS\x10\x9d\x01\x12"\n\x1dPHONE_COMMAND_PAUSE_RECORDING\x10\xa4\x01\x12#\n\x1ePHONE_COMMAND_NOTIFY_OTA_ERROR\x10\xa7\x01\x12 \n\x1bPHONE_COMMAND_DOWNLOAD_INFO\x10\xad\x01\x12)\n$PHONE_COMMAND_GET_DOWNLOAD_FILE_LIST\x10\xac\x01\x12\x30\n+PHONE_COMMAND_ADD_DOWNLOAD_LIST_RESULT_SYNC\x10\xbe\x01\x12+\n&CAMERA_NOTIFICATION_DELETE_FILE_RESULT\x10\xd7@\x12\'\n"PHONE_COMMAND_SET_CAMERA_LIVE_INFO\x10\x87\x01\x12\'\n"PHONE_COMMAND_GET_CAMERA_LIVE_INFO\x10\x88\x01\x12$\n\x1fPHONE_COMMAND_START_CAMERA_LIVE\x10\x89\x01\x12#\n\x1ePHONE_COMMAND_STOP_CAMERA_LIVE\x10\x90\x01\x12+\n&PHONE_COMMAND_START_CAMERA_LIVE_RECORD\x10\x91\x01\x12*\n%PHONE_COMMAND_STOP_CAMERA_LIVE_RECORD\x10\x92\x01\x12 \n\x1bPHONE_COMMAND_SET_WIFI_MODE\x10\x93\x01\x12%\n PHONE_COMMAND_GET_WIFI_SCAN_LIST\x10\x94\x01\x12*\n%PHONE_COMMAND_GET_CONNECTED_WIFI_LIST\x10\x95\x01\x12 \n\x1bPHONE_COMMAND_GET_WIFI_MODE\x10\x96\x01\x12\x18\n\x13PHONE_REQUEST_BEGIN\x10\x80 \x12\x1e\n\x19\x43\x41MERA_NOTIFICATION_BEGIN\x10\x80@\x12*\n%CAMERA_NOTIFICATION_INTERVAL_REC_INFO\x10\xce@\x12\x32\n-CAMERA_NOTIFICATION_FIRMWARE_UPGRADE_COMPLETE\x10\x81@\x12+\n&CAMERA_NOTIFICATION_CAPTURE_AUTO_SPLIT\x10\x82@\x12\'\n"CAMERA_NOTIFICATION_BATTERY_UPDATE\x10\x83@\x12$\n\x1f\x43\x41MERA_NOTIFICATION_BATTERY_LOW\x10\x84@\x12!\n\x1c\x43\x41MERA_NOTIFICATION_SHUTDOWN\x10\x85@\x12\'\n"CAMERA_NOTIFICATION_STORAGE_UPDATE\x10\x86@\x12%\n CAMERA_NOTIFICATION_STORAGE_FULL\x10\x87@\x12$\n\x1f\x43\x41MERA_NOTIFICATION_KEY_PRESSED\x10\x88@\x12(\n#CAMERA_NOTIFICATION_CAPTURE_STOPPED\x10\x89@\x12\x32\n-CAMERA_NOTIFICATION_TAKE_PICTURE_STATE_UPDATE\x10\x8a@\x12.\n)CAMERA_NOTIFICATION_DELETE_FILES_PROGRESS\x10\x8b@\x12%\n CAMERA_NOTIFICATION_PHONE_INSERT\x10\x8c@\x12/\n*CAMERA_NOTIFICATION_BT_DISCOVER_PERIPHERAL\x10\x8d@\x12\x33\n.CAMERA_NOTIFICATION_BT_CONNECTED_TO_PERIPHERAL\x10\x8e@\x12\x33\n.CAMERA_NOTIFICATION_BT_DISCONNECTED_PERIPHERAL\x10\x8f@\x12/\n*CAMERA_NOTIFICATION_CURRENT_CAPTURE_STATUS\x10\x90@\x12-\n(CAMERA_NOTIFICATION_AUTHORIZATION_RESULT\x10\x91@\x12\x30\n+CAMERA_NOTIFICATION_TIMELAPSE_STATUS_UPDATE\x10\x92@\x12\x31\n,CAMERA_NOTIFICATION_SYNC_CAPTURE_MODE_UPDATE\x10\x93@\x12\x34\n/CAMERA_NOTIFICATION_SYNC_CAPTURE_BUTTON_TRIGGER\x10\x94@\x12.\n)CAMERA_NOTIFICATION_BT_REMOTE_VER_UPDATED\x10\x95@\x12.\n)CAMERA_NOTIFICATION_CAM_TEMPERATURE_VALUE\x10\x96@\x12\'\n"CAMERA_NOTIFICATION_CAM_WIFI_START\x10\x97@\x12\x32\n-CAMERA_NOTIFICATION_CAM_BT_MSG_ANALYZE_FAILED\x10\x98@\x12\x32\n-CAMERA_NOTIFICATION_CHARGE_BOX_BATTERY_UPDATE\x10\x99@\x12.\n)CAMERA_NOTIFICATION_LIVEVIEW_BEGIN_ROTATE\x10\x9b@\x12(\n#CAMERA_NOTIFICATION_EXPOSURE_UPDATE\x10\x9c@\x12\x32\n-CAMERA_NOTIFICATION_CHARGE_BOX_CONNECT_STATUS\x10\x9e@\x12$\n\x1f\x43\x41MERA_NOTIFICATION_WIFI_STATUS\x10\xa8@\x12\x32\n-CAMERA_NOTIFICATION_UPDATE_LIVE_STREAM_PARAMS\x10\xaa@\x12\x36\n1CAMERA_NOTIFICATION_FIRMWARE_UPGRADE_STATUS_TOAPP\x10\xae@\x12+\n&CAMERA_NOTIFICATION_CAMERA_LIVE_STATUS\x10\xb6@\x12)\n$CAMERA_NOTIFICATION_WIFI_MODE_CHANGE\x10\xb7@\x12+\n&CAMERA_NOTIFICATION_DATA_EXPORT_STATUS\x10\xb8@\x12/\n*CAMERA_NOTIFICATION_WIFI_SCAN_LIST_CHANGED\x10\xb9@\x12&\n!CAMERA_NOTIFICATION_DETECTED_FACE\x10\xba@\x12(\n#CAMERA_NOTIFICATION_DARK_EIS_STATUS\x10\xbc@\x12\x39\n4CAMERA_NOTIFICATION_SUPPORT_TAKE_PHOTO_ON_REC_STATUS\x10\xc0@\x12&\n!PHONE_COMMAND_STOP_USBCARD_BACKUP\x10\x85\x01\x12)\n$PHONE_COMMAND_QUICKREADER_GET_STATUS\x10\xb6\x01\x12\'\n"CAMERA_NOTIFICATION_USBCARD_STATUS\x10\xb2@\x12+\n&CAMERA_NOTIFICATION_NEED_DOWNLOAD_FILE\x10\xc3@\x12+\n&CAMERA_NOTIFICATION_CAM_SUBMODE_CHANGE\x10\xd3@\x12/\n*CAMERA_NOTIFICATION_FAVORITE_CHANGE_STATUS\x10\xdc@\x12\x1f\n\x1aPHONE_COMMAND_SET_FAVORITE\x10\xb0\x01\x12\x32\n-CAMERA_NOTIFICATION_CLOUD_STORAGE_BIND_STATUS\x10\xbf@\x12&\n!CAMERA_NOTIFICATION_USER_TAKEOVER\x10\xdd@\x12\x1a\n\x15\x46\x41\x43TORY_COMMAND_BEGIN\x10\x80`\x12\x1e\n\x19\x46\x41\x43TORY_COMMAND_OLED_TEST\x10\x81`\x12\x1d\n\x18\x46\x41\x43TORY_COMMAND_LED_TEST\x10\x82`\x12!\n\x1c\x46\x41\x43TORY_COMMAND_SPEAKER_TEST\x10\x83`\x12"\n\x1d\x46\x41\x43TORY_COMMAND_OLED_ROW_EVEN\x10\x84`\x12$\n\x1f\x46\x41\x43TORY_COMMAND_OLED_ROW_UNEVEN\x10\x85`\x12#\n\x1e\x46\x41\x43TORY_COMMAND_OLED_LINE_EVEN\x10\x86`\x12%\n FACTORY_COMMAND_OLED_LINE_UNEVEN\x10\x87`\x12%\n FACTORY_COMMAND_WIFI_STATUS_TEST\x10\x88`\x12*\n%FACTORY_COMMAND_BLUETOOTH_STATUS_TEST\x10\x89`\x12\x1f\n\x1a\x46\x41\x43TORY_COMMAND_MOTOR_TEST\x10\x8a`\x12\'\n"FACTORY_COMMAND_WHITE_BALANCE_TEST\x10\x8b`\x12#\n\x1e\x46\x41\x43TORY_COMMAND_GYROSCOPE_TEST\x10\x8c`\x12"\n\x1d\x46\x41\x43TORY_COMMAND_LED_TEST_STOP\x10\x8d`\x12$\n\x1f\x46\x41\x43TORY_COMMAND_MOTOR_TEST_STOP\x10\x8e`\x12.\n)FACTORY_COMMAND_WHITE_BALANCE_STATUS_TEST\x10\x8f`\x12#\n\x1e\x46\x41\x43TORY_COMMAND_FW_AGEING_TEST\x10\x90`\x12\'\n"FACTORY_COMMAND_BUTTON_STATUS_TEST\x10\x91`\x12&\n!FACTORY_COMMAND_TP_JIUGONGGE_TEST\x10\x92`\x12#\n\x1e\x46\x41\x43TORY_COMMAND_LCD_COLOR_TEST\x10\x93`\x12#\n\x1e\x46\x41\x43TORY_COMMAND_USB_SPEED_TEST\x10\x94`\x12*\n%FACTORY_COMMAND_USB_LCD_TP_CLOSE_TEST\x10\x95`\x12\'\n"FACTORY_COMMAND_VIGNETTE_DATA_SAVE\x10\x96`\x12"\n\x1d\x46\x41\x43TORY_COMMAND_BLC_DATA_SAVE\x10\x97`\x12"\n\x1d\x46\x41\x43TORY_COMMAND_BPC_DATA_SAVE\x10\x98`\x12\x1f\n\x1a\x46\x41\x43TORY_COMMAND_PLAY_AUDIO\x10\x99`\x12\x1f\n\x1a\x46\x41\x43TORY_COMMAND_STOP_AUDIO\x10\xa0`\x12\'\n"FACTORY_COMMAND_RECORD_AUDIO_START\x10\xa1`\x12&\n!FACTORY_COMMAND_RECORD_AUDIO_STOP\x10\xa2`\x12!\n\x1c\x46\x41\x43TORY_COMMAND_DEVLINK_TEST\x10\xa3`\x12*\n%FACTORY_COMMAND_GET_AGEINGTEST_STATUS\x10\xa4`\x12(\n#FACTORY_COMMAND_LCD_COLOR_TEST_STOP\x10\xa5`\x12-\n(FACTORY_COMMAND_LCD_COLOR_TEST_COLOR_SET\x10\xa6`\x12+\n&FACTORY_COMMAND_BUTTON_HANDLER_REFRESH\x10\xa7`\x12)\n$FACTORY_COMMAND_OLED_CORRECTION_EVEN\x10\xa8`\x12+\n&FACTORY_COMMAND_OLED_CORRECTION_UNEVEN\x10\xa9`\x12\x34\n/FACTORY_COMMAND_OLED_CORRECTION_SET_OFFSET_TEST\x10\xaa`\x12\x34\n/FACTORY_COMMAND_OLED_CORRECTION_GET_OFFSET_TEST\x10\xab`\x12 \n\x1b\x46\x41\x43TORY_COMMAND_CHARGINGBOX\x10\xac`\x12,\n\'FACTORY_COMMAND_CHARGINGBOX_BUTTON_TEST\x10\xad`\x12*\n%FACTORY_COMMAND_CHARGINGBOX_HALL_TEST\x10\xae`\x12\'\n"FACTORY_COMMAND_SCRIPT_JSON_UPLOAD\x10\xaf`\x12&\n!FACTORY_COMMAND_SCRIPT_CMD_UPLOAD\x10\xb0`\x12#\n\x1e\x46\x41\x43TORY_COMMAND_SCRIPT_REFRESH\x10\xb1`\x12#\n\x1e\x46\x41\x43TORY_COMMAND_SCRIPT_CMD_RUN\x10\xb2`\x12(\n#FACTORY_COMMAND_SET_AAA_FACTORYMODE\x10\xb3`\x12\'\n"FACTORY_COMMAND_SET_AAA_NORMALMODE\x10\xb4`\x12+\n&FACTORY_COMMAND_GET_WHITEBLANCE_STATUS\x10\xb5`\x12#\n\x1e\x46\x41\x43TORY_COMMAND_GET_SFR_STATUS\x10\xb6`\x12#\n\x1e\x46\x41\x43TORY_COMMAND_GET_SFR_RESULT\x10\xb7`\x12\x32\n-PHONE_COMMAND_GET_CLOUD_STORAGE_UPLOAD_STATUS\x10\xa0\x01\x12\x32\n-PHONE_COMMAND_SET_CLOUD_STORAGE_UPLOAD_STATUS\x10\xa1\x01\x12\x30\n+PHONE_COMMAND_GET_CLOUD_STORAGE_BIND_STATUS\x10\xa2\x01\x12\x30\n+PHONE_COMMAND_SET_CLOUD_STORAGE_BIND_STATUS\x10\xa3\x01\x12(\n#PHONE_COMMAND_DEL_WIFI_HISTORY_INFO\x10\xaf\x01\x42\x08\xa2\x02\x05INSPBb\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "message_code_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"\242\002\005INSPB"
    _globals["_MESSAGECODE"]._serialized_start = 42
    _globals["_MESSAGECODE"]._serialized_end = 8300
# @@protoc_insertion_point(module_scope)
