# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: charging_command_type.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b"\n\x1b\x63harging_command_type.proto\x12\x11insta360.messages*\xb9\x02\n\x13\x43hargingMessageCode\x12\x11\n\rFAC_OLED_TEST\x10\x00\x12\x15\n\x11\x46\x41\x43_OLED_ROW_EVEN\x10\x01\x12\x17\n\x13\x46\x41\x43_OLED_ROW_UNEVEN\x10\x02\x12\x16\n\x12\x46\x41\x43_OLED_LINE_EVEN\x10\x03\x12\x18\n\x14\x46\x41\x43_OLED_LINE_UNEVEN\x10\x04\x12\x10\n\x0c\x46\x41\x43_LED_TEST\x10\x05\x12\x14\n\x10\x46\x41\x43_DEVLINK_TEST\x10\x06\x12\x13\n\x0f\x46\x41\x43_BUTTON_TEST\x10\x07\x12\x1b\n\x17\x46\x41\x43_NORMAL_MODE_REFRESH\x10\x08\x12\x11\n\rFAC_HALL_TEST\x10\t\x12\x16\n\x12\x46\x41\x43_BLUETOOTH_TEST\x10\x10\x12\x1b\n\x17\x46\x41\x43_BLUETOOTH_WKUP_TEST\x10\x11\x12\x0b\n\x07\x46\x41\x43_NUM\x10\x12\x42\x08\xa2\x02\x05INSPBb\x06proto3"
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(
    DESCRIPTOR, "charging_command_type_pb2", _globals
)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"\242\002\005INSPB"
    _globals["_CHARGINGMESSAGECODE"]._serialized_start = 51
    _globals["_CHARGINGMESSAGECODE"]._serialized_end = 364
# @@protoc_insertion_point(module_scope)
