# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: set_appid.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x0fset_appid.proto\x12\x11insta360.messages"\x19\n\x08SetAppid\x12\r\n\x05\x61ppid\x18\x01 \x01(\t"\x0e\n\x0cSetAppidRespB\x08\xa2\x02\x05INSPBb\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "set_appid_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"\242\002\005INSPB"
    _globals["_SETAPPID"]._serialized_start = 38
    _globals["_SETAPPID"]._serialized_end = 63
    _globals["_SETAPPIDRESP"]._serialized_start = 65
    _globals["_SETAPPIDRESP"]._serialized_end = 79
# @@protoc_insertion_point(module_scope)
