# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: set_favorite.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x12set_favorite.proto\x12\x11insta360.messages"l\n\x0bSetFavorite\x12\x16\n\x0ematerial_index\x18\x01 \x01(\r\x12\x15\n\rfavorite_flag\x18\x02 \x01(\r\x12\x14\n\x0cmaterial_url\x18\x03 \x01(\t\x12\x18\n\x10modify_timestamp\x18\x04 \x01(\x03"G\n\x0fSetFavoriteList\x12\x34\n\x0cset_favorite\x18\x01 \x03(\x0b\x32\x1e.insta360.messages.SetFavorite"d\n\x13MaterialFavoriteReq\x12\x10\n\x08\x63md_type\x18\x01 \x01(\r\x12\x13\n\x0bindex_start\x18\x02 \x01(\r\x12\x11\n\tindex_end\x18\x03 \x01(\r\x12\x13\n\x0bis_end_flag\x18\x04 \x01(\x08"S\n\x14MaterialFavoriteResp\x12\x10\n\x08\x63md_type\x18\x01 \x01(\r\x12\x13\n\x0bis_end_flag\x18\x02 \x01(\x08\x12\x14\n\x0cmaterial_num\x18\x03 \x01(\rB\x08\xa2\x02\x05INSPBb\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "set_favorite_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"\242\002\005INSPB"
    _globals["_SETFAVORITE"]._serialized_start = 41
    _globals["_SETFAVORITE"]._serialized_end = 149
    _globals["_SETFAVORITELIST"]._serialized_start = 151
    _globals["_SETFAVORITELIST"]._serialized_end = 222
    _globals["_MATERIALFAVORITEREQ"]._serialized_start = 224
    _globals["_MATERIALFAVORITEREQ"]._serialized_end = 324
    _globals["_MATERIALFAVORITERESP"]._serialized_start = 326
    _globals["_MATERIALFAVORITERESP"]._serialized_end = 409
# @@protoc_insertion_point(module_scope)
