# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: interval_rec_info.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b"\n\x17interval_rec_info.proto\x12\x11insta360.messages\"\xe4\x01\n\x0fIntervalRecInfo\x12\x0f\n\x07\x62\x45nable\x18\x01 \x01(\r\x12\x12\n\ntotalCount\x18\x02 \x01(\r\x12\x0c\n\x04mode\x18\x03 \x01(\r\x12\x14\n\x0cintervalTime\x18\x04 \x01(\r\x12\x11\n\tstartTime\x18\x05 \x01(\r\x12\x11\n\tshotCount\x18\x06 \x01(\r\x12:\n\ttoastType\x18\x07 \x01(\x0e\x32'.insta360.messages.IntervalRecToastType\x12\x10\n\x08stopCase\x18\x08 \x01(\r\x12\x14\n\x0csum_duration\x18\t \x01(\r*\xc6\x02\n\x14IntervalRecToastType\x12\x1b\n\x17INTERVAL_REC_TOAST_NULL\x10\x00\x12\x1c\n\x18INTERVAL_REC_TOAST_START\x10\x01\x12\x1f\n\x1bINTERVAL_REC_TOAST_AUTO_END\x10\x02\x12!\n\x1dINTERVAL_REC_TOAST_MANUAL_END\x10\x03\x12\x1d\n\x19INTERVAL_REC_TOAST_CANCEL\x10\x04\x12 \n\x1cINTERVAL_REC_TOAST_OTHER_END\x10\x05\x12#\n\x1fINTERVAL_REC_TOAST_INTERVAL_REC\x10\x06\x12\x1f\n\x1bINTERVAL_REC_TOAST_CONFLICT\x10\x07\x12(\n$INTERVAL_REC_TOAST_AUTO_END_WITH_APP\x10\x08\x42\x08\xa2\x02\x05INSPBb\x06proto3"
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "interval_rec_info_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"\242\002\005INSPB"
    _globals["_INTERVALRECTOASTTYPE"]._serialized_start = 278
    _globals["_INTERVALRECTOASTTYPE"]._serialized_end = 604
    _globals["_INTERVALRECINFO"]._serialized_start = 47
    _globals["_INTERVALRECINFO"]._serialized_end = 275
# @@protoc_insertion_point(module_scope)
