# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: photo.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x0bphoto.proto\x12\x11insta360.messages"<\n\x05Photo\x12\x0b\n\x03uri\x18\x01 \x01(\t\x12\x11\n\tfile_size\x18\x02 \x01(\x04\x12\x13\n\x0bs_thumbnail\x18\x03 \x01(\x0c*\x90\x02\n\tPhotoSize\x12\x12\n\x0eSize_6912_3456\x10\x00\x12\x12\n\x0eSize_6272_3136\x10\x01\x12\x12\n\x0eSize_6080_3040\x10\x02\x12\x12\n\x0eSize_4000_3000\x10\x03\x12\x12\n\x0eSize_4000_2250\x10\x04\x12\x12\n\x0eSize_5212_3542\x10\x05\x12\x12\n\x0eSize_5312_2988\x10\x06\x12\x12\n\x0eSize_8000_6000\x10\x07\x12\x12\n\x0eSize_8000_4500\x10\x08\x12\x12\n\x0eSize_2976_2976\x10\t\x12\x12\n\x0eSize_5984_5984\x10\n\x12\x13\n\x0fSize_11968_5984\x10\x0b\x12\x12\n\x0eSize_5952_2976\x10\x0c*\xbe\x01\n\x0cPhotoSubMode\x12\x10\n\x0cPHOTO_SINGLE\x10\x00\x12\r\n\tPHOTO_HDR\x10\x01\x12\x12\n\x0ePHOTO_INTERVAL\x10\x02\x12\x0f\n\x0bPHOTO_BURST\x10\x03\x12\x13\n\x0fPHOTO_AEB_NIGHT\x10\x04\x12\x14\n\x10PHOTO_INSTA_PANO\x10\x05\x12\x18\n\x14PHOTO_INSTA_PANO_HDR\x10\x06\x12\x13\n\x0fPHOTO_STARLAPSE\x10\x07\x12\x0e\n\nPHOTO_NONE\x10\x64*\xda\x01\n\x0eRawCaptureType\x12\x18\n\x14RAW_CAPTURE_TYPE_OFF\x10\x00\x12\x18\n\x14RAW_CAPTURE_TYPE_DNG\x10\x01\x12\x18\n\x14RAW_CAPTURE_TYPE_RAW\x10\x02\x12\x1d\n\x19RAW_CAPTURE_TYPE_PURESHOT\x10\x03\x12!\n\x1dRAW_CAPTURE_TYPE_PURESHOT_RAW\x10\x04\x12\x19\n\x15RAW_CAPTURE_TYPE_INSP\x10\x05\x12\x1d\n\x19RAW_CAPTURE_TYPE_INSP_RAW\x10\x06\x42\x08\xa2\x02\x05INSPBb\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "photo_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"\242\002\005INSPB"
    _globals["_PHOTOSIZE"]._serialized_start = 97
    _globals["_PHOTOSIZE"]._serialized_end = 369
    _globals["_PHOTOSUBMODE"]._serialized_start = 372
    _globals["_PHOTOSUBMODE"]._serialized_end = 562
    _globals["_RAWCAPTURETYPE"]._serialized_start = 565
    _globals["_RAWCAPTURETYPE"]._serialized_end = 783
    _globals["_PHOTO"]._serialized_start = 34
    _globals["_PHOTO"]._serialized_end = 94
# @@protoc_insertion_point(module_scope)
