# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: photography_options.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from video_pb2 import *
from photo_pb2 import *
from flicker_pb2 import *
from exposure_pb2 import *
from sensor_pb2 import *

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x19photography_options.proto\x12\x11insta360.messages\x1a\x0bvideo.proto\x1a\x0bphoto.proto\x1a\rflicker.proto\x1a\x0e\x65xposure.proto\x1a\x0csensor.proto"\x81,\n\x12PhotographyOptions\x12\x0f\n\x07\x63hannel\x18\x01 \x01(\r\x12\x12\n\nbrightness\x18\x02 \x01(\x11\x12\x10\n\x08\x63ontrast\x18\x03 \x01(\r\x12\x12\n\nsaturation\x18\x04 \x01(\r\x12\x0b\n\x03hue\x18\x05 \x01(\x11\x12\x11\n\tsharpness\x18\x06 \x01(\r\x12\x15\n\rexposure_bias\x18\x07 \x01(\x11\x12I\n\rexposure_mode\x18\x08 \x01(\x0e\x32\x32.insta360.messages.PhotographyOptions.ExposureMode\x12I\n\rexposure_prog\x18\t \x01(\x0b\x32\x32.insta360.messages.PhotographyOptions.ExposureProg\x12M\n\x0f\x65xposure_manual\x18\n \x01(\x0b\x32\x34.insta360.messages.PhotographyOptions.ExposureManual\x12\x45\n\nmeter_mode\x18\x0b \x01(\x0e\x32\x31.insta360.messages.PhotographyOptions.AEMeterMode\x12\x1c\n\x14manual_meter_weights\x18\x0c \x03(\r\x12I\n\rwhite_balance\x18\r \x01(\x0e\x32\x32.insta360.messages.PhotographyOptions.WhiteBalance\x12+\n\x07\x66licker\x18\x0e \x01(\x0e\x32\x1a.insta360.messages.Flicker\x12\x10\n\x08\x65v_index\x18\x0f \x01(\r\x12V\n\x15\x61uto_mode_video_param\x18\x10 \x01(\x0b\x32\x37.insta360.messages.PhotographyOptions.ExposureParameter\x12V\n\x15\x61uto_mode_still_param\x18\x11 \x01(\x0b\x32\x37.insta360.messages.PhotographyOptions.ExposureParameter\x12\x30\n\ngamma_mode\x18\x12 \x01(\x0e\x32\x1c.insta360.messages.GammaMode\x12V\n\x14long_exposure_manual\x18\x13 \x01(\x0b\x32\x38.insta360.messages.PhotographyOptions.LongExposureManual\x12:\n\x0estill_exposure\x18\x14 \x01(\x0b\x32".insta360.messages.ExposureOptions\x12:\n\x0evideo_exposure\x18\x15 \x01(\x0b\x32".insta360.messages.ExposureOptions\x12\x1b\n\x13preview_mctf_enable\x18\x16 \x01(\x08\x12!\n\x19preview_sport_mode_enable\x18\x17 \x01(\x08\x12\x1b\n\x13video_iso_top_limit\x18\x18 \x01(\r\x12;\n\x10raw_capture_type\x18\x19 \x01(\x0e\x32!.insta360.messages.RawCaptureType\x12\x1e\n\x16photography_self_timer\x18\x1a \x01(\r\x12\x17\n\x0f\x61\x65\x62_capture_num\x18\x1b \x01(\r\x12V\n\x13preview_sport_level\x18\x1c \x01(\x0e\x32\x39.insta360.messages.PhotographyOptions.PREVIEW_SPORT_LEVEL\x12\x17\n\x0frecord_duration\x18\x1d \x01(\r\x12\x15\n\rphoto_size_id\x18\x1e \x01(\r\x12=\n\x11record_resolution\x18\x1f \x01(\x0e\x32".insta360.messages.VideoResolution\x12\x15\n\rvideo_bitrate\x18  \x01(\r\x12,\n\x08\x66ov_type\x18! \x01(\x0e\x32\x1a.insta360.messages.FovType\x12\x1d\n\x15\x66lowstate_base_enable\x18" \x01(\x08\x12\x44\n\ncolor_mode\x18# \x01(\x0e\x32\x30.insta360.messages.PhotographyOptions.COLOR_MODE\x12H\n\rres_rec_limit\x18$ \x03(\x0b\x32\x31.insta360.messages.PhotographyOptions.ResRecLimit\x12\x1c\n\x14\x61\x63\x63\x65lerate_frequency\x18% \x01(\r\x12\x1a\n\x12\x66ocal_length_value\x18& \x01(\x01\x12\x1b\n\x13white_balance_value\x18\' \x01(\r\x12\x36\n\x10photo_resolution\x18( \x01(\x0e\x32\x1c.insta360.messages.PhotoSize\x12\x16\n\x0eremaining_time\x18) \x01(\r\x12\x17\n\x0f\x64\x61rk_eis_enable\x18* \x01(\x08\x12P\n\x10\x66low_state_level\x18+ \x01(\x0e\x32\x36.insta360.messages.PhotographyOptions.Flow_State_Level\x12\x19\n\x11\x62urst_capture_num\x18, \x01(\r\x12\x19\n\x11\x63\x61\x63he_capture_num\x18- \x01(\r\x12\x17\n\x0fmetering_enable\x18. \x01(\x08\x12\x1a\n\x12\x62urst_capture_time\x18\x33 \x01(\r\x12\x1c\n\x14\x63\x61\x63he_capture_enable\x18\x34 \x01(\x08\x12\x12\n\nzoom_scale\x18\x35 \x01(\x01\x12\x14\n\x0cmax_rec_time\x18\x36 \x01(\r\x12^\n\x17\x66low_state_level_by_cv5\x18\x37 \x01(\x0e\x32=.insta360.messages.PhotographyOptions.Flow_State_Level_By_Cv5\x12Y\n\x14starlasp_export_type\x18\x38 \x01(\x0e\x32;.insta360.messages.PhotographyOptions.StarLapse_Export_Type\x12#\n\x1bvideo_flowstate_base_enable\x18: \x01(\x08\x12\x1a\n\x12\x64ouble_zoom_enable\x18; \x01(\x08\x12T\n\x12pano_exposure_mode\x18= \x01(\x0e\x32\x38.insta360.messages.PhotographyOptions.Pano_Exposure_Mode\x12L\n\x0bselfie_mode\x18> \x01(\x0e\x32\x37.insta360.messages.PhotographyOptions.VIDEO_SELFIE_MODE\x12\x19\n\x11hdr_switch_status\x18? \x01(\x08\x12\\\n\x18\x66lowstate_horizon_enable\x18\x46 \x01(\x0e\x32:.insta360.messages.PhotographyOptions.FlowStateHorizonType\x1a\x80\x02\n\x0c\x45xposureProg\x12I\n\x04mode\x18\x01 \x01(\x0e\x32;.insta360.messages.PhotographyOptions.ExposureProg.ProgMode\x12\x0b\n\x03iso\x18\x02 \x01(\r\x12I\n\rshutter_speed\x18\x03 \x01(\x0e\x32\x32.insta360.messages.PhotographyOptions.ShutterSpeed"M\n\x08ProgMode\x12\x11\n\rPROG_MODE_OFF\x10\x00\x12\x11\n\rPROG_MODE_ISO\x10\x01\x12\x1b\n\x17PROG_MODE_SHUTTER_SPEED\x10\x02\x1a\xe3\x03\n\x0e\x45xposureManual\x12T\n\x0brelate_mode\x18\x01 \x01(\x0e\x32?.insta360.messages.PhotographyOptions.ExposureManual.RelateMode\x12\x0b\n\x03iso\x18\x02 \x01(\r\x12I\n\rshutter_speed\x18\x03 \x01(\x0e\x32\x32.insta360.messages.PhotographyOptions.ShutterSpeed\x12\x11\n\tvideo_iso\x18\x04 \x01(\r\x12O\n\x13video_shutter_speed\x18\x05 \x01(\x0e\x32\x32.insta360.messages.PhotographyOptions.ShutterSpeed\x12\x11\n\tstill_iso\x18\x06 \x01(\r\x12O\n\x13still_shutter_speed\x18\x07 \x01(\x0e\x32\x32.insta360.messages.PhotographyOptions.ShutterSpeed"[\n\nRelateMode\x12\x15\n\x11RELATE_MODE_VIDEO\x10\x00\x12\x15\n\x11RELATE_MODE_STILL\x10\x01\x12\x1f\n\x1bRELATE_MODE_VIDEO_AND_STILL\x10\x02\x1ak\n\x11\x45xposureParameter\x12\x0b\n\x03iso\x18\x01 \x01(\r\x12I\n\rshutter_speed\x18\x02 \x01(\x0e\x32\x32.insta360.messages.PhotographyOptions.ShutterSpeed\x1a\x38\n\x12LongExposureManual\x12\x0b\n\x03iso\x18\x01 \x01(\r\x12\x15\n\rshutter_speed\x18\x02 \x01(\r\x1aX\n\x0bResRecLimit\x12\x35\n\tvideo_res\x18\x01 \x01(\x0e\x32".insta360.messages.VideoResolution\x12\x12\n\nlimit_time\x18\x02 \x01(\r"L\n\x0c\x45xposureMode\x12\x11\n\rEXP_MODE_AUTO\x10\x00\x12\x14\n\x10\x45XP_MODE_PROGRAM\x10\x01\x12\x13\n\x0f\x45XP_MODE_MANUAL\x10\x02"A\n\x0b\x41\x45MeterMode\x12\x18\n\x14\x41\x45_METER_MODE_NORMAL\x10\x00\x12\x18\n\x14\x41\x45_METER_MODE_MANUAL\x10\x01"a\n\x0cWhiteBalance\x12\x0b\n\x07WB_AUTO\x10\x00\x12\x0c\n\x08WB_2700K\x10\x01\x12\x0c\n\x08WB_4000K\x10\x02\x12\x0c\n\x08WB_5000K\x10\x03\x12\x0c\n\x08WB_6500K\x10\x04\x12\x0c\n\x08WB_7500K\x10\x05"_\n\x13PREVIEW_SPORT_LEVEL\x12\x16\n\x12PREVIEW_SPORT_AUTO\x10\x00\x12\x16\n\x12PREVIEW_SPORT_FAST\x10\x01\x12\x18\n\x14PREVIEW_SPORT_FASTER\x10\x02"a\n\nCOLOR_MODE\x12\x15\n\x11\x43OLOR_MODE_NORMAL\x10\x00\x12\x12\n\x0e\x43OLOR_MODE_LOG\x10\x01\x12\x14\n\x10\x43OLOR_MODE_VIVID\x10\x02\x12\x12\n\x0e\x43OLOR_MODE_HDR\x10\x03"\x82\x01\n\x10\x46low_State_Level\x12\x1a\n\x16\x46low_State_Level_Close\x10\x00\x12\x18\n\x14\x46low_State_Level_Low\x10\x01\x12\x1d\n\x19\x46low_State_Level_Standard\x10\x02\x12\x19\n\x15\x46LOW_State_Level_High\x10\x03"\x9d\x01\n\x17\x46low_State_Level_By_Cv5\x12\x1e\n\x1a\x46low_State_Level_CV5_Close\x10\x00\x12\x1f\n\x1b\x46LOW_State_Level_CV5_Slight\x10\x01\x12 \n\x1c\x46LOW_State_Level_CV5_General\x10\x02\x12\x1f\n\x1b\x46LOW_State_Level_CV5_Strong\x10\x03"Z\n\x15StarLapse_Export_Type\x12\x13\n\x0fStarLapse_Video\x10\x00\x12\x15\n\x11Star_Trails_Video\x10\x01\x12\x15\n\x11Star_Trails_Photo\x10\x02"o\n\x12Pano_Exposure_Mode\x12\x1a\n\x16Pano_Exposure_Mode_Off\x10\x00\x12\x1c\n\x18Pano_Exposure_Mode_Light\x10\x01\x12\x1f\n\x1bPano_Exposure_Mode_Lsolated\x10\x02"?\n\x11VIDEO_SELFIE_MODE\x12\r\n\tMODE_NONE\x10\x00\x12\x0b\n\x07ME_MODE\x10\x01\x12\x0e\n\nTORCH_MODE\x10\x02"r\n\x14\x46lowStateHorizonType\x12\x1e\n\x1a\x46LOW_STATE_HORIZON_DISABLE\x10\x00\x12\x1d\n\x19\x46LOW_STATE_HORIZON_ENABLE\x10\x01\x12\x1b\n\x17\x46LOW_STATE_HORIZON_AUTO\x10\x02"\xad\x06\n\x0cShutterSpeed\x12\x0e\n\nSPEED_AUTO\x10\x00\x12\x0c\n\x08SPEED_60\x10\x01\x12\x0c\n\x08SPEED_30\x10\x02\x12\x0c\n\x08SPEED_15\x10\x03\x12\x0b\n\x07SPEED_8\x10\x04\x12\x0b\n\x07SPEED_4\x10\x05\x12\x0b\n\x07SPEED_2\x10\x06\x12\r\n\tSPEED_1P6\x10\x07\x12\r\n\tSPEED_1P3\x10\x08\x12\x0b\n\x07SPEED_1\x10\t\x12\x10\n\x0cSPEED_1D1P25\x10\n\x12\x10\n\x0cSPEED_1D1P67\x10\x0b\x12\r\n\tSPEED_1D2\x10\x0c\x12\x0f\n\x0bSPEED_1D2P5\x10\r\x12\r\n\tSPEED_1D3\x10\x0e\x12\r\n\tSPEED_1D4\x10\x0f\x12\r\n\tSPEED_1D5\x10\x10\x12\x10\n\x0cSPEED_1D6P25\x10\x11\x12\x0e\n\nSPEED_1D8P\x10\x12\x12\x0e\n\nSPEED_1D10\x10\x13\x12\x10\n\x0cSPEED_1D12P5\x10\x14\x12\x0e\n\nSPEED_1D15\x10\x15\x12\x0e\n\nSPEED_1D20\x10\x16\x12\x0e\n\nSPEED_1D25\x10\x17\x12\x0e\n\nSPEED_1D30\x10\x18\x12\x0e\n\nSPEED_1D40\x10\x19\x12\x0e\n\nSPEED_1D50\x10\x1a\x12\x0e\n\nSPEED_1D60\x10\x1b\x12\x0e\n\nSPEED_1D80\x10\x1c\x12\x0f\n\x0bSPEED_1D100\x10\x1d\x12\x0f\n\x0bSPEED_1D120\x10\x1e\x12\x0f\n\x0bSPEED_1D160\x10\x1f\x12\x0f\n\x0bSPEED_1D200\x10 \x12\x0f\n\x0bSPEED_1D240\x10!\x12\x0f\n\x0bSPEED_1D320\x10"\x12\x0f\n\x0bSPEED_1D400\x10#\x12\x0f\n\x0bSPEED_1D500\x10$\x12\x0f\n\x0bSPEED_1D640\x10%\x12\x0f\n\x0bSPEED_1D800\x10&\x12\x10\n\x0cSPEED_1D1000\x10\'\x12\x10\n\x0cSPEED_1D1250\x10(\x12\x10\n\x0cSPEED_1D1600\x10)\x12\x10\n\x0cSPEED_1D2000\x10*\x12\x10\n\x0cSPEED_1D2500\x10+\x12\x10\n\x0cSPEED_1D3200\x10,\x12\x10\n\x0cSPEED_1D4000\x10-\x12\x10\n\x0cSPEED_1D5000\x10.\x12\x10\n\x0cSPEED_1D6400\x10/\x12\x10\n\x0cSPEED_1D8000\x10\x30*\xca\n\n\x15PhotographyOptionType\x12\x1e\n\x1aPHOTOGRAPHY_OPTION_UNKNOWN\x10\x00\x12\x0b\n\x07\x43HANNEL\x10\x01\x12\x0e\n\nBRIGHTNESS\x10\x02\x12\x0c\n\x08\x43ONTRAST\x10\x03\x12\x0e\n\nSATURATION\x10\x04\x12\x07\n\x03HUE\x10\x05\x12\r\n\tSHARPNESS\x10\x06\x12\x11\n\rEXPOSURE_BIAS\x10\x07\x12\x11\n\rEXPOSURE_MODE\x10\x08\x12\x11\n\rEXPOSURE_PROG\x10\t\x12\x13\n\x0f\x45XPOSURE_MANUAL\x10\n\x12\x11\n\rAE_METER_MODE\x10\x0b\x12\x1a\n\x16\x41\x45_MANUAL_METER_WEIGHT\x10\x0c\x12\x11\n\rWHITE_BALANCE\x10\r\x12\x0b\n\x07\x46LICKER\x10\x0e\x12\x0c\n\x08\x45V_INDEX\x10\x0f\x12\x19\n\x15\x41UTO_MODE_VIDEO_PARAM\x10\x10\x12\x19\n\x15\x41UTO_MODE_STILL_PARAM\x10\x11\x12\x14\n\x10VIDEO_GAMMA_MODE\x10\x12\x12\x18\n\x14LONG_EXPOSURE_MANUAL\x10\x13\x12\x1a\n\x16STILL_EXPOSURE_OPTIONS\x10\x14\x12\x1a\n\x16VIDEO_EXPOSURE_OPTIONS\x10\x15\x12\x17\n\x13PREVIEW_MCTF_ENABLE\x10\x16\x12\x1d\n\x19PREVIEW_SPORT_MODE_ENABLE\x10\x17\x12\x17\n\x13VIDEO_ISO_TOP_LIMIT\x10\x18\x12\x14\n\x10RAW_CAPTURE_TYPE\x10\x19\x12\x1a\n\x16PHOTOGRAPHY_SELF_TIMER\x10\x1a\x12\x13\n\x0f\x41\x45\x42_CAPTURE_NUM\x10\x1b\x12\x17\n\x13PREVIEW_SPORT_LEVEL\x10\x1c\x12\x12\n\x0eRECORD_DURAION\x10\x1d\x12\x11\n\rPHOTO_SIZE_ID\x10\x1e\x12\x15\n\x11RECORD_RESOLUTION\x10\x1f\x12\x18\n\x14PHOTO_GRAPHY_BITRATE\x10 \x12\x0c\n\x08\x46OV_TYPE\x10!\x12\x17\n\x13\x46LOWSTATE_BASE_TYPE\x10"\x12\x0e\n\nCOLOR_MODE\x10#\x12\x11\n\rRES_REC_LIMIT\x10$\x12\x18\n\x14\x41\x43\x43\x45LERATE_FREQUENCY\x10%\x12\x16\n\x12\x46OCAL_LENGTH_VALUE\x10&\x12\x17\n\x13WHITE_BALANCE_VALUE\x10\'\x12\x14\n\x10PHOTO_RESOLUTION\x10(\x12\x12\n\x0eREMAINING_TIME\x10)\x12\x13\n\x0f\x44\x41RK_EIS_ENABLE\x10*\x12\x13\n\x0f\x46LOWSTATE_LEVEL\x10+\x12\x15\n\x11\x42URST_CAPTURE_NUM\x10,\x12\x15\n\x11\x43\x41\x43HE_CAPTURE_NUM\x10-\x12\x13\n\x0fMETERING_ENABLE\x10.\x12\x16\n\x12\x42URST_CAPTURE_TIME\x10\x33\x12\x18\n\x14\x43\x41\x43HE_CAPTURE_ENABLE\x10\x34\x12\x0e\n\nZOOM_SCALE\x10\x35\x12\x10\n\x0cMAX_REC_TIME\x10\x36\x12\x1a\n\x16\x46LOWSTATE_LEVEL_BY_CV5\x10\x37\x12\x19\n\x15STARLAPSE_EXPORT_TYPE\x10\x38\x12\x1d\n\x19VIDEO_FLOWSTATE_BASE_TYPE\x10:\x12\x0f\n\x0b\x44OUBLE_ZOOM\x10;\x12\x16\n\x12PANO_EXPOSURE_MODE\x10=\x12\x15\n\x11VIDEO_SELFIE_MODE\x10>\x12\x15\n\x11HDR_SWITCH_STATUS\x10?\x12\x1c\n\x18\x46LOWSTATE_HORIZON_ENABLE\x10\x46\x12!\n\x1dPHOTO_GRAPHY_OPTIONS_TYPE_NUM\x10GB\x08\xa2\x02\x05INSPBP\x00P\x01P\x02P\x03P\x04\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "photography_options_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"\242\002\005INSPB"
    _globals["_PHOTOGRAPHYOPTIONTYPE"]._serialized_start = 5756
    _globals["_PHOTOGRAPHYOPTIONTYPE"]._serialized_end = 7110
    _globals["_PHOTOGRAPHYOPTIONS"]._serialized_start = 120
    _globals["_PHOTOGRAPHYOPTIONS"]._serialized_end = 5753
    _globals["_PHOTOGRAPHYOPTIONS_EXPOSUREPROG"]._serialized_start = 2819
    _globals["_PHOTOGRAPHYOPTIONS_EXPOSUREPROG"]._serialized_end = 3075
    _globals["_PHOTOGRAPHYOPTIONS_EXPOSUREPROG_PROGMODE"]._serialized_start = 2998
    _globals["_PHOTOGRAPHYOPTIONS_EXPOSUREPROG_PROGMODE"]._serialized_end = 3075
    _globals["_PHOTOGRAPHYOPTIONS_EXPOSUREMANUAL"]._serialized_start = 3078
    _globals["_PHOTOGRAPHYOPTIONS_EXPOSUREMANUAL"]._serialized_end = 3561
    _globals["_PHOTOGRAPHYOPTIONS_EXPOSUREMANUAL_RELATEMODE"]._serialized_start = 3470
    _globals["_PHOTOGRAPHYOPTIONS_EXPOSUREMANUAL_RELATEMODE"]._serialized_end = 3561
    _globals["_PHOTOGRAPHYOPTIONS_EXPOSUREPARAMETER"]._serialized_start = 3563
    _globals["_PHOTOGRAPHYOPTIONS_EXPOSUREPARAMETER"]._serialized_end = 3670
    _globals["_PHOTOGRAPHYOPTIONS_LONGEXPOSUREMANUAL"]._serialized_start = 3672
    _globals["_PHOTOGRAPHYOPTIONS_LONGEXPOSUREMANUAL"]._serialized_end = 3728
    _globals["_PHOTOGRAPHYOPTIONS_RESRECLIMIT"]._serialized_start = 3730
    _globals["_PHOTOGRAPHYOPTIONS_RESRECLIMIT"]._serialized_end = 3818
    _globals["_PHOTOGRAPHYOPTIONS_EXPOSUREMODE"]._serialized_start = 3820
    _globals["_PHOTOGRAPHYOPTIONS_EXPOSUREMODE"]._serialized_end = 3896
    _globals["_PHOTOGRAPHYOPTIONS_AEMETERMODE"]._serialized_start = 3898
    _globals["_PHOTOGRAPHYOPTIONS_AEMETERMODE"]._serialized_end = 3963
    _globals["_PHOTOGRAPHYOPTIONS_WHITEBALANCE"]._serialized_start = 3965
    _globals["_PHOTOGRAPHYOPTIONS_WHITEBALANCE"]._serialized_end = 4062
    _globals["_PHOTOGRAPHYOPTIONS_PREVIEW_SPORT_LEVEL"]._serialized_start = 4064
    _globals["_PHOTOGRAPHYOPTIONS_PREVIEW_SPORT_LEVEL"]._serialized_end = 4159
    _globals["_PHOTOGRAPHYOPTIONS_COLOR_MODE"]._serialized_start = 4161
    _globals["_PHOTOGRAPHYOPTIONS_COLOR_MODE"]._serialized_end = 4258
    _globals["_PHOTOGRAPHYOPTIONS_FLOW_STATE_LEVEL"]._serialized_start = 4261
    _globals["_PHOTOGRAPHYOPTIONS_FLOW_STATE_LEVEL"]._serialized_end = 4391
    _globals["_PHOTOGRAPHYOPTIONS_FLOW_STATE_LEVEL_BY_CV5"]._serialized_start = 4394
    _globals["_PHOTOGRAPHYOPTIONS_FLOW_STATE_LEVEL_BY_CV5"]._serialized_end = 4551
    _globals["_PHOTOGRAPHYOPTIONS_STARLAPSE_EXPORT_TYPE"]._serialized_start = 4553
    _globals["_PHOTOGRAPHYOPTIONS_STARLAPSE_EXPORT_TYPE"]._serialized_end = 4643
    _globals["_PHOTOGRAPHYOPTIONS_PANO_EXPOSURE_MODE"]._serialized_start = 4645
    _globals["_PHOTOGRAPHYOPTIONS_PANO_EXPOSURE_MODE"]._serialized_end = 4756
    _globals["_PHOTOGRAPHYOPTIONS_VIDEO_SELFIE_MODE"]._serialized_start = 4758
    _globals["_PHOTOGRAPHYOPTIONS_VIDEO_SELFIE_MODE"]._serialized_end = 4821
    _globals["_PHOTOGRAPHYOPTIONS_FLOWSTATEHORIZONTYPE"]._serialized_start = 4823
    _globals["_PHOTOGRAPHYOPTIONS_FLOWSTATEHORIZONTYPE"]._serialized_end = 4937
    _globals["_PHOTOGRAPHYOPTIONS_SHUTTERSPEED"]._serialized_start = 4940
    _globals["_PHOTOGRAPHYOPTIONS_SHUTTERSPEED"]._serialized_end = 5753
# @@protoc_insertion_point(module_scope)
