# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: camera_posture.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x14\x63\x61mera_posture.proto\x12\x11insta360.messages"\xbe\x02\n\x1fNotificationCameraPostureUpdate\x12\\\n\x0e\x63\x61mera_posture\x18\x01 \x01(\x0e\x32\x44.insta360.messages.NotificationCameraPostureUpdate.CameraPostureType"\xbc\x01\n\x11\x43\x61meraPostureType\x12\x1b\n\x17\x43\x41MERA_POSTURE_ROTATE_0\x10\x00\x12\x1c\n\x18\x43\x41MERA_POSTURE_ROTATE_90\x10\x01\x12\x1d\n\x19\x43\x41MERA_POSTURE_ROTATE_180\x10\x02\x12\x1d\n\x19\x43\x41MERA_POSTURE_ROTATE_270\x10\x03\x12\x15\n\x11\x43\x41MERA_POSTURE_UP\x10\x04\x12\x17\n\x13\x43\x41MERA_POSTURE_DOWN\x10\x05\x42\x08\xa2\x02\x05INSPBb\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "camera_posture_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"\242\002\005INSPB"
    _globals["_NOTIFICATIONCAMERAPOSTUREUPDATE"]._serialized_start = 44
    _globals["_NOTIFICATIONCAMERAPOSTUREUPDATE"]._serialized_end = 362
    _globals[
        "_NOTIFICATIONCAMERAPOSTUREUPDATE_CAMERAPOSTURETYPE"
    ]._serialized_start = 174
    _globals["_NOTIFICATIONCAMERAPOSTUREUPDATE_CAMERAPOSTURETYPE"]._serialized_end = 362
# @@protoc_insertion_point(module_scope)
