# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: fileinfo_list.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x13\x66ileinfo_list.proto\x12\x11insta360.messages"/\n\x08\x46ileInfo\x12\x11\n\tfile_path\x18\x01 \x01(\t\x12\x10\n\x08metadata\x18\x02 \x01(\x0c"?\n\rFileInfo_List\x12.\n\tfile_info\x18\x01 \x03(\x0b\x32\x1b.insta360.messages.FileInfoB\x08\xa2\x02\x05INSPBb\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "fileinfo_list_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"\242\002\005INSPB"
    _globals["_FILEINFO"]._serialized_start = 42
    _globals["_FILEINFO"]._serialized_end = 89
    _globals["_FILEINFO_LIST"]._serialized_start = 91
    _globals["_FILEINFO_LIST"]._serialized_end = 154
# @@protoc_insertion_point(module_scope)
