# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: start_timelapse.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from timelapse_pb2 import *
from extra_info_pb2 import *

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x15start_timelapse.proto\x12\x11insta360.messages\x1a\x0ftimelapse.proto\x1a\x10\x65xtra_info.proto"z\n\x0eStartTimelapse\x12.\n\x04mode\x18\x01 \x01(\x0e\x32 .insta360.messages.TimelapseMode\x12\x38\n\x0e\x65xtra_metadata\x18\x02 \x01(\x0b\x32 .insta360.messages.ExtraMetadata"\x14\n\x12StartTimelapseRespB\x08\xa2\x02\x05INSPBP\x00P\x01\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "start_timelapse_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"\242\002\005INSPB"
    _globals["_STARTTIMELAPSE"]._serialized_start = 79
    _globals["_STARTTIMELAPSE"]._serialized_end = 201
    _globals["_STARTTIMELAPSERESP"]._serialized_start = 203
    _globals["_STARTTIMELAPSERESP"]._serialized_end = 223
# @@protoc_insertion_point(module_scope)
