# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: chargebox.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from battery_pb2 import *

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x0f\x63hargebox.proto\x12\x11insta360.messages\x1a\rbattery.proto"\xe9\x05\n\x18\x43hargeboxConnectedStatus\x12\x65\n\x19\x63hargebox_connected_state\x18\x01 \x01(\x0e\x32\x42.insta360.messages.ChargeboxConnectedStatus.ChargeboxConnectedType\x12\x44\n\x1a\x63hargingbox_battery_status\x18\x02 \x01(\x0b\x32 .insta360.messages.BatteryStatus\x12^\n\x16\x63hargebox_onoff_status\x18\x03 \x01(\x0e\x32>.insta360.messages.ChargeboxConnectedStatus.ChargeboxOnOffInfo\x12n\n\x1d\x63hargebox_usb_connected_state\x18\x04 \x01(\x0e\x32G.insta360.messages.ChargeboxConnectedStatus.ChargeboxUsbBtConnectedType\x12m\n\x1c\x63hargebox_bt_connected_state\x18\x05 \x01(\x0e\x32G.insta360.messages.ChargeboxConnectedStatus.ChargeboxUsbBtConnectedType"9\n\x16\x43hargeboxConnectedType\x12\x10\n\x0c\x64isconnected\x10\x00\x12\r\n\tconnected\x10\x01"-\n\x12\x43hargeboxOnOffInfo\x12\x0b\n\x07offline\x10\x00\x12\n\n\x06online\x10\x01"w\n\x1b\x43hargeboxUsbBtConnectedType\x12\x1b\n\x17usb_bt_status_undefined\x10\x00\x12\x1e\n\x1ausb_bt_status_disconnected\x10\x01\x12\x1b\n\x17usb_bt_status_connected\x10\x02\x42\x08\xa2\x02\x05INSPBP\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "chargebox_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"\242\002\005INSPB"
    _globals["_CHARGEBOXCONNECTEDSTATUS"]._serialized_start = 54
    _globals["_CHARGEBOXCONNECTEDSTATUS"]._serialized_end = 799
    _globals["_CHARGEBOXCONNECTEDSTATUS_CHARGEBOXCONNECTEDTYPE"]._serialized_start = 574
    _globals["_CHARGEBOXCONNECTEDSTATUS_CHARGEBOXCONNECTEDTYPE"]._serialized_end = 631
    _globals["_CHARGEBOXCONNECTEDSTATUS_CHARGEBOXONOFFINFO"]._serialized_start = 633
    _globals["_CHARGEBOXCONNECTEDSTATUS_CHARGEBOXONOFFINFO"]._serialized_end = 678
    _globals[
        "_CHARGEBOXCONNECTEDSTATUS_CHARGEBOXUSBBTCONNECTEDTYPE"
    ]._serialized_start = 680
    _globals[
        "_CHARGEBOXCONNECTEDSTATUS_CHARGEBOXUSBBTCONNECTEDTYPE"
    ]._serialized_end = 799
# @@protoc_insertion_point(module_scope)
