# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: get_gyro.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x0eget_gyro.proto\x12\x11insta360.messages"\x18\n\x07GetGyro\x12\r\n\x05\x63ount\x18\x01 \x01(\r"\x1d\n\x0bGetGyroResp\x12\x0e\n\x06gyroes\x18\x01 \x01(\x0c\x42\x08\xa2\x02\x05INSPBb\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "get_gyro_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"\242\002\005INSPB"
    _globals["_GETGYRO"]._serialized_start = 37
    _globals["_GETGYRO"]._serialized_end = 61
    _globals["_GETGYRORESP"]._serialized_start = 63
    _globals["_GETGYRORESP"]._serialized_end = 92
# @@protoc_insertion_point(module_scope)
