# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: get_sync_capture_mode.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from sync_capture_mode_pb2 import *

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x1bget_sync_capture_mode.proto\x12\x11insta360.messages\x1a\x17sync_capture_mode.proto"\x14\n\x12GetSyncCaptureMode"R\n\x16GetSyncCaptureModeResp\x12\x38\n\x0c\x63\x61pture_mode\x18\x01 \x01(\x0e\x32".insta360.messages.SyncCaptureModeB\x08\xa2\x02\x05INSPBP\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(
    DESCRIPTOR, "get_sync_capture_mode_pb2", _globals
)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"\242\002\005INSPB"
    _globals["_GETSYNCCAPTUREMODE"]._serialized_start = 75
    _globals["_GETSYNCCAPTUREMODE"]._serialized_end = 95
    _globals["_GETSYNCCAPTUREMODERESP"]._serialized_start = 97
    _globals["_GETSYNCCAPTUREMODERESP"]._serialized_end = 179
# @@protoc_insertion_point(module_scope)
