# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: get_whiteblance_status.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x1cget_whiteblance_status.proto"\x9b\x01\n\x14GetWhiteblanceStatus\x12\x35\n\x05state\x18\x01 \x01(\x0e\x32&.GetWhiteblanceStatus.WhiteblanceState\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\x0c">\n\x10WhiteblanceState\x12\x12\n\x0e\x42LANCE_UNKNOWN\x10\x00\x12\x16\n\x12\x42LANCE_EXE_SUCCESS\x10\x01\x42\x08\xa2\x02\x05INSPBb\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(
    DESCRIPTOR, "get_whiteblance_status_pb2", _globals
)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"\242\002\005INSPB"
    _globals["_GETWHITEBLANCESTATUS"]._serialized_start = 33
    _globals["_GETWHITEBLANCESTATUS"]._serialized_end = 188
    _globals["_GETWHITEBLANCESTATUS_WHITEBLANCESTATE"]._serialized_start = 126
    _globals["_GETWHITEBLANCESTATUS_WHITEBLANCESTATE"]._serialized_end = 188
# @@protoc_insertion_point(module_scope)
