# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: track.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from file_type_pb2 import *

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x0btrack.proto\x12\x11insta360.messages\x1a\x0f\x66ile_type.proto"\xa7\x02\n\nTrackState\x12\x33\n\x0btrack_state\x18\x01 \x01(\x0e\x32\x1e.insta360.messages.TrackStatus\x12\x31\n\tlog_state\x18\x02 \x01(\x0e\x32\x1e.insta360.messages.TrackStatus\x12\x38\n\rexport_status\x18\x03 \x01(\x0e\x32!.insta360.messages.TransferStatus\x12:\n\x0f\x64ownload_status\x18\x04 \x01(\x0e\x32!.insta360.messages.TransferStatus\x12.\n\tfile_type\x18\x05 \x01(\x0e\x32\x1b.insta360.messages.FileType\x12\x0b\n\x03uri\x18\x06 \x01(\t*`\n\x0bTrackStatus\x12\x0e\n\nTrack_IDLE\x10\x00\x12\x0e\n\nTrack_Sync\x10\x01\x12\x0f\n\x0bTrack_Start\x10\x02\x12\r\n\tTrack_End\x10\x03\x12\x11\n\rTrack_Timeout\x10\x04*L\n\x0eTransferStatus\x12\x13\n\x0fTransferUnknown\x10\x00\x12\x13\n\x0fTransferSuccess\x10\x01\x12\x10\n\x0cTransferFail\x10\x02\x42\x08\xa2\x02\x05INSPBP\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "track_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"\242\002\005INSPB"
    _globals["_TRACKSTATUS"]._serialized_start = 349
    _globals["_TRACKSTATUS"]._serialized_end = 445
    _globals["_TRANSFERSTATUS"]._serialized_start = 447
    _globals["_TRANSFERSTATUS"]._serialized_end = 523
    _globals["_TRACKSTATE"]._serialized_start = 52
    _globals["_TRACKSTATE"]._serialized_end = 347
# @@protoc_insertion_point(module_scope)
