# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: button_press.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x12\x62utton_press.proto\x12\x11insta360.messages"\xf1\x04\n\x12\x42uttonPressOptions\x12\x31\n\x05\x63lick\x18\x01 \x01(\x0e\x32".insta360.messages.ButtonPressMode\x12\x38\n\x0c\x64ouble_click\x18\x02 \x01(\x0e\x32".insta360.messages.ButtonPressMode\x12\x38\n\x0ctriple_click\x18\x03 \x01(\x0e\x32".insta360.messages.ButtonPressMode\x12\x36\n\nlong_press\x18\x04 \x01(\x0e\x32".insta360.messages.ButtonPressMode\x12\x37\n\x0bshort_press\x18\x05 \x01(\x0e\x32".insta360.messages.ButtonPressMode\x12:\n\x0eshutdown_click\x18\x06 \x01(\x0e\x32".insta360.messages.ButtonPressMode\x12\x41\n\x15shutdown_double_click\x18\x07 \x01(\x0e\x32".insta360.messages.ButtonPressMode\x12\x41\n\x15shutdown_triple_click\x18\x08 \x01(\x0e\x32".insta360.messages.ButtonPressMode\x12?\n\x13shutdown_long_press\x18\t \x01(\x0e\x32".insta360.messages.ButtonPressMode\x12@\n\x14shutdown_short_press\x18\n \x01(\x0e\x32".insta360.messages.ButtonPressMode"\xff\x03\n\x13\x42uttonFollowOptions\x12\x32\n\x05\x63lick\x18\x01 \x01(\x0e\x32#.insta360.messages.ButtonFollowMode\x12\x39\n\x0c\x64ouble_click\x18\x02 \x01(\x0e\x32#.insta360.messages.ButtonFollowMode\x12\x39\n\x0ctriple_click\x18\x03 \x01(\x0e\x32#.insta360.messages.ButtonFollowMode\x12\x37\n\nlong_press\x18\x04 \x01(\x0e\x32#.insta360.messages.ButtonFollowMode\x12;\n\x0eshutdown_click\x18\x05 \x01(\x0e\x32#.insta360.messages.ButtonFollowMode\x12\x42\n\x15shutdown_double_click\x18\x06 \x01(\x0e\x32#.insta360.messages.ButtonFollowMode\x12\x42\n\x15shutdown_triple_click\x18\x07 \x01(\x0e\x32#.insta360.messages.ButtonFollowMode\x12@\n\x13shutdown_long_press\x18\x08 \x01(\x0e\x32#.insta360.messages.ButtonFollowMode*\xd3\x04\n\x0f\x42uttonPressMode\x12\x11\n\rDO_NOT_CHANGE\x10\x00\x12\x0e\n\nDO_NOTHING\x10\x01\x12\r\n\tSHUT_DOWN\x10\x02\x12\x10\n\x0cTAKE_PICTURE\x10\x03\x12\x0b\n\x07\x43\x41PTURE\x10\x04\x12\r\n\tSELFTIMER\x10\x05\x12\r\n\tTIMELAPSE\x10\x06\x12\x13\n\x0fHIGH_FRAME_RATE\x10\x07\x12\x1a\n\x16\x41\x43TION_TIMELAPSE_VIDEO\x10\x08\x12\x15\n\x11INTERVAL_SHOOTING\x10\t\x12\x19\n\x15\x41\x43TION_INTERVAL_VIDEO\x10\n\x12\x12\n\x0eTAKE_HDR_IMAGE\x10\x0b\x12\x1b\n\x17\x41\x43TION_STATIC_TIMELAPSE\x10\x0c\x12\x19\n\x15\x41\x43TION_CALIBRATE_GYRO\x10\r\x12\x16\n\x12\x41\x43TION_HDR_CAPTURE\x10\x0e\x12\x14\n\x10\x41\x43TION_TIMESHIFT\x10\x0f\x12\x14\n\x10TAKE_BURST_IMAGE\x10\x10\x12\x18\n\x14TAKE_AEB_NIGHT_IMAGE\x10\x11\x12\x11\n\rSUPER_CAPTURE\x10\x12\x12\x18\n\x14\x41\x43TION_LOOPRECORDING\x10\x13\x12\x18\n\x14TAKE_STARLAPSE_IMAGE\x10\x14\x12\x11\n\rFPV_RECORDING\x10\x15\x12\x13\n\x0fMOVIE_RECORDING\x10\x16\x12\x19\n\x15SLOW_MOTION_RECORDING\x10\x17\x12\x14\n\x10SELFIE_RECORDING\x10\x18\x12\x14\n\x10\x46OLLOW_CHARGEBOX\x10\x19\x12\x0e\n\nPURE_VIDEO\x10\x1a*j\n\x10\x42uttonFollowMode\x12\x12\n\x0e\x46OLLOW_UNKNOWN\x10\x00\x12\x0f\n\x0b\x46OLLOW_FULL\x10\x01\x12\x0f\n\x0b\x46OLLOW_PARM\x10\x02\x12\x0f\n\x0b\x46OLLOW_MODE\x10\x03\x12\x0f\n\x0b\x46OLLOW_NONE\x10\x04*\xce\x01\n\x0f\x42uttonPressType\x12\t\n\x05\x43LICK\x10\x00\x12\x10\n\x0c\x44OUBLE_CLICK\x10\x01\x12\x10\n\x0cTRIPLE_CLICK\x10\x02\x12\x0e\n\nLONG_PRESS\x10\x03\x12\x12\n\x0eSHUTDOWN_CLICK\x10\x04\x12\x19\n\x15SHUTDOWN_DOUBLE_CLICK\x10\x05\x12\x19\n\x15SHUTDOWN_TRIPLE_CLICK\x10\x06\x12\x17\n\x13SHUTDOWN_LONG_PRESS\x10\x07\x12\x19\n\x15\x42UTTON_PRESS_TYPE_NUM\x10\x08\x42\x08\xa2\x02\x05INSPBb\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "button_press_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"\242\002\005INSPB"
    _globals["_BUTTONPRESSMODE"]._serialized_start = 1184
    _globals["_BUTTONPRESSMODE"]._serialized_end = 1779
    _globals["_BUTTONFOLLOWMODE"]._serialized_start = 1781
    _globals["_BUTTONFOLLOWMODE"]._serialized_end = 1887
    _globals["_BUTTONPRESSTYPE"]._serialized_start = 1890
    _globals["_BUTTONPRESSTYPE"]._serialized_end = 2096
    _globals["_BUTTONPRESSOPTIONS"]._serialized_start = 42
    _globals["_BUTTONPRESSOPTIONS"]._serialized_end = 667
    _globals["_BUTTONFOLLOWOPTIONS"]._serialized_start = 670
    _globals["_BUTTONFOLLOWOPTIONS"]._serialized_end = 1181
# @@protoc_insertion_point(module_scope)
