# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: camera_live_result.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from camera_live_info_pb2 import *

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x18\x63\x61mera_live_result.proto\x12\x11insta360.messages\x1a\x16\x63\x61mera_live_info.proto"\\\n\x10\x43\x61meraLiveResult\x12\x12\n\nerror_code\x18\x01 \x01(\r\x12\x34\n\tlive_info\x18\x02 \x01(\x0b\x32!.insta360.messages.CameraLiveInfoB\x08\xa2\x02\x05INSPBP\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "camera_live_result_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"\242\002\005INSPB"
    _globals["_CAMERALIVERESULT"]._serialized_start = 71
    _globals["_CAMERALIVERESULT"]._serialized_end = 163
# @@protoc_insertion_point(module_scope)
