# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bt_central.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from bluetooth_pb2 import *

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x10\x62t_central.proto\x12\x11insta360.messages\x1a\x0f\x62luetooth.proto"P\n\x10ScanBTPeripheral\x12<\n\x0fperipheral_type\x18\x01 \x01(\x0e\x32#.insta360.messages.BTPeripheralType"L\n\x15\x43onnectToBTPeripheral\x12\x33\n\nperipheral\x18\x01 \x01(\x0b\x32\x1f.insta360.messages.BTPeripheral"M\n\x16\x44isconnectBTPeripheral\x12\x33\n\nperipheral\x18\x01 \x01(\x0b\x32\x1f.insta360.messages.BTPeripheral"X\n\x18GetConnectedBTPeripheral\x12<\n\x0fperipheral_type\x18\x01 \x01(\x0e\x32#.insta360.messages.BTPeripheralType"T\n\x1cGetConnectedBTPeripheralResp\x12\x34\n\x0bperipherals\x18\x01 \x03(\x0b\x32\x1f.insta360.messages.BTPeripheralB\x08\xa2\x02\x05INSPBP\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "bt_central_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"\242\002\005INSPB"
    _globals["_SCANBTPERIPHERAL"]._serialized_start = 56
    _globals["_SCANBTPERIPHERAL"]._serialized_end = 136
    _globals["_CONNECTTOBTPERIPHERAL"]._serialized_start = 138
    _globals["_CONNECTTOBTPERIPHERAL"]._serialized_end = 214
    _globals["_DISCONNECTBTPERIPHERAL"]._serialized_start = 216
    _globals["_DISCONNECTBTPERIPHERAL"]._serialized_end = 293
    _globals["_GETCONNECTEDBTPERIPHERAL"]._serialized_start = 295
    _globals["_GETCONNECTEDBTPERIPHERAL"]._serialized_end = 383
    _globals["_GETCONNECTEDBTPERIPHERALRESP"]._serialized_start = 385
    _globals["_GETCONNECTEDBTPERIPHERALRESP"]._serialized_end = 469
# @@protoc_insertion_point(module_scope)
