# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: capture_stopped.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from video_pb2 import *

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x15\x63\x61pture_stopped.proto\x12\x11insta360.messages\x1a\x0bvideo.proto"\xa9\x03\n\x1aNotificationCaptureStopped\x12I\n\x08\x65rr_code\x18\x01 \x01(\x0e\x32\x37.insta360.messages.NotificationCaptureStopped.ErrorCode\x12\'\n\x05video\x18\x02 \x01(\x0b\x32\x18.insta360.messages.Video"\x96\x02\n\tErrorCode\x12\x13\n\x0fOVER_TIME_LIMIT\x10\x00\x12\x10\n\x0cSTORAGE_FULL\x10\x01\x12\x13\n\x0fOTHER_SITUATION\x10\x02\x12\x1a\n\x16OVER_FILE_NUMBER_LIMIT\x10\x03\x12\x12\n\x0eLOW_CARD_SPEED\x10\x04\x12\x16\n\x12MUXER_STREAM_ERROR\x10\x05\x12\x0f\n\x0b\x44ROP_FRAMES\x10\x06\x12\x0f\n\x0bLOW_BATTERY\x10\x07\x12\x10\n\x0cSTORAGEFRGMT\x10\x08\x12\r\n\tHIGH_TEMP\x10\t\x12\x13\n\x0fLOW_POWER_START\x10\n\x12\x18\n\x14STORAGE_RUNOUT_START\x10\x0b\x12\x13\n\x0fHIGH_TEMP_START\x10\x0c\x42\x08\xa2\x02\x05INSPBP\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "capture_stopped_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"\242\002\005INSPB"
    _globals["_NOTIFICATIONCAPTURESTOPPED"]._serialized_start = 58
    _globals["_NOTIFICATIONCAPTURESTOPPED"]._serialized_end = 483
    _globals["_NOTIFICATIONCAPTURESTOPPED_ERRORCODE"]._serialized_start = 205
    _globals["_NOTIFICATIONCAPTURESTOPPED_ERRORCODE"]._serialized_end = 483
# @@protoc_insertion_point(module_scope)
