# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cloud_storage.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x13\x63loud_storage.proto\x12\x11insta360.messages"\x92\x02\n\x18\x43loudStorageUploadParams\x12T\n\rupload_status\x18\x01 \x01(\x0e\x32=.insta360.messages.CloudStorageUploadParams.CloudUploadStatus\x12\x11\n\ttotal_num\x18\x02 \x01(\r\x12\x13\n\x0b\x63urrent_num\x18\x03 \x01(\r\x12\x1b\n\x13is_auto_upload_flag\x18\x04 \x01(\r\x12#\n\x1bis_delete_after_upload_flag\x18\x05 \x01(\r"6\n\x11\x43loudUploadStatus\x12\x08\n\x04NONE\x10\x00\x12\r\n\tUPLOADING\x10\x01\x12\x08\n\x04IDLE\x10\x02"\xe7\x02\n\x16\x43loudStorageBindParams\x12N\n\x0b\x62ind_status\x18\x01 \x01(\x0e\x32\x39.insta360.messages.CloudStorageBindParams.CloudBindStatus\x12\x11\n\tuser_name\x18\x02 \x01(\t\x12\r\n\x05token\x18\x03 \x01(\t\x12\x0c\n\x04uuid\x18\x04 \x01(\t\x12\x10\n\x08\x65ndpoint\x18\x05 \x01(\t\x12\x12\n\nserial_num\x18\x06 \x01(\t\x12\x13\n\x0b\x64\x65vice_type\x18\x07 \x01(\t\x12\x18\n\x10is_token_timeout\x18\x08 \x01(\r\x12\x12\n\ndomain_url\x18\t \x01(\t\x12\x16\n\x0etotal_capacity\x18\n \x01(\x01\x12\x15\n\rused_capacity\x18\x0b \x01(\x01"5\n\x0f\x43loudBindStatus\x12\x08\n\x04NONE\x10\x00\x12\t\n\x05\x42OUND\x10\x01\x12\r\n\tNOT_BOUND\x10\x02"\x98\x01\n\x12\x43loudStorageStatus\x12>\n\x0b\x62ind_params\x18\x01 \x01(\x0b\x32).insta360.messages.CloudStorageBindParams\x12\x42\n\rupload_params\x18\x02 \x01(\x0b\x32+.insta360.messages.CloudStorageUploadParamsB\x08\xa2\x02\x05INSPBb\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "cloud_storage_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"\242\002\005INSPB"
    _globals["_CLOUDSTORAGEUPLOADPARAMS"]._serialized_start = 43
    _globals["_CLOUDSTORAGEUPLOADPARAMS"]._serialized_end = 317
    _globals["_CLOUDSTORAGEUPLOADPARAMS_CLOUDUPLOADSTATUS"]._serialized_start = 263
    _globals["_CLOUDSTORAGEUPLOADPARAMS_CLOUDUPLOADSTATUS"]._serialized_end = 317
    _globals["_CLOUDSTORAGEBINDPARAMS"]._serialized_start = 320
    _globals["_CLOUDSTORAGEBINDPARAMS"]._serialized_end = 679
    _globals["_CLOUDSTORAGEBINDPARAMS_CLOUDBINDSTATUS"]._serialized_start = 626
    _globals["_CLOUDSTORAGEBINDPARAMS_CLOUDBINDSTATUS"]._serialized_end = 679
    _globals["_CLOUDSTORAGESTATUS"]._serialized_start = 682
    _globals["_CLOUDSTORAGESTATUS"]._serialized_end = 834
# @@protoc_insertion_point(module_scope)
