# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: temperature.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x11temperature.proto\x12\x11insta360.messages"X\n\tTempState\x12\x37\n\ntemp_state\x18\x01 \x01(\x0e\x32#.insta360.messages.TemperatureState\x12\x12\n\ntemp_value\x18\x02 \x01(\x05*h\n\x10TemperatureState\x12\x0c\n\x08TEMP_LOW\x10\x00\x12\x0e\n\nTEMP_ALERT\x10\x01\x12\x0f\n\x0bTEMP_MIDDLE\x10\x02\x12\r\n\tTEMP_HIGH\x10\x03\x12\x16\n\x12TEMP_HIGH_SHUTDOWN\x10\x04\x42\x08\xa2\x02\x05INSPBb\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "temperature_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"\242\002\005INSPB"
    _globals["_TEMPERATURESTATE"]._serialized_start = 130
    _globals["_TEMPERATURESTATE"]._serialized_end = 234
    _globals["_TEMPSTATE"]._serialized_start = 40
    _globals["_TEMPSTATE"]._serialized_end = 128
# @@protoc_insertion_point(module_scope)
