# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: capture_state.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x13\x63\x61pture_state.proto\x12\x11insta360.messages*\x85\x05\n\x12\x43\x61meraCaptureState\x12\x0f\n\x0bNOT_CAPTURE\x10\x00\x12\x12\n\x0eNORMAL_CAPTURE\x10\x01\x12\x15\n\x11TIMELAPSE_CAPTURE\x10\x02\x12\x1d\n\x19INTERVAL_SHOOTING_CAPTURE\x10\x03\x12\x13\n\x0fSINGLE_SHOOTING\x10\x04\x12\x10\n\x0cHDR_SHOOTING\x10\x05\x12\x17\n\x13SELF_TIMER_SHOOTING\x10\x06\x12\x17\n\x13\x42ULLET_TIME_CAPTURE\x10\x07\x12\x16\n\x12SETTINGS_NEW_VALUE\x10\x08\x12\x0f\n\x0bHDR_CAPTURE\x10\t\x12\x12\n\x0e\x42URST_SHOOTING\x10\n\x12\x1d\n\x19STATIC_TIMELAPSE_SHOOTING\x10\x0b\x12\x1a\n\x16INTERVAL_VIDEO_CAPTURE\x10\x0c\x12\x15\n\x11TIMESHIFT_CAPTURE\x10\r\x12\x16\n\x12\x41\x45\x42_NIGHT_SHOOTING\x10\x0e\x12\x1e\n\x1aSINGLE_POWER_PANO_SHOOTING\x10\x0f\x12\x1b\n\x17HDR_POWER_PANO_SHOOTING\x10\x10\x12\x18\n\x14SUPER_NORMAL_CAPTURE\x10\x11\x12\x1a\n\x16LOOP_RECORDING_CAPTURE\x10\x12\x12\x16\n\x12STARLAPSE_SHOOTING\x10\x13\x12\x19\n\x15\x46PV_RECORDING_CAPTURE\x10\x14\x12\x1b\n\x17MOVIE_RECORDING_CAPTURE\x10\x15\x12\x17\n\x13SLOW_MOTION_CAPTURE\x10\x16\x12\x1c\n\x18SELFIE_RECORDING_CAPTURE\x10\x17\x12\x1a\n\x16PURE_RECORDING_CAPTURE\x10\x18*\x99\x01\n\x15\x43\x61meraCaptureSubState\x12\x12\n\x0eSUB_STATE_NULL\x10\x00\x12\x13\n\x0fSUB_STATE_PAUSE\x10\x01\x12\x19\n\x15SUB_STATE_RECORD_SAVE\x10\x02\x12\x18\n\x14SUB_STATE_PHOTO_SAVE\x10\x03\x12"\n\x1eSUB_STATE_STARTLAPSE_SYNTHESIS\x10\x04\x42\x08\xa2\x02\x05INSPBb\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "capture_state_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"\242\002\005INSPB"
    _globals["_CAMERACAPTURESTATE"]._serialized_start = 43
    _globals["_CAMERACAPTURESTATE"]._serialized_end = 688
    _globals["_CAMERACAPTURESUBSTATE"]._serialized_start = 691
    _globals["_CAMERACAPTURESUBSTATE"]._serialized_end = 844
# @@protoc_insertion_point(module_scope)
