# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: get_current_button_status.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from capture_state_pb2 import *

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x1fget_current_button_status.proto\x12\x11insta360.messages\x1a\x13\x63\x61pture_state.proto"\xd7\x02\n\x0c\x42uttonStatus\x12:\n\x05state\x18\x01 \x01(\x0e\x32+.insta360.messages.ButtonStatus.ButtonState"\x8a\x02\n\x0b\x42uttonState\x12\x12\n\x0e\x42UTTON_UNKNOWN\x10\x00\x12\x15\n\x11\x42UTTON_POWER_DONW\x10\x01\x12\x15\n\x11\x42UTTON_SHOOT_DONW\x10\x02\x12\x14\n\x10\x42UTTON_BOTH_DONW\x10\x03\x12\x14\n\x10\x42UTTON_NONE_DONW\x10\x04\x12\x19\n\x15\x42UTTON_POWER_PRESS_1S\x10\x05\x12\x19\n\x15\x42UTTON_POWER_PRESS_2S\x10\x06\x12\x1d\n\x19\x42UTTON_POWER_DOUBLE_CLICK\x10\x07\x12\x19\n\x15\x42UTTON_SHOOT_PRESS_1S\x10\x08\x12\x1d\n\x19\x42UTTON_SHOOT_DOUBLE_CLICK\x10\t"M\n\x1aGetCurrentButtonStatusResp\x12/\n\x06status\x18\x01 \x01(\x0b\x32\x1f.insta360.messages.ButtonStatusB\x08\xa2\x02\x05INSPBP\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(
    DESCRIPTOR, "get_current_button_status_pb2", _globals
)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"\242\002\005INSPB"
    _globals["_BUTTONSTATUS"]._serialized_start = 76
    _globals["_BUTTONSTATUS"]._serialized_end = 419
    _globals["_BUTTONSTATUS_BUTTONSTATE"]._serialized_start = 153
    _globals["_BUTTONSTATUS_BUTTONSTATE"]._serialized_end = 419
    _globals["_GETCURRENTBUTTONSTATUSRESP"]._serialized_start = 421
    _globals["_GETCURRENTBUTTONSTATUSRESP"]._serialized_end = 498
# @@protoc_insertion_point(module_scope)
