# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: camera_live_info.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from video_pb2 import *

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x16\x63\x61mera_live_info.proto\x12\x11insta360.messages\x1a\x0bvideo.proto"\xa3\x01\n\x10\x43\x61meraLiveParams\x12\x34\n\tlive_mode\x18\x01 \x01(\x0e\x32!.insta360.messages.CameraLiveMode\x12\x11\n\tlive_addr\x18\x02 \x01(\t\x12\x10\n\x08res_with\x18\x03 \x01(\r\x12\x12\n\nres_height\x18\x04 \x01(\r\x12\x0f\n\x07res_fps\x18\x05 \x01(\r\x12\x0f\n\x07\x62itrate\x18\x06 \x01(\r"\x89\x01\n\x0e\x43\x61meraLiveInfo\x12\x38\n\x0blive_status\x18\x01 \x01(\x0e\x32#.insta360.messages.CameraLiveStatus\x12=\n\x10live_push_params\x18\x02 \x01(\x0b\x32#.insta360.messages.CameraLiveParams*)\n\x10\x43\x61meraLiveStatus\x12\x08\n\x04IDLE\x10\x00\x12\x0b\n\x07LIVEING\x10\x01*/\n\x0e\x43\x61meraLiveMode\x12\x0f\n\x0bLIVE_NORMAL\x10\x00\x12\x0c\n\x08LIVE_HDR\x10\x01\x42\x08\xa2\x02\x05INSPBP\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "camera_live_info_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"\242\002\005INSPB"
    _globals["_CAMERALIVESTATUS"]._serialized_start = 364
    _globals["_CAMERALIVESTATUS"]._serialized_end = 405
    _globals["_CAMERALIVEMODE"]._serialized_start = 407
    _globals["_CAMERALIVEMODE"]._serialized_end = 454
    _globals["_CAMERALIVEPARAMS"]._serialized_start = 59
    _globals["_CAMERALIVEPARAMS"]._serialized_end = 222
    _globals["_CAMERALIVEINFO"]._serialized_start = 225
    _globals["_CAMERALIVEINFO"]._serialized_end = 362
# @@protoc_insertion_point(module_scope)
