# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: camera_submode.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from photo_pb2 import *
from video_pb2 import *
from sensor_pb2 import *

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x14\x63\x61mera_submode.proto\x12\x11insta360.messages\x1a\x0bphoto.proto\x1a\x0bvideo.proto\x1a\x0csensor.proto"\xb6\x01\n\x13NotifyCameraSubMode\x12\x36\n\rphoto_submode\x18\x01 \x01(\x0e\x32\x1f.insta360.messages.PhotoSubMode\x12\x36\n\rvideo_submode\x18\x02 \x01(\x0e\x32\x1f.insta360.messages.VideoSubMode\x12/\n\x06sensor\x18\x03 \x01(\x0e\x32\x1f.insta360.messages.SensorDeviceB\x08\xa2\x02\x05INSPBP\x00P\x01P\x02\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "camera_submode_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"\242\002\005INSPB"
    _globals["_NOTIFYCAMERASUBMODE"]._serialized_start = 84
    _globals["_NOTIFYCAMERASUBMODE"]._serialized_end = 266
# @@protoc_insertion_point(module_scope)
