# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: set_camera_live_info.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from camera_live_info_pb2 import *

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x1aset_camera_live_info.proto\x12\x11insta360.messages\x1a\x16\x63\x61mera_live_info.proto"L\n\x11SetCameraLiveInfo\x12\x37\n\nlive_param\x18\x01 \x01(\x0b\x32#.insta360.messages.CameraLiveParams"\x17\n\x15SetCameraLiveInfoRespB\x08\xa2\x02\x05INSPBP\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(
    DESCRIPTOR, "set_camera_live_info_pb2", _globals
)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"\242\002\005INSPB"
    _globals["_SETCAMERALIVEINFO"]._serialized_start = 73
    _globals["_SETCAMERALIVEINFO"]._serialized_end = 149
    _globals["_SETCAMERALIVEINFORESP"]._serialized_start = 151
    _globals["_SETCAMERALIVEINFORESP"]._serialized_end = 174
# @@protoc_insertion_point(module_scope)
