# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: wifi_mode.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x0fwifi_mode.proto\x12\x11insta360.messages"R\n\x0eWifiModeResult\x12.\n\twifi_mode\x18\x01 \x01(\x0e\x32\x1b.insta360.messages.WifiMode\x12\x10\n\x08\x65rr_code\x18\x02 \x01(\x05*$\n\x08WifiMode\x12\x06\n\x02\x41P\x10\x00\x12\x07\n\x03STA\x10\x01\x12\x07\n\x03P2P\x10\x02\x42\x08\xa2\x02\x05INSPBb\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "wifi_mode_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"\242\002\005INSPB"
    _globals["_WIFIMODE"]._serialized_start = 122
    _globals["_WIFIMODE"]._serialized_end = 158
    _globals["_WIFIMODERESULT"]._serialized_start = 38
    _globals["_WIFIMODERESULT"]._serialized_end = 120
# @@protoc_insertion_point(module_scope)
