# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: extra_info.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from offset_state_pb2 import *
from window_crop_info_pb2 import *
from photo_pb2 import *

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x10\x65xtra_info.proto\x12\x11insta360.messages\x1a\x12offset_state.proto\x1a\x16window_crop_info.proto\x1a\x0bphoto.proto"\xe9;\n\rExtraMetadata\x12\x15\n\rserial_number\x18\x01 \x01(\t\x12\x13\n\x0b\x63\x61mera_type\x18\x02 \x01(\t\x12\x12\n\nfw_version\x18\x03 \x01(\t\x12\x11\n\tfile_type\x18\x04 \x01(\t\x12\x0e\n\x06offset\x18\x05 \x01(\t\x12\n\n\x02ip\x18\x06 \x01(\t\x12\x15\n\rcreation_time\x18\x07 \x01(\x04\x12\x13\n\x0b\x65xport_time\x18\x08 \x01(\x04\x12\x11\n\tfile_size\x18\t \x01(\x04\x12\x12\n\ntotal_time\x18\n \x01(\r\x12\x0b\n\x03gps\x18\x0b \x01(\x0c\x12\x13\n\x0borientation\x18\x0c \x01(\x0c\x12G\n\x0cuser_options\x18\r \x01(\x0b\x32\x31.insta360.messages.ExtraMetadata.ExtraUserOptions\x12\x0c\n\x04gyro\x18\x0e \x01(\x0c\x12=\n\thdr_state\x18\x0f \x01(\x0e\x32*.insta360.messages.ExtraMetadata.HDR_STATE\x12\x16\n\x0ehdr_identifier\x18\x10 \x01(\t\x12\x17\n\x0foriginal_offset\x18\x11 \x01(\t\x12\x46\n\x0etrigger_source\x18\x12 \x01(\x0e\x32..insta360.messages.ExtraMetadata.TriggerSource\x12;\n\tdimension\x18\x13 \x01(\x0b\x32(.insta360.messages.ExtraMetadata.Vector2\x12\x12\n\nframe_rate\x18\x14 \x01(\x05\x12\x41\n\x0fimage_translate\x18\x15 \x01(\x0b\x32(.insta360.messages.ExtraMetadata.Vector2\x12\x12\n\ngamma_mode\x18\x16 \x01(\t\x12H\n\x14thumbnail_gyro_index\x18\x17 \x01(\x0b\x32*.insta360.messages.ExtraMetadata.GyroIndex\x12\x1d\n\x15\x66irst_frame_timestamp\x18\x18 \x01(\x03\x12\x1c\n\x14rolling_shutter_time\x18\x19 \x01(\x01\x12G\n\x0f\x66ile_group_info\x18\x1a \x01(\x0b\x32..insta360.messages.ExtraMetadata.FileGroupInfo\x12;\n\x10window_crop_info\x18\x1b \x01(\x0b\x32!.insta360.messages.WindowCropInfo\x12\x16\n\x0egyro_timestamp\x18\x1c \x01(\x01\x12\x1d\n\x15is_has_gyro_timestamp\x18\x1d \x01(\x08\x12\x1a\n\x12timelapse_interval\x18\x1e \x01(\r\x12\x12\n\ngyro_calib\x18\x1f \x01(\x0c\x12G\n\x0f\x65vo_status_mode\x18  \x01(\x0e\x32..insta360.messages.ExtraMetadata.EvoStatusMode\x12\x15\n\revo_status_id\x18! \x01(\t\x12\x1a\n\x12original_offset_3d\x18" \x01(\t\x12?\n\x0bgps_sources\x18# \x03(\x0e\x32*.insta360.messages.ExtraMetadata.GpsSource\x12\x1b\n\x13\x66irst_gps_timestamp\x18$ \x01(\x03\x12\x19\n\x11orientation_calib\x18% \x01(\x0c\x12\x14\n\x0cis_collected\x18& \x01(\x08\x12\x14\n\x0crecycle_time\x18\' \x01(\x04\x12\x14\n\x0ctotal_frames\x18( \x01(\r\x12\x11\n\tis_selfie\x18) \x01(\x08\x12\x1b\n\x13is_flowstate_online\x18* \x01(\x08\x12\x11\n\tis_dewarp\x18+ \x01(\x08\x12\x41\n\x0fresolution_size\x18, \x01(\x0b\x32(.insta360.messages.ExtraMetadata.Vector2\x12\x43\n\x0c\x62\x61ttery_type\x18- \x01(\x0e\x32-.insta360.messages.ExtraMetadata.Battery_type\x12\x44\n\x0b\x63\x61m_posture\x18. \x01(\x0e\x32/.insta360.messages.ExtraMetadata.Camera_Posture\x12@\n\x08\x66ov_type\x18/ \x01(\x0e\x32..insta360.messages.ExtraMetadata.Image_FovType\x12\x10\n\x08\x64istance\x18\x30 \x01(\x01\x12\x0b\n\x03\x66ov\x18\x31 \x01(\x01\x12J\n\x10gyro_filter_type\x18\x32 \x01(\x0e\x32\x30.insta360.messages.ExtraMetadata.Gyro_FilterType\x12<\n\tgyro_type\x18\x33 \x01(\x0e\x32).insta360.messages.ExtraMetadata.GyroType\x12[\n\x17media_data_rotate_angel\x18\x34 \x01(\x0e\x32:.insta360.messages.ExtraMetadata.VideoMediaDataRotateAngle\x12\x11\n\toffset_v2\x18\x35 \x01(\t\x12\x11\n\toffset_v3\x18\x36 \x01(\t\x12\x1a\n\x12original_offset_v2\x18\x37 \x01(\t\x12\x1a\n\x12original_offset_v3\x18\x38 \x01(\t\x12\x42\n\x0b\x66ocusSensor\x18\x39 \x01(\x0e\x32-.insta360.messages.ExtraMetadata.SensorDevice\x12K\n\x10\x65xpectOutputType\x18: \x01(\x0e\x32\x31.insta360.messages.ExtraMetadata.ExpectOutputType\x12)\n!timelapse_interval_in_millisecond\x18; \x01(\x08\x12\x11\n\tphoto_rot\x18< \x03(\x02\x12\x42\n\naudio_mode\x18= \x01(\x0e\x32..insta360.messages.ExtraMetadata.AudioModeType\x12\x13\n\x0bis_raw_gyro\x18> \x01(\x08\x12;\n\x10raw_capture_type\x18? \x01(\x0e\x32!.insta360.messages.RawCaptureType\x12?\n\x08pts_type\x18@ \x01(\x0e\x32-.insta360.messages.ExtraMetadata.VideoPtsType\x12\x46\n\rgyro_cfg_info\x18\x41 \x01(\x0b\x32/.insta360.messages.ExtraMetadata.GyroConfigInfo\x12\x46\n\x0flens_283M_type1\x18\x42 \x01(\x0e\x32-.insta360.messages.ExtraMetadata.Lens283MType\x12\x46\n\x0flens_283M_type2\x18\x43 \x01(\x0e\x32-.insta360.messages.ExtraMetadata.Lens283MType\x12\x35\n\roffset_states\x18\x44 \x01(\x0e\x32\x1e.insta360.messages.OffsetState\x12\x0f\n\x07q_i_uav\x18\x45 \x03(\x02\x12\x0f\n\x07r_uav_i\x18\x46 \x03(\x02\x12\x46\n\x0e\x61uto_clip_para\x18G \x01(\x0b\x32..insta360.messages.ExtraMetadata.AutoClipParam\x12H\n\x0fmeta_track_para\x18H \x01(\x0b\x32/.insta360.messages.ExtraMetadata.MetaTrackParam\x12>\n\ntime_scale\x18I \x01(\x0e\x32*.insta360.messages.ExtraMetadata.TimeScale\x12I\n\x10hdr_process_type\x18J \x01(\x0e\x32/.insta360.messages.ExtraMetadata.HdrProcessType\x12\x46\n\x0ethumbnail_type\x18K \x01(\x0e\x32..insta360.messages.ExtraMetadata.ThumbnailType\x12S\n\x15pureshot_process_type\x18L \x01(\x0e\x32\x34.insta360.messages.ExtraMetadata.PureShotProcessType\x12\x19\n\x11pre_rec_time_flag\x18M \x01(\x08\x12T\n\x16\x66rame_rate_av_rational\x18N \x01(\x0b\x32\x34.insta360.messages.ExtraMetadata.FrameRateAVRational\x1a\xde\x04\n\x10\x45xtraUserOptions\x12\x0e\n\x06\x66ilter\x18\x01 \x01(\t\x12\x10\n\x08\x62\x65\x66ilter\x18\x02 \x01(\t\x12\r\n\x05\x65uler\x18\x03 \x01(\x0c\x12\x11\n\trm_purple\x18\x04 \x01(\x08\x12\x1b\n\x13gyro_calibrate_mode\x18\x05 \x01(\r\x12\x14\n\x0c\x65uler_enable\x18\x06 \x01(\x08\x12M\n\tlogo_type\x18\x07 \x01(\x0e\x32:.insta360.messages.ExtraMetadata.ExtraUserOptions.LogoType\x12\x15\n\radjustFilters\x18\x08 \x01(\t\x12\x12\n\nlut_filter\x18\t \x01(\t\x12\x63\n\x15offset_convert_states\x18\n \x03(\x0e\x32\x44.insta360.messages.ExtraMetadata.ExtraUserOptions.OffsetConvertState\x12%\n\x1dplay_trim_recommend_timestamp\x18\x0b \x01(\x01">\n\x08LogoType\x12\x15\n\x11UNKNOWN_LOGO_TYPE\x10\x00\x12\x0b\n\x07NO_LOGO\x10\x01\x12\x0e\n\nINSTA_LOGO\x10\x02"\x8c\x01\n\x12OffsetConvertState\x12\x0e\n\nWaterProof\x10\x00\x12\x0f\n\x0b\x44ivingWater\x10\x01\x12\r\n\tDivingAir\x10\x02\x12\x16\n\x12StitchOptimization\x10\x03\x12\x0b\n\x07Protect\x10\x04\x12\x11\n\rSphereProtect\x10\x05\x12\x0e\n\nFpvProtect\x10\x06\x1a\x1f\n\x07Vector2\x12\t\n\x01x\x18\x01 \x01(\x05\x12\t\n\x01y\x18\x02 \x01(\x05\x1a-\n\tGyroIndex\x12\r\n\x05index\x18\x01 \x01(\x05\x12\x11\n\ttimestamp\x18\x02 \x01(\x03\x1a|\n\rFileGroupInfo\x12;\n\x04type\x18\x01 \x01(\x0e\x32-.insta360.messages.ExtraMetadata.SubMediaType\x12\r\n\x05index\x18\x02 \x01(\r\x12\x10\n\x08identify\x18\x03 \x01(\t\x12\r\n\x05total\x18\x04 \x01(\r\x1a\x37\n\x0eGyroConfigInfo\x12\x11\n\tacc_range\x18\x01 \x01(\r\x12\x12\n\ngyro_range\x18\x02 \x01(\r\x1a\xa2\x02\n\rAutoClipParam\x12\x41\n\x07version\x18\x01 \x01(\x0b\x32\x30.insta360.messages.ExtraMetadata.AutoClipVersion\x12\x13\n\x0bsample_rate\x18\x02 \x01(\x02\x12\r\n\x05img_w\x18\x03 \x01(\r\x12\r\n\x05img_h\x18\x04 \x01(\r\x12\x11\n\timg_pitch\x18\x05 \x01(\r\x12\x42\n\x0c\x63ompute_type\x18\x06 \x01(\x0e\x32,.insta360.messages.ExtraMetadata.ComputeType\x12\x0b\n\x03\x66ps\x18\x07 \x01(\r\x12\x10\n\x08seq_diff\x18\x08 \x01(\r\x12\x10\n\x08pts_diff\x18\t \x01(\r\x12\x13\n\x0btotal_frame\x18\n \x01(\r\x1aL\n\x0eMetaTrackParam\x12\x13\n\x0bImuDataSize\x18\x01 \x01(\x04\x12\x13\n\x0b\x41\x41\x41\x44\x61taSize\x18\x02 \x01(\x04\x12\x10\n\x08\x43ompress\x18\x03 \x01(\r\x1a/\n\x13\x46rameRateAVRational\x12\x0b\n\x03num\x18\x01 \x01(\r\x12\x0b\n\x03\x64\x65n\x18\x02 \x01(\r\x1a;\n\x0c\x41iLibVersion\x12\r\n\x05major\x18\x01 \x01(\r\x12\r\n\x05minor\x18\x02 \x01(\r\x12\r\n\x05patch\x18\x03 \x01(\r\x1a\x93\x02\n\x0f\x41utoClipVersion\x12=\n\x08platform\x18\x01 \x01(\x0e\x32+.insta360.messages.ExtraMetadata.AiPlatform\x12?\n\talgorithm\x18\x02 \x01(\x0e\x32,.insta360.messages.ExtraMetadata.AiAlgorithm\x12@\n\tmodel_ver\x18\x03 \x01(\x0b\x32-.insta360.messages.ExtraMetadata.AiLibVersion\x12>\n\x07svc_ver\x18\x04 \x01(\x0b\x32-.insta360.messages.ExtraMetadata.AiLibVersion"<\n\tHDR_STATE\x12\x0b\n\x07NOT_HDR\x10\x00\x12\x13\n\x0fWAITING_PROCESS\x10\x01\x12\r\n\tPROCESSED\x10\x02"X\n\rTriggerSource\x12\x0b\n\x07Unknown\x10\x00\x12\x10\n\x0c\x43\x61meraButton\x10\x01\x12\x11\n\rRemoteControl\x10\x02\x12\x07\n\x03USB\x10\x03\x12\x0c\n\x08\x42tRemote\x10\x04"F\n\rEvoStatusMode\x12\x17\n\x13UNKNOWN_STATUS_MODE\x10\x00\x12\r\n\tDEGREE180\x10\x01\x12\r\n\tDEGREE360\x10\x02"/\n\tGpsSource\x12\x07\n\x03GSV\x10\x00\x12\r\n\tDASHBOARD\x10\x01\x12\n\n\x06REMOTE\x10\x02"1\n\x0c\x42\x61ttery_type\x12\t\n\x05THICK\x10\x00\x12\x08\n\x04THIN\x10\x01\x12\x0c\n\x08VERTICAL\x10\x02"i\n\x0e\x43\x61mera_Posture\x12\x13\n\x0f\x43\x41MERA_ROTATE_0\x10\x00\x12\x14\n\x10\x43\x41MERA_ROTATE_90\x10\x01\x12\x15\n\x11\x43\x41MERA_ROTATE_180\x10\x02\x12\x15\n\x11\x43\x41MERA_ROTATE_270\x10\x03"\xad\x02\n\rImage_FovType\x12\x14\n\x10\x46OV_TYPE_UNKNOWN\x10\x00\x12\x11\n\rFOV_TYPE_WIDE\x10\x01\x12\x13\n\x0f\x46OV_TYPE_LINEAR\x10\x02\x12\x16\n\x12\x46OV_TYPE_ULTRAWIDE\x10\x03\x12\x13\n\x0f\x46OV_TYPE_NARROW\x10\x04\x12\x10\n\x0c\x46OV_TYPE_POV\x10\x05\x12\x17\n\x13\x46OV_TYPE_LINEARPLUS\x10\x06\x12\x1a\n\x16\x46OV_TYPE_LINEARHORIZON\x10\x07\x12\x10\n\x0c\x46OV_TYPE_FPV\x10\x08\x12\x12\n\x0e\x46OV_TYPE_SUPER\x10\t\x12\x17\n\x13\x46OV_TYPE_TINYPLANET\x10\n\x12\x19\n\x15\x46OV_TYPE_INFINITYWIDE\x10\x0b\x12\x10\n\x0c\x46OV_TYPE_NUM\x10\x0c"e\n\x0fGyro_FilterType\x12\x1c\n\x18GYRO_FILTER_TYPE_UNKNOWN\x10\x00\x12\x1a\n\x16GYRO_FILTER_TYPE_BRUTE\x10\x01\x12\x18\n\x14GYRO_FILTER_TYPE_AKF\x10\x02"@\n\x08GyroType\x12\x19\n\x15INSDEV_IMU_TYPE_20948\x10\x00\x12\x19\n\x15INSDEV_IMU_TYPE_40609\x10\x01"\xbb\x01\n\x19VideoMediaDataRotateAngle\x12\x1d\n\x19MEDIA_DATA_ROTATE_UNKNOWN\x10\x00\x12\x1d\n\x19MEDIA_DATA_ROTATE_ANGLE_0\x10\x01\x12\x1f\n\x1bMEDIA_DATA_ROTATE_ANGLE_180\x10\x03\x12\x1e\n\x1aMEDIA_DATA_ROTATE_ANGLE_90\x10\x06\x12\x1f\n\x1bMEDIA_DATA_ROTATE_ANGLE_270\x10\x08"q\n\x0cSensorDevice\x12\x19\n\x15SENSOR_DEVICE_UNKNOWN\x10\x00\x12\x17\n\x13SENSOR_DEVICE_FRONT\x10\x01\x12\x16\n\x12SENSOR_DEVICE_REAR\x10\x02\x12\x15\n\x11SENSOR_DEVICE_ALL\x10\x03"O\n\x10\x45xpectOutputType\x12\x0b\n\x07\x44\x45\x46\x41ULT\x10\x00\x12\x0e\n\nINSTA_PANO\x10\x01\x12\x10\n\x0cMULTI_CAMERA\x10\x02\x12\x0c\n\x08ONE_TAKE\x10\x03"\xec\x01\n\rAudioModeType\x12\x16\n\x12\x41UDIO_MODE_UNKNOWN\x10\x00\x12\x14\n\x10\x41UDIO_MODE_FOCUS\x10\x01\x12\x1c\n\x18\x41UDIO_MODE_WINDREDUCTION\x10\x02\x12\x12\n\x0e\x41UDIO_MODE_360\x10\x03\x12\x15\n\x11\x41UDIO_MODE_STEREO\x10\x04\x12\x18\n\x14\x41UDIO_MODE_EXTMICDEV\x10\x05\x12\x18\n\x14\x41UDIO_MODE_AIRPODDEV\x10\x06\x12\x17\n\x13\x41UDIO_MODE_RESERVE1\x10\x07\x12\x17\n\x13\x41UDIO_MODE_RESERVE2\x10\x08"U\n\x0cVideoPtsType\x12\x15\n\x11VIDEO_PTS_UNKNOWN\x10\x00\x12\x11\n\rVIDEO_PTS_MP4\x10\x01\x12\x1b\n\x17VIDEO_PTS_EXPOSURE_FILE\x10\x02"V\n\x0cLens283MType\x12\x0f\n\x0bLENS_UNKNOW\x10\x00\x12\x19\n\x15LENS_LOW_TRANSPARENCY\x10\x01\x12\x1a\n\x16LENS_HIGH_TRANSPARENCY\x10\x02"i\n\tTimeScale\x12\x10\n\x0cTIMESCALE_1X\x10\x00\x12\x10\n\x0cTIMESCALE_4X\x10\x01\x12\x10\n\x0cTIMESCALE_8X\x10\x02\x12\x12\n\x0eTIMESCALE_1_4X\x10\x03\x12\x12\n\x0eTIMESCALE_1_8X\x10\x04"A\n\x0eHdrProcessType\x12\x18\n\x14HDR_PROCESS_EXTERNAL\x10\x00\x12\x15\n\x11HDR_PROCESS_INNER\x10\x01"u\n\rThumbnailType\x12\x1a\n\x16THUMBNAIL_TYPE_UNKNOWN\x10\x00\x12\x16\n\x12THUMBNAIL_TYPE_YUV\x10\x01\x12\x17\n\x13THUMBNAIL_TYPE_JPEG\x10\x02\x12\x17\n\x13THUMBNAIL_TYPE_H264\x10\x03"P\n\x13PureShotProcessType\x12\x1d\n\x19PURESHOT_PROCESS_EXTERNAL\x10\x00\x12\x1a\n\x16PURESHOT_PROCESS_INNER\x10\x01"\xd3\x03\n\x0cSubMediaType\x12\x10\n\x0cVIDEO_NORMAL\x10\x00\x12\x14\n\x10VIDEO_BULLETTIME\x10\x01\x12\x13\n\x0fVIDEO_TIMELAPSE\x10\x02\x12\x10\n\x0cPHOTO_NORMAL\x10\x03\x12\r\n\tPHOTO_HDR\x10\x04\x12\x1a\n\x16PHOTO_INTERVALSHOOTING\x10\x05\x12\r\n\tVIDEO_HDR\x10\x06\x12\x0f\n\x0bPHOTO_BURST\x10\x07\x12\x1a\n\x16VIDEO_STATIC_TIMELAPSE\x10\x08\x12\x13\n\x0fVIDEO_TIMESHIFT\x10\t\x12\x18\n\x14PHOTO_AEB_NIGHT_MODE\x10\n\x12\x16\n\x12VIDEO_SUPER_NORMAL\x10\x0b\x12\x17\n\x13VIDEO_LOOPRECORDING\x10\x0c\x12\x13\n\x0fPHOTO_STARLAPSE\x10\r\x12\x13\n\x0fPHOTO_PANO_MODE\x10\x0e\x12\r\n\tVIDEO_FPV\x10\x0f\x12\x0f\n\x0bVIDEO_MOVIE\x10\x10\x12\x14\n\x10VIDEO_SLOWMOTION\x10\x11\x12\x10\n\x0cVIDEO_SELFIE\x10\x12\x12\x16\n\x12PHOTO_PURESHOTPLUS\x10\x13\x12\x0e\n\nVIDEO_PURE\x10\x14\x12\x13\n\x0fVIDEO_STARLAPSE\x10\x15"\x19\n\x0b\x41iAlgorithm\x12\n\n\x06\x45\x44ITOR\x10\x00"(\n\nAiPlatform\x12\x07\n\x03\x43V5\x10\x00\x12\x08\n\x04\x43V22\x10\x01\x12\x07\n\x03H22\x10\x02"@\n\x0b\x43omputeType\x12\x0f\n\x0b\x43OMPUTE_CPU\x10\x00\x12\x0f\n\x0b\x43OMPUTE_VPU\x10\x01\x12\x0f\n\x0b\x43OMPUTE_DSP\x10\x02"\x8a\x01\n\x15\x46ileExtraMetadataResp\x12\x0b\n\x03uri\x18\x01 \x03(\t\x12\x33\n\tmediaData\x18\x02 \x03(\x0b\x32 .insta360.messages.ExtraMetadata\x12\x13\n\x0btotal_count\x18\x03 \x01(\r\x12\r\n\x05start\x18\x04 \x01(\r\x12\x0b\n\x03\x65nd\x18\x05 \x01(\r*\xc0\x03\n\tExtraType\x12\x12\n\x0e\x45XTRA_TYPE_ALL\x10\x00\x12\x17\n\x13\x45XTRA_TYPE_METADATA\x10\x01\x12\x18\n\x14\x45XTRA_TYPE_THUMBNAIL\x10\x02\x12\x13\n\x0f\x45XTRA_TYPE_GYRO\x10\x03\x12\x17\n\x13\x45XTRA_TYPE_EXPOSURE\x10\x04\x12\x1c\n\x18\x45XTRA_TYPE_EXT_THUMBNAIL\x10\x05\x12\x18\n\x14\x45XTRA_TYPE_FRAME_PTS\x10\x06\x12\x12\n\x0e\x45XTRA_TYPE_GPS\x10\x07\x12\x17\n\x13\x45XTRA_TYPE_STAR_NUM\x10\x08\x12\x17\n\x13\x45XTRA_TYPE_AAA_DATA\x10\t\x12\x18\n\x14\x45XTRA_TYPE_HIGHLIGHT\x10\n\x12\x16\n\x12\x45XTRA_TYPE_AAA_SIM\x10\x0b\x12\x1c\n\x18\x45XTRA_TYPE_EXPOTIME_VIN1\x10\x0c\x12\x17\n\x13\x45XTRA_TYPE_MAGNETIC\x10\r\x12\x14\n\x10\x45XTRA_TYPE_EULER\x10\x0e\x12\x16\n\x12\x45XTRA_TYPE_SECGYRO\x10\x0f\x12\x14\n\x10\x45XTRA_TYPE_SPEED\x10\x10\x12\x13\n\x0f\x45XTRA_TYPE_TBOX\x10\x11\x42\x08\xa2\x02\x05INSPBP\x00P\x01P\x02\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "extra_info_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"\242\002\005INSPB"
    _globals["_EXTRATYPE"]._serialized_start = 7898
    _globals["_EXTRATYPE"]._serialized_end = 8346
    _globals["_EXTRAMETADATA"]._serialized_start = 97
    _globals["_EXTRAMETADATA"]._serialized_end = 7754
    _globals["_EXTRAMETADATA_EXTRAUSEROPTIONS"]._serialized_start = 3442
    _globals["_EXTRAMETADATA_EXTRAUSEROPTIONS"]._serialized_end = 4048
    _globals["_EXTRAMETADATA_EXTRAUSEROPTIONS_LOGOTYPE"]._serialized_start = 3843
    _globals["_EXTRAMETADATA_EXTRAUSEROPTIONS_LOGOTYPE"]._serialized_end = 3905
    _globals[
        "_EXTRAMETADATA_EXTRAUSEROPTIONS_OFFSETCONVERTSTATE"
    ]._serialized_start = 3908
    _globals[
        "_EXTRAMETADATA_EXTRAUSEROPTIONS_OFFSETCONVERTSTATE"
    ]._serialized_end = 4048
    _globals["_EXTRAMETADATA_VECTOR2"]._serialized_start = 4050
    _globals["_EXTRAMETADATA_VECTOR2"]._serialized_end = 4081
    _globals["_EXTRAMETADATA_GYROINDEX"]._serialized_start = 4083
    _globals["_EXTRAMETADATA_GYROINDEX"]._serialized_end = 4128
    _globals["_EXTRAMETADATA_FILEGROUPINFO"]._serialized_start = 4130
    _globals["_EXTRAMETADATA_FILEGROUPINFO"]._serialized_end = 4254
    _globals["_EXTRAMETADATA_GYROCONFIGINFO"]._serialized_start = 4256
    _globals["_EXTRAMETADATA_GYROCONFIGINFO"]._serialized_end = 4311
    _globals["_EXTRAMETADATA_AUTOCLIPPARAM"]._serialized_start = 4314
    _globals["_EXTRAMETADATA_AUTOCLIPPARAM"]._serialized_end = 4604
    _globals["_EXTRAMETADATA_METATRACKPARAM"]._serialized_start = 4606
    _globals["_EXTRAMETADATA_METATRACKPARAM"]._serialized_end = 4682
    _globals["_EXTRAMETADATA_FRAMERATEAVRATIONAL"]._serialized_start = 4684
    _globals["_EXTRAMETADATA_FRAMERATEAVRATIONAL"]._serialized_end = 4731
    _globals["_EXTRAMETADATA_AILIBVERSION"]._serialized_start = 4733
    _globals["_EXTRAMETADATA_AILIBVERSION"]._serialized_end = 4792
    _globals["_EXTRAMETADATA_AUTOCLIPVERSION"]._serialized_start = 4795
    _globals["_EXTRAMETADATA_AUTOCLIPVERSION"]._serialized_end = 5070
    _globals["_EXTRAMETADATA_HDR_STATE"]._serialized_start = 5072
    _globals["_EXTRAMETADATA_HDR_STATE"]._serialized_end = 5132
    _globals["_EXTRAMETADATA_TRIGGERSOURCE"]._serialized_start = 5134
    _globals["_EXTRAMETADATA_TRIGGERSOURCE"]._serialized_end = 5222
    _globals["_EXTRAMETADATA_EVOSTATUSMODE"]._serialized_start = 5224
    _globals["_EXTRAMETADATA_EVOSTATUSMODE"]._serialized_end = 5294
    _globals["_EXTRAMETADATA_GPSSOURCE"]._serialized_start = 5296
    _globals["_EXTRAMETADATA_GPSSOURCE"]._serialized_end = 5343
    _globals["_EXTRAMETADATA_BATTERY_TYPE"]._serialized_start = 5345
    _globals["_EXTRAMETADATA_BATTERY_TYPE"]._serialized_end = 5394
    _globals["_EXTRAMETADATA_CAMERA_POSTURE"]._serialized_start = 5396
    _globals["_EXTRAMETADATA_CAMERA_POSTURE"]._serialized_end = 5501
    _globals["_EXTRAMETADATA_IMAGE_FOVTYPE"]._serialized_start = 5504
    _globals["_EXTRAMETADATA_IMAGE_FOVTYPE"]._serialized_end = 5805
    _globals["_EXTRAMETADATA_GYRO_FILTERTYPE"]._serialized_start = 5807
    _globals["_EXTRAMETADATA_GYRO_FILTERTYPE"]._serialized_end = 5908
    _globals["_EXTRAMETADATA_GYROTYPE"]._serialized_start = 5910
    _globals["_EXTRAMETADATA_GYROTYPE"]._serialized_end = 5974
    _globals["_EXTRAMETADATA_VIDEOMEDIADATAROTATEANGLE"]._serialized_start = 5977
    _globals["_EXTRAMETADATA_VIDEOMEDIADATAROTATEANGLE"]._serialized_end = 6164
    _globals["_EXTRAMETADATA_SENSORDEVICE"]._serialized_start = 6166
    _globals["_EXTRAMETADATA_SENSORDEVICE"]._serialized_end = 6279
    _globals["_EXTRAMETADATA_EXPECTOUTPUTTYPE"]._serialized_start = 6281
    _globals["_EXTRAMETADATA_EXPECTOUTPUTTYPE"]._serialized_end = 6360
    _globals["_EXTRAMETADATA_AUDIOMODETYPE"]._serialized_start = 6363
    _globals["_EXTRAMETADATA_AUDIOMODETYPE"]._serialized_end = 6599
    _globals["_EXTRAMETADATA_VIDEOPTSTYPE"]._serialized_start = 6601
    _globals["_EXTRAMETADATA_VIDEOPTSTYPE"]._serialized_end = 6686
    _globals["_EXTRAMETADATA_LENS283MTYPE"]._serialized_start = 6688
    _globals["_EXTRAMETADATA_LENS283MTYPE"]._serialized_end = 6774
    _globals["_EXTRAMETADATA_TIMESCALE"]._serialized_start = 6776
    _globals["_EXTRAMETADATA_TIMESCALE"]._serialized_end = 6881
    _globals["_EXTRAMETADATA_HDRPROCESSTYPE"]._serialized_start = 6883
    _globals["_EXTRAMETADATA_HDRPROCESSTYPE"]._serialized_end = 6948
    _globals["_EXTRAMETADATA_THUMBNAILTYPE"]._serialized_start = 6950
    _globals["_EXTRAMETADATA_THUMBNAILTYPE"]._serialized_end = 7067
    _globals["_EXTRAMETADATA_PURESHOTPROCESSTYPE"]._serialized_start = 7069
    _globals["_EXTRAMETADATA_PURESHOTPROCESSTYPE"]._serialized_end = 7149
    _globals["_EXTRAMETADATA_SUBMEDIATYPE"]._serialized_start = 7152
    _globals["_EXTRAMETADATA_SUBMEDIATYPE"]._serialized_end = 7619
    _globals["_EXTRAMETADATA_AIALGORITHM"]._serialized_start = 7621
    _globals["_EXTRAMETADATA_AIALGORITHM"]._serialized_end = 7646
    _globals["_EXTRAMETADATA_AIPLATFORM"]._serialized_start = 7648
    _globals["_EXTRAMETADATA_AIPLATFORM"]._serialized_end = 7688
    _globals["_EXTRAMETADATA_COMPUTETYPE"]._serialized_start = 7690
    _globals["_EXTRAMETADATA_COMPUTETYPE"]._serialized_end = 7754
    _globals["_FILEEXTRAMETADATARESP"]._serialized_start = 7757
    _globals["_FILEEXTRAMETADATARESP"]._serialized_end = 7895
# @@protoc_insertion_point(module_scope)
