# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: options.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from photo_pb2 import *
from video_pb2 import *
from battery_pb2 import *
from storage_pb2 import *
from button_press_pb2 import *
from flicker_pb2 import *
from sensor_pb2 import *
from chargebox_pb2 import *
from offset_state_pb2 import *
from window_crop_info_pb2 import *
from heat_shell_pb2 import *

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\roptions.proto\x12\x11insta360.messages\x1a\x0bphoto.proto\x1a\x0bvideo.proto\x1a\rbattery.proto\x1a\rstorage.proto\x1a\x12\x62utton_press.proto\x1a\rflicker.proto\x1a\x0csensor.proto\x1a\x0f\x63hargebox.proto\x1a\x12offset_state.proto\x1a\x16window_crop_info.proto\x1a\x10heat_shell.proto"\x91/\n\x07Options\x12<\n\x10video_resolution\x18\x01 \x01(\x0e\x32".insta360.messages.VideoResolution\x12\x30\n\nphoto_size\x18\x02 \x01(\x0e\x32\x1c.insta360.messages.PhotoSize\x12\x15\n\rvideo_bitrate\x18\x03 \x01(\r\x12\x15\n\raudio_bitrate\x18\x04 \x01(\r\x12\x18\n\x10\x61udio_samplerate\x18\x05 \x01(\r\x12\x15\n\rorigin_offset\x18\x06 \x01(\t\x12\x1a\n\x12\x63\x61pture_time_limit\x18\x07 \x01(\r\x12\x13\n\x0bgps_timeout\x18\x08 \x01(\r\x12\x1e\n\x16remaining_capture_time\x18\t \x01(\r\x12\x1a\n\x12remaining_pictures\x18\n \x01(\r\x12\x38\n\x0e\x62\x61ttery_status\x18\x0b \x01(\x0b\x32 .insta360.messages.BatteryStatus\x12\x12\n\nlocal_time\x18\x0c \x01(\x04\x12"\n\x1atime_zone_seconds_from_GMT\x18\r \x01(\x05\x12\x0c\n\x04mute\x18\x0e \x01(\x08\x12\x15\n\rserial_number\x18\x0f \x01(\t\x12\x0c\n\x04UUID\x18\x10 \x01(\t\x12;\n\x0cpressOptions\x18\x11 \x01(\x0b\x32%.insta360.messages.ButtonPressOptions\x12\x15\n\ractivate_time\x18\x13 \x01(\x04\x12\x36\n\rstorage_state\x18\x14 \x01(\x0b\x32\x1f.insta360.messages.StorageState\x12\x12\n\nlens_index\x18\x15 \x01(\r\x12\x14\n\x0cmedia_offset\x18\x16 \x01(\t\x12\x12\n\nself_timer\x18\x17 \x01(\r\x12\x18\n\x10gyro_sample_rate\x18\x18 \x01(\r\x12?\n\tacc_range\x18\x19 \x01(\x0e\x32,.insta360.messages.Options.AccFullScaleRange\x12\x41\n\ngyro_range\x18\x1a \x01(\x0e\x32-.insta360.messages.Options.GyroFullScaleRange\x12\x18\n\x10take_raw_picture\x18\x1b \x01(\x08\x12\x30\n\ngamma_mode\x18\x1c \x01(\x0e\x32\x1c.insta360.messages.GammaMode\x12\x12\n\nmedia_time\x18\x1d \x01(\x03\x12\x18\n\x10\x66irmwareRevision\x18\x1e \x01(\t\x12?\n\x0csys_adoption\x18\x1f \x01(\x0e\x32).insta360.messages.Options.AdoptionSystem\x12\x10\n\x08\x63pu_type\x18  \x01(\t\x12G\n\x12gyro_filter_config\x18! \x01(\x0b\x32+.insta360.messages.Options.GyroFilterConfig\x12\x13\n\x0bmctf_enable\x18" \x01(\x08\x12\x19\n\x11sport_mode_enable\x18# \x01(\x08\x12\x36\n\twifi_info\x18$ \x01(\x0b\x32#.insta360.messages.Options.WifiInfo\x12\x45\n\x11wifi_channel_list\x18% \x01(\x0b\x32*.insta360.messages.Options.WifiChannelList\x12\x18\n\x10\x61uthorization_id\x18& \x01(\t\x12\x1a\n\x12\x63\x61libration_offset\x18\' \x01(\t\x12\x37\n\x0ephoto_sub_mode\x18( \x01(\x0e\x32\x1f.insta360.messages.PhotoSubMode\x12\x37\n\x0evideo_sub_mode\x18) \x01(\x0e\x32\x1f.insta360.messages.VideoSubMode\x12=\n\x11second_stream_res\x18* \x01(\x0e\x32".insta360.messages.VideoResolution\x12:\n\x0bwifi_status\x18+ \x01(\x0e\x32%.insta360.messages.Options.WifiStatus\x12\x41\n\x0f\x65vo_status_mode\x18, \x01(\x0e\x32(.insta360.messages.Options.EvoStatusMode\x12\x18\n\x10origin_offset_3d\x18- \x01(\t\x12\x17\n\x0fmedia_offset_3d\x18. \x01(\t\x12\x1d\n\x15\x63\x61libration_offset_3d\x18/ \x01(\t\x12\x13\n\x0b\x63\x61mera_type\x18\x30 \x01(\t\x12\x19\n\x11\x62t_remote_version\x18\x31 \x01(\t\x12?\n\x0e\x62t_remote_type\x18\x32 \x01(\x0e\x32\'.insta360.messages.Options.BTRemoteType\x12\x42\n\x0fquality_setting\x18\x33 \x01(\x0e\x32).insta360.messages.Options.QualitySetting\x12\x1c\n\x14over_heat_protection\x18\x34 \x01(\x08\x12\x1f\n\x17\x63\x61libration_orientation\x18\x35 \x01(\x0c\x12\x18\n\x10standby_duration\x18\x36 \x01(\r\x12\x1c\n\x14quick_capture_enable\x18\x37 \x01(\x08\x12\x13\n\x0b\x62t_mac_addr\x18\x38 \x01(\t\x12\x46\n\x11television_system\x18\x39 \x01(\x0e\x32+.insta360.messages.Options.TelevisionSystem\x12\x1c\n\x14sensor0_serial_vr360\x18: \x01(\t\x12\x1c\n\x14sensor1_serial_vr360\x18; \x01(\t\x12\x1b\n\x13sensor_serial_vr180\x18< \x01(\t\x12\x16\n\x0emobvoi_license\x18= \x01(\t\x12\x19\n\x11mobvoi_public_key\x18> \x01(\t\x12\x36\n\tgyro_info\x18? \x01(\x0b\x32#.insta360.messages.Options.GyroInfo\x12\x11\n\tsensor_id\x18@ \x01(\t\x12\x1f\n\x17\x65nableInternalFlowstate\x18\x41 \x01(\x08\x12\x45\n\x11video_encode_type\x18\x42 \x01(\x0e\x32*.insta360.messages.Options.VideoEncodeType\x12)\n\x06sensor\x18\x43 \x01(\x0b\x32\x19.insta360.messages.Sensor\x12\x11\n\tis_selfie\x18\x44 \x01(\x08\x12\x1c\n\x14rolling_shutter_time\x18\x45 \x01(\x01\x12\x16\n\x0egyro_timestamp\x18\x46 \x01(\x01\x12-\n\tvideo_fov\x18G \x01(\x0e\x32\x1a.insta360.messages.FovType\x12-\n\tstill_fov\x18H \x01(\x0e\x32\x1a.insta360.messages.FovType\x12\x1a\n\x12Gyro_Polyfit_State\x18I \x01(\x08\x12\x1c\n\x14Gyro_Calibrate_State\x18J \x01(\x08\x12#\n\x1bmobvoi_license_verity_state\x18K \x01(\x08\x12+\n\x07\x66licker\x18L \x01(\x0e\x32\x1a.insta360.messages.Flicker\x12\x12\n\ntemp_value\x18M \x01(\x05\x12\x18\n\x10origin_offset_v2\x18N \x01(\t\x12\x18\n\x10origin_offset_v3\x18O \x01(\t\x12\x17\n\x0fmedia_offset_v2\x18P \x01(\t\x12\x17\n\x0fmedia_offset_v3\x18Q \x01(\t\x12\x34\n\x0b\x66ocusSensor\x18R \x01(\x0e\x32\x1f.insta360.messages.SensorDevice\x12\x45\n\x10\x65xpectOutputType\x18S \x01(\x0e\x32+.insta360.messages.Options.ExpectOutputType\x12\x32\n\x07hw_type\x18T \x01(\x0e\x32!.insta360.messages.Options.HwType\x12M\n\x18\x43hargeboxConnectedStatus\x18U \x01(\x0b\x32+.insta360.messages.ChargeboxConnectedStatus\x12\x41\n\x0f\x63\x61mera_language\x18X \x01(\x0e\x32(.insta360.messages.Options.LANGUAGE_TYPE\x12\x13\n\x0b\x62le_version\x18Y \x01(\t\x12\x44\n\x0e\x63\x61mera_posture\x18] \x01(\x0e\x32,.insta360.messages.Options.CameraPostureType\x12=\n\x0c\x62t_wakeup_sw\x18\x61 \x01(\x0e\x32\'.insta360.messages.Options.Bt_Wakeup_Sw\x12\x35\n\roffset_states\x18g \x01(\x0e\x32\x1e.insta360.messages.OffsetState\x12\x17\n\x0fota_pkg_version\x18n \x01(\t\x12\x1b\n\x13\x62ox_ota_pkg_version\x18r \x01(\t\x12\x16\n\x0e\x62ox_bt_version\x18s \x01(\t\x12\x13\n\x0b\x62ox_version\x18t \x01(\t\x12\x13\n\x0bgo3_version\x18u \x01(\t\x12\x1b\n\x13wifi_working_status\x18v \x01(\x08\x12=\n\rfollowOptions\x18w \x01(\x0b\x32&.insta360.messages.ButtonFollowOptions\x12\x12\n\nled_switch\x18x \x01(\x08\x12W\n!camera_posture_when_capture_start\x18z \x01(\x0e\x32,.insta360.messages.Options.CameraPostureType\x12\x62\n-chargebox_connected_status_when_capture_start\x18{ \x01(\x0b\x32+.insta360.messages.ChargeboxConnectedStatus\x12;\n\x10window_crop_info\x18| \x01(\x0b\x32!.insta360.messages.WindowCropInfo\x12\x1e\n\x15\x61ssistive_grid_enable\x18\x80\x01 \x01(\x08\x12\x1e\n\x15\x66reeframe_grid_enable\x18\x81\x01 \x01(\x08\x12\x1f\n\x16\x64\x61rk_eis_enable_global\x18\x85\x01 \x01(\x08\x12\x1f\n\x16metering_enable_global\x18\x86\x01 \x01(\x08\x12\x1f\n\x16\x65nableInternalSplicing\x18\x87\x01 \x01(\x08\x12!\n\x18quick_reader_moving_flag\x18\x93\x01 \x01(\x08\x12:\n\x0fheat_shell_type\x18\x95\x01 \x01(\x0e\x32 .insta360.messages.HeatShellType\x12\x44\n\x14offset_detected_type\x18\x96\x01 \x01(\x0e\x32%.insta360.messages.OffsetDetectedType\x12\x12\n\thas_crash\x18\x9b\x01 \x01(\x08\x1a&\n\x10GyroFilterConfig\x12\x12\n\ndlpf_value\x18\x01 \x01(\r\x1a\xb7\x02\n\x08WifiInfo\x12\x0c\n\x04ssid\x18\x01 \x01(\t\x12\x10\n\x08password\x18\x02 \x01(\t\x12\x0f\n\x07\x63hannel\x18\x03 \x01(\x05\x12\x36\n\x04mode\x18\x04 \x01(\x0e\x32(.insta360.messages.Options.WifiInfo.Mode\x12\x41\n\nwifi_state\x18\x05 \x01(\x0e\x32-.insta360.messages.Options.WifiInfo.WifiState\x12\x16\n\x0epasswd_version\x18\x06 \x01(\x05\x12\x10\n\x08mac_addr\x18\x07 \x01(\t" \n\x04Mode\x12\x06\n\x02\x41P\x10\x00\x12\x07\n\x03STA\x10\x01\x12\x07\n\x03P2P\x10\x02"3\n\tWifiState\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x08\n\x04\x41UTO\x10\x01\x12\x06\n\x02ON\x10\x02\x12\x07\n\x03OFF\x10\x03\x1a=\n\x0fWifiChannelList\x12\x14\n\x0c\x63ountry_code\x18\x01 \x01(\t\x12\x14\n\x0c\x63hannel_list\x18\x02 \x01(\x0c\x1a\xa5\x02\n\x08GyroInfo\x12?\n\tgyro_type\x18\x01 \x01(\x0e\x32,.insta360.messages.Options.GyroInfo.GyroType\x12=\n\x08gyro_pos\x18\x02 \x01(\x0e\x32+.insta360.messages.Options.GyroInfo.GyroPos"@\n\x08GyroType\x12\x19\n\x15INSDEV_IMU_TYPE_20948\x10\x00\x12\x19\n\x15INSDEV_IMU_TYPE_40609\x10\x01"W\n\x07GyroPos\x12\x17\n\x13INSDEV_IMU_POS_VIN0\x10\x00\x12\x17\n\x13INSDEV_IMU_POS_VIN1\x10\x01\x12\x1a\n\x16INSDEV_IMU_POS_UNKNOWN\x10\x02"L\n\x11\x41\x63\x63\x46ullScaleRange\x12\x0c\n\x08RANGE_2G\x10\x00\x12\x0c\n\x08RANGE_4G\x10\x01\x12\x0c\n\x08RANGE_8G\x10\x02\x12\r\n\tRANGE_16G\x10\x03"^\n\x12GyroFullScaleRange\x12\x10\n\x0cRANGE_250DPS\x10\x00\x12\x10\n\x0cRANGE_500DPS\x10\x01\x12\x11\n\rRANGE_1000DPS\x10\x02\x12\x11\n\rRANGE_2000DPS\x10\x03"2\n\x0e\x41\x64optionSystem\x12\r\n\tPHONE_IOS\x10\x00\x12\x11\n\rPHONE_ANDROID\x10\x01"\x1e\n\nWifiStatus\x12\x08\n\x04\x41UTO\x10\x00\x12\x06\n\x02ON\x10\x01"F\n\rEvoStatusMode\x12\x17\n\x13UNKNOWN_STATUS_MODE\x10\x00\x12\r\n\tDEGREE180\x10\x01\x12\r\n\tDEGREE360\x10\x02"X\n\x0c\x42TRemoteType\x12\x15\n\x11UNKNOWN_BT_REMOTE\x10\x00\x12\x19\n\x15\x42T_REMOTE_WITHOUT_GPS\x10\x01\x12\x16\n\x12\x42T_REMOTE_WITH_GPS\x10\x02"3\n\x0eQualitySetting\x12\x10\n\x0cHIGH_QUALITY\x10\x00\x12\x0f\n\x0bLOW_QUALITY\x10\x01"%\n\x10TelevisionSystem\x12\x08\n\x04NTSC\x10\x00\x12\x07\n\x03PAL\x10\x01"3\n\x0fVideoEncodeType\x12\x0f\n\x0b\x45NCODE_H264\x10\x00\x12\x0f\n\x0b\x45NCODE_H265\x10\x01"O\n\x10\x45xpectOutputType\x12\x0b\n\x07\x44\x45\x46\x41ULT\x10\x00\x12\x0e\n\nINSTA_PANO\x10\x01\x12\x10\n\x0cMULTI_CAMERA\x10\x02\x12\x0c\n\x08ONE_TAKE\x10\x03"B\n\x06HwType\x12\x13\n\x0fHW_TYPE_UNKNOWN\x10\x00\x12\x0f\n\x0bHW_TYPE_MFI\x10\x01\x12\x12\n\x0eHW_TYPE_NO_MFI\x10\x02"\'\n\rLANGUAGE_TYPE\x12\x06\n\x02\x45N\x10\x00\x12\x06\n\x02ZH\x10\x01\x12\x06\n\x02JA\x10\x02"\xbc\x01\n\x11\x43\x61meraPostureType\x12\x1b\n\x17\x43\x41MERA_POSTURE_ROTATE_0\x10\x00\x12\x1c\n\x18\x43\x41MERA_POSTURE_ROTATE_90\x10\x01\x12\x1d\n\x19\x43\x41MERA_POSTURE_ROTATE_180\x10\x02\x12\x1d\n\x19\x43\x41MERA_POSTURE_ROTATE_270\x10\x03\x12\x15\n\x11\x43\x41MERA_POSTURE_UP\x10\x04\x12\x17\n\x13\x43\x41MERA_POSTURE_DOWN\x10\x05"S\n\x0c\x42t_Wakeup_Sw\x12\x14\n\x10\x42t_Wakeup_Sw_Off\x10\x00\x12\x13\n\x0f\x42t_Wakeup_Sw_On\x10\x01\x12\x18\n\x14\x42t_Wakeup_Sw_Unknown\x10\x02*\xbb\x07\n\x0c\x46unctionMode\x12\x18\n\x14\x46UNCTION_MODE_NORMAL\x10\x00\x12\x1d\n\x19\x46UNCTION_MODE_LIVE_STREAM\x10\x01\x12"\n\x1e\x46UNCTION_MODE_MOBILE_TIMELAPSE\x10\x02\x12#\n\x1f\x46UNCTION_MODE_INTERVAL_SHOOTING\x10\x03\x12!\n\x1d\x46UNCTION_MODE_HIGH_FRAME_RATE\x10\x04\x12\x17\n\x13\x46UNCTION_MODE_BURST\x10\x05\x12\x1e\n\x1a\x46UNCTION_MODE_NORMAL_IMAGE\x10\x06\x12\x1e\n\x1a\x46UNCTION_MODE_NORMAL_VIDEO\x10\x07\x12\x1b\n\x17\x46UNCTION_MODE_HDR_IMAGE\x10\x08\x12\x1b\n\x17\x46UNCTION_MODE_HDR_VIDEO\x10\t\x12 \n\x1c\x46UNCTION_MODE_INTERVAL_VIDEO\x10\n\x12"\n\x1e\x46UNCTION_MODE_STATIC_TIMELAPSE\x10\x0b\x12\x1b\n\x17\x46UNCTION_MODE_TIMESHIFT\x10\x0c\x12!\n\x1d\x46UNCTION_MODE_AEB_NIGHT_IMAGE\x10\r\x12)\n%FUNCTION_MODE_NORMAL_POWER_PANO_IMAGE\x10\x0e\x12&\n"FUNCTION_MODE_HDR_POWER_PANO_IMAGE\x10\x0f\x12\x1d\n\x19\x46UNCTION_MODE_SUPER_VIDEO\x10\x10\x12&\n"FUNCTION_MODE_LOOP_RECORDING_VIDEO\x10\x11\x12!\n\x1d\x46UNCTION_MODE_STARLAPSE_IMAGE\x10\x12\x12\x1b\n\x17\x46UNCTION_MODE_FPV_VIDEO\x10\x13\x12\x1d\n\x19\x46UNCTION_MODE_MOVIE_VIDEO\x10\x14\x12"\n\x1e\x46UNCTION_MODE_SLOWMOTION_VIDEO\x10\x15\x12\x1e\n\x1a\x46UNCTION_MODE_SELFIE_VIDEO\x10\x16\x12!\n\x1d\x46UNCTION_MODE_QC_SINGLE_PRESS\x10\x17\x12!\n\x1d\x46UNCTION_MODE_QC_DOUBLE_PRESS\x10\x18\x12%\n!FUNCTION_MODE_CAMERA_SINGLE_PRESS\x10\x19\x12%\n!FUNCTION_MODE_CAMERA_DOUBLE_PRESS\x10\x1a\x12\x1c\n\x18\x46UNCTION_MODE_PURE_VIDEO\x10\x1b*\xce\x02\n\x0b\x43\x61ptureMode\x12\x18\n\x14\x43\x61pture_MODE_UNKNOWN\x10\x00\x12\x17\n\x13\x43\x61pture_MODE_NORMAL\x10\x01\x12\x1b\n\x17\x43\x61pture_MODE_BULLETTIME\x10\x02\x12\x14\n\x10\x43\x61pture_MODE_HDR\x10\x03\x12\x1a\n\x16\x43\x61pture_MODE_TIMESHIFT\x10\x04\x12\x1c\n\x18\x43\x61pture_MODE_SUPER_VIDEO\x10\x05\x12\x1e\n\x1a\x43\x61pture_MODE_LOOPRECORDING\x10\x06\x12\x14\n\x10\x43\x61pture_MODE_FPV\x10\x07\x12\x16\n\x12\x43\x61pture_MODE_MOVIE\x10\x08\x12\x1b\n\x17\x43\x61pture_MODE_SLOWMOTION\x10\t\x12\x17\n\x13\x43\x61pture_MODE_SELFIE\x10\n\x12\x1b\n\x17\x43\x61pture_MODE_PURE_VIDEO\x10\x0b*\xf3\x12\n\nOptionType\x12\x12\n\x0eOPTION_UNKNOWN\x10\x00\x12\x14\n\x10VIDEO_RESOLUTION\x10\x01\x12\x0e\n\nPHOTO_SIZE\x10\x02\x12\x11\n\rVIDEO_BITRATE\x10\x03\x12\x11\n\rAUDIO_BITRATE\x10\x04\x12\x14\n\x10\x41UDIO_SAMPLERATE\x10\x05\x12\x11\n\rORIGIN_OFFSET\x10\x06\x12\x16\n\x12\x43\x41PTURE_TIME_LIMIT\x10\x07\x12\x0f\n\x0bGPS_TIMEOUT\x10\x08\x12\x1a\n\x16REMAINING_CAPTURE_TIME\x10\t\x12\x16\n\x12REMAINING_PICTURES\x10\n\x12\x12\n\x0e\x42\x41TTERY_STATUS\x10\x0b\x12\x0e\n\nLOCAL_TIME\x10\x0c\x12\r\n\tTIME_ZONE\x10\r\x12\x08\n\x04MUTE\x10\x0e\x12\x11\n\rSERIAL_NUMBER\x10\x0f\x12\x08\n\x04UUID\x10\x10\x12\x18\n\x14\x42UTTON_PRESS_OPTIONS\x10\x11\x12\x11\n\rACTIVATE_TIME\x10\x13\x12\x11\n\rSTORAGE_STATE\x10\x14\x12\x0e\n\nLENS_INDEX\x10\x15\x12\x10\n\x0cMEDIA_OFFSET\x10\x16\x12\x0e\n\nSELF_TIMER\x10\x17\x12\x14\n\x10GYRO_SAMPLE_RATE\x10\x18\x12\x18\n\x14\x41\x43\x43_FULL_SCALE_RANGE\x10\x19\x12\x19\n\x15GYRO_FULL_SCALE_RANGE\x10\x1a\x12\x14\n\x10TAKE_RAW_PICTURE\x10\x1b\x12\x0e\n\nGAMMA_MODE\x10\x1c\x12\x0e\n\nMEDIA_TIME\x10\x1d\x12\x14\n\x10\x46IRMWAREREVISION\x10\x1e\x12\x10\n\x0cSYS_ADOPTION\x10\x1f\x12\x0c\n\x08\x43PU_TYPE\x10 \x12\x0f\n\x0bGYRO_FILTER\x10!\x12\x0f\n\x0bMCTF_ENABLE\x10"\x12\x15\n\x11SPORT_MODE_ENABLE\x10#\x12\r\n\tWIFI_INFO\x10$\x12\x15\n\x11WIFI_CHANNEL_LIST\x10%\x12\x14\n\x10\x41UTHORIZATION_ID\x10&\x12\x16\n\x12\x43\x41LIBRATION_OFFSET\x10\'\x12\x12\n\x0ePHOTO_SUB_MODE\x10(\x12\x12\n\x0eVIDEO_SUB_MODE\x10)\x12\x15\n\x11SECOND_STREAM_RES\x10*\x12\x0f\n\x0bWIFI_STATUS\x10+\x12\x13\n\x0f\x45VO_STATUS_MODE\x10,\x12\x14\n\x10ORIGIN_OFFSET_3D\x10-\x12\x13\n\x0fMEDIA_OFFSET_3D\x10.\x12\x19\n\x15\x43\x41LIBRATION_OFFSET_3D\x10/\x12\x0f\n\x0b\x43\x41MERA_TYPE\x10\x30\x12\x15\n\x11\x42T_REMOTE_VERSION\x10\x31\x12\x12\n\x0e\x42T_REMOTE_TYPE\x10\x32\x12\x13\n\x0fQUALITY_SETTING\x10\x33\x12\x17\n\x13OVERHEAT_PROTECTION\x10\x34\x12\x1b\n\x17\x43\x41LIBRATION_ORIENTATION\x10\x35\x12\x14\n\x10STANDBY_DURATION\x10\x36\x12\x18\n\x14QUICK_CAPTURE_ENABLE\x10\x37\x12\x0f\n\x0b\x42T_MAC_ADDR\x10\x38\x12\x15\n\x11TELEVISION_SYSTEM\x10\x39\x12\x18\n\x14SENSOR0_SERIAL_VR360\x10:\x12\x18\n\x14SENSOR1_SERIAL_VR360\x10;\x12\x17\n\x13SENSOR_SERIAL_VR180\x10<\x12\x12\n\x0eMOBVOI_LICENSE\x10=\x12\x15\n\x11MOBVOI_PUBLIC_KEY\x10>\x12\r\n\tGYRO_INFO\x10?\x12\r\n\tSENSOR_ID\x10@\x12\x16\n\x12INTERNAL_FLOWSTATE\x10\x41\x12\x15\n\x11VIDEO_ENCODE_TYPE\x10\x42\x12\x0f\n\x0bSENSOR_INFO\x10\x43\x12\r\n\tIS_SELFIE\x10\x44\x12\x18\n\x14ROLLING_SHUTTER_TIME\x10\x45\x12\x13\n\x0fGYRO_TIME_STAMP\x10\x46\x12\r\n\tVIDEO_FOV\x10G\x12\r\n\tSTILL_FOV\x10H\x12\x16\n\x12GYRO_POLYFIT_STATE\x10I\x12\x18\n\x14GYRO_CALIBRATE_STATE\x10J\x12\x1f\n\x1bMOBVOI_LICENSE_VERITY_STATE\x10K\x12\x12\n\x0e\x46LICKER_GLOBAL\x10L\x12\x0e\n\nTEMP_VALUE\x10M\x12\x14\n\x10ORIGIN_OFFSET_V2\x10N\x12\x14\n\x10ORIGIN_OFFSET_V3\x10O\x12\x13\n\x0fMEDIA_OFFSET_V2\x10P\x12\x13\n\x0fMEDIA_OFFSET_V3\x10Q\x12\x1a\n\x16INSTAPANO_FOCUS_SENSOR\x10R\x12\x16\n\x12\x45XPECT_OUTPUT_TYPE\x10S\x12\x0b\n\x07HW_TYPE\x10T\x12\x1e\n\x1a\x43HARGEBOX_CONNECTED_STATUS\x10U\x12\x10\n\x0c\x42T_CAR_TABLE\x10V\x12\x0c\n\x08PTZ_CTRL\x10W\x12\x13\n\x0f\x43\x41MERA_LANGUAGE\x10X\x12\x12\n\x0eHW_BLE_VERSION\x10Y\x12\x12\n\x0e\x43\x41MERA_POSTURE\x10]\x12\x10\n\x0c\x42T_WAKEUP_SW\x10\x61\x12\x11\n\rOFFSET_STATES\x10g\x12\x13\n\x0fOTA_PKG_VERSION\x10n\x12\x17\n\x13\x42OX_OTA_PKG_VERSION\x10r\x12\x12\n\x0e\x42OX_BT_VERSION\x10s\x12\x0f\n\x0b\x42OX_VERSION\x10t\x12\x0f\n\x0bGO3_VERSION\x10u\x12\x17\n\x13WIFI_WORKING_STATUS\x10v\x12\x18\n\x14\x42UTTON_FOLLOW_OPTION\x10w\x12\x0e\n\nLED_SWITCH\x10x\x12%\n!CAMERA_POSTURE_WHEN_CAPTURE_START\x10z\x12\x31\n-CHARGEBOX_CONNECTED_STATUS_WHEN_CAPTURE_START\x10{\x12\x14\n\x10WINDOW_CROP_INFO\x10|\x12\x13\n\x0e\x41SSISTIVE_GRID\x10\x80\x01\x12\x13\n\x0e\x46REEFRAME_GRID\x10\x81\x01\x12\x1b\n\x16\x44\x41RK_EIS_ENABLE_GLOBAL\x10\x85\x01\x12\x1b\n\x16METERING_ENABLE_GLOBAL\x10\x86\x01\x12\x16\n\x11INTERNAL_SPLICING\x10\x87\x01\x12\x1d\n\x18QUICK_READER_MOVING_FLAG\x10\x93\x01\x12\x14\n\x0fHEAT_SHELL_TYPE\x10\x95\x01\x12\x19\n\x14OFFSET_DETECTED_TYPE\x10\x96\x01\x12\x0e\n\tHAS_CRASH\x10\x9b\x01\x12\x10\n\x0bOPTIONS_NUM\x10\x9c\x01\x42\x08\xa2\x02\x05INSPBP\x00P\x01P\x02P\x03P\x04P\x05P\x06P\x07P\x08P\tP\nb\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "options_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"\242\002\005INSPB"
    _globals["_FUNCTIONMODE"]._serialized_start = 6257
    _globals["_FUNCTIONMODE"]._serialized_end = 7212
    _globals["_CAPTUREMODE"]._serialized_start = 7215
    _globals["_CAPTUREMODE"]._serialized_end = 7549
    _globals["_OPTIONTYPE"]._serialized_start = 7552
    _globals["_OPTIONTYPE"]._serialized_end = 9971
    _globals["_OPTIONS"]._serialized_start = 221
    _globals["_OPTIONS"]._serialized_end = 6254
    _globals["_OPTIONS_GYROFILTERCONFIG"]._serialized_start = 4512
    _globals["_OPTIONS_GYROFILTERCONFIG"]._serialized_end = 4550
    _globals["_OPTIONS_WIFIINFO"]._serialized_start = 4553
    _globals["_OPTIONS_WIFIINFO"]._serialized_end = 4864
    _globals["_OPTIONS_WIFIINFO_MODE"]._serialized_start = 4779
    _globals["_OPTIONS_WIFIINFO_MODE"]._serialized_end = 4811
    _globals["_OPTIONS_WIFIINFO_WIFISTATE"]._serialized_start = 4813
    _globals["_OPTIONS_WIFIINFO_WIFISTATE"]._serialized_end = 4864
    _globals["_OPTIONS_WIFICHANNELLIST"]._serialized_start = 4866
    _globals["_OPTIONS_WIFICHANNELLIST"]._serialized_end = 4927
    _globals["_OPTIONS_GYROINFO"]._serialized_start = 4930
    _globals["_OPTIONS_GYROINFO"]._serialized_end = 5223
    _globals["_OPTIONS_GYROINFO_GYROTYPE"]._serialized_start = 5070
    _globals["_OPTIONS_GYROINFO_GYROTYPE"]._serialized_end = 5134
    _globals["_OPTIONS_GYROINFO_GYROPOS"]._serialized_start = 5136
    _globals["_OPTIONS_GYROINFO_GYROPOS"]._serialized_end = 5223
    _globals["_OPTIONS_ACCFULLSCALERANGE"]._serialized_start = 5225
    _globals["_OPTIONS_ACCFULLSCALERANGE"]._serialized_end = 5301
    _globals["_OPTIONS_GYROFULLSCALERANGE"]._serialized_start = 5303
    _globals["_OPTIONS_GYROFULLSCALERANGE"]._serialized_end = 5397
    _globals["_OPTIONS_ADOPTIONSYSTEM"]._serialized_start = 5399
    _globals["_OPTIONS_ADOPTIONSYSTEM"]._serialized_end = 5449
    _globals["_OPTIONS_WIFISTATUS"]._serialized_start = 5451
    _globals["_OPTIONS_WIFISTATUS"]._serialized_end = 5481
    _globals["_OPTIONS_EVOSTATUSMODE"]._serialized_start = 5483
    _globals["_OPTIONS_EVOSTATUSMODE"]._serialized_end = 5553
    _globals["_OPTIONS_BTREMOTETYPE"]._serialized_start = 5555
    _globals["_OPTIONS_BTREMOTETYPE"]._serialized_end = 5643
    _globals["_OPTIONS_QUALITYSETTING"]._serialized_start = 5645
    _globals["_OPTIONS_QUALITYSETTING"]._serialized_end = 5696
    _globals["_OPTIONS_TELEVISIONSYSTEM"]._serialized_start = 5698
    _globals["_OPTIONS_TELEVISIONSYSTEM"]._serialized_end = 5735
    _globals["_OPTIONS_VIDEOENCODETYPE"]._serialized_start = 5737
    _globals["_OPTIONS_VIDEOENCODETYPE"]._serialized_end = 5788
    _globals["_OPTIONS_EXPECTOUTPUTTYPE"]._serialized_start = 5790
    _globals["_OPTIONS_EXPECTOUTPUTTYPE"]._serialized_end = 5869
    _globals["_OPTIONS_HWTYPE"]._serialized_start = 5871
    _globals["_OPTIONS_HWTYPE"]._serialized_end = 5937
    _globals["_OPTIONS_LANGUAGE_TYPE"]._serialized_start = 5939
    _globals["_OPTIONS_LANGUAGE_TYPE"]._serialized_end = 5978
    _globals["_OPTIONS_CAMERAPOSTURETYPE"]._serialized_start = 5981
    _globals["_OPTIONS_CAMERAPOSTURETYPE"]._serialized_end = 6169
    _globals["_OPTIONS_BT_WAKEUP_SW"]._serialized_start = 6171
    _globals["_OPTIONS_BT_WAKEUP_SW"]._serialized_end = 6254
# @@protoc_insertion_point(module_scope)
