# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: battery.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\rbattery.proto\x12\x11insta360.messages"\xa4\x02\n\rBatteryStatus\x12>\n\npower_type\x18\x01 \x01(\x0e\x32*.insta360.messages.BatteryStatus.PowerType\x12\x15\n\rbattery_level\x18\x02 \x01(\r\x12\x15\n\rbattery_scale\x18\x03 \x01(\r\x12\x42\n\x0c\x62\x61ttery_type\x18\x04 \x01(\x0e\x32,.insta360.messages.BatteryStatus.BatteryType"%\n\tPowerType\x12\x0b\n\x07\x42\x41TTERY\x10\x00\x12\x0b\n\x07\x41\x44\x41PTER\x10\x01":\n\x0b\x42\x61tteryType\x12\t\n\x05THICK\x10\x00\x12\x08\n\x04THIN\x10\x01\x12\x0c\n\x08VERTICAL\x10\x02\x12\x08\n\x04NONE\x10\x64\x42\x08\xa2\x02\x05INSPBb\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "battery_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"\242\002\005INSPB"
    _globals["_BATTERYSTATUS"]._serialized_start = 37
    _globals["_BATTERYSTATUS"]._serialized_end = 329
    _globals["_BATTERYSTATUS_POWERTYPE"]._serialized_start = 232
    _globals["_BATTERYSTATUS_POWERTYPE"]._serialized_end = 269
    _globals["_BATTERYSTATUS_BATTERYTYPE"]._serialized_start = 271
    _globals["_BATTERYSTATUS_BATTERYTYPE"]._serialized_end = 329
# @@protoc_insertion_point(module_scope)
