# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: set_key_time_point.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from options_pb2 import *

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x18set_key_time_point.proto\x12\x11insta360.messages\x1a\roptions.proto"\xb0\x01\n\x0fSetKeyTimePoint\x12\x11\n\ttimestamp\x18\x01 \x01(\x04\x12\x41\n\x04type\x18\x02 \x01(\x0e\x32\x33.insta360.messages.SetKeyTimePoint.KeyTimePointType\x12\x12\n\ntypeDetail\x18\x03 \x01(\t"3\n\x10KeyTimePointType\x12\x0b\n\x07INSTANT\x10\x00\x12\t\n\x05START\x10\x01\x12\x07\n\x03\x45ND\x10\x02"\x15\n\x13SetKeyTimePointRespB\x08\xa2\x02\x05INSPBP\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "set_key_time_point_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"\242\002\005INSPB"
    _globals["_SETKEYTIMEPOINT"]._serialized_start = 63
    _globals["_SETKEYTIMEPOINT"]._serialized_end = 239
    _globals["_SETKEYTIMEPOINT_KEYTIMEPOINTTYPE"]._serialized_start = 188
    _globals["_SETKEYTIMEPOINT_KEYTIMEPOINTTYPE"]._serialized_end = 239
    _globals["_SETKEYTIMEPOINTRESP"]._serialized_start = 241
    _globals["_SETKEYTIMEPOINTRESP"]._serialized_end = 262
# @@protoc_insertion_point(module_scope)
