# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: storage.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\rstorage.proto\x12\x11insta360.messages"\x9c\x01\n\x0cStorageState\x12\x30\n\ncard_state\x18\x01 \x01(\x0e\x32\x1c.insta360.messages.CardState\x12\x12\n\nfree_space\x18\x02 \x01(\x04\x12\x13\n\x0btotal_space\x18\x03 \x01(\x04\x12\x31\n\x08location\x18\x04 \x01(\x0e\x32\x1f.insta360.messages.CardLocation*\x8f\x01\n\tCardState\x12\x10\n\x0cSTOR_CS_PASS\x10\x00\x12\x12\n\x0eSTOR_CS_NOCARD\x10\x01\x12\x13\n\x0fSTOR_CS_NOSPACE\x10\x02\x12\x1a\n\x16STOR_CS_INVALID_FORMAT\x10\x03\x12\x12\n\x0eSTOR_CS_WPCARD\x10\x04\x12\x17\n\x13STOR_CS_OTHER_ERROR\x10\x05*6\n\x0c\x43\x61rdLocation\x12\x12\n\x0eSTOR_CL_CAMERA\x10\x00\x12\x12\n\x0eSTOR_CL_READER\x10\x01\x42\x08\xa2\x02\x05INSPBb\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "storage_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"\242\002\005INSPB"
    _globals["_CARDSTATE"]._serialized_start = 196
    _globals["_CARDSTATE"]._serialized_end = 339
    _globals["_CARDLOCATION"]._serialized_start = 341
    _globals["_CARDLOCATION"]._serialized_end = 395
    _globals["_STORAGESTATE"]._serialized_start = 37
    _globals["_STORAGESTATE"]._serialized_end = 193
# @@protoc_insertion_point(module_scope)
