# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: download_info.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x13\x64ownload_info.proto\x12\x11insta360.messages"\xe9\x01\n\x0c\x44ownLoadInfo\x12\x10\n\x08totalNum\x18\x01 \x01(\x04\x12\x12\n\ncurrentNum\x18\x02 \x01(\x04\x12\x12\n\npercentage\x18\x03 \x01(\x01\x12\x36\n\x06status\x18\x04 \x01(\x0e\x32&.insta360.messages.DownLoadInfo.Status\x12\x12\n\nsuccessNum\x18\x05 \x01(\x04"S\n\x06Status\x12\n\n\x06UNKNOW\x10\x00\x12\x0b\n\x07SUCCESS\x10\x01\x12\x08\n\x04\x46\x41IL\x10\x02\x12\t\n\x05PAUSE\x10\x03\x12\x0f\n\x0b\x44OWNLOADING\x10\x04\x12\n\n\x06\x43\x41NCEL\x10\x05"\xbc\x03\n\x16\x44ownloadListResultSync\x12P\n\x0f\x61\x64\x64_list_result\x18\x01 \x01(\x0e\x32\x37.insta360.messages.DownloadListResultSync.AddListResult\x12\x46\n\x05\x65rror\x18\x02 \x01(\x0e\x32\x37.insta360.messages.DownloadListResultSync.DownloadError\x12\x15\n\ris_clear_list\x18\x03 \x01(\x08\x12\x18\n\x10success_file_num\x18\x04 \x01(\x04\x12\x16\n\x0e\x65rror_file_num\x18\x05 \x01(\x04"M\n\rAddListResult\x12\n\n\x06UNKNOW\x10\x00\x12\x0f\n\x0b\x41LL_SUCCESS\x10\x01\x12\x08\n\x04\x46\x41IL\x10\x02\x12\x15\n\x11PARTIALLY_SUCCESS\x10\x03"p\n\rDownloadError\x12\x0c\n\x08\x45RR_NONE\x10\x00\x12\x0e\n\nERR_UNKNOW\x10\x01\x12\x10\n\x0c\x45RR_NO_SPACE\x10\x02\x12\x18\n\x14\x45RR_NOT_SUPPORT_FILE\x10\x03\x12\x15\n\x11\x45RR_NO_PERMISSION\x10\x04\x42\x08\xa2\x02\x05INSPBb\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "download_info_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"\242\002\005INSPB"
    _globals["_DOWNLOADINFO"]._serialized_start = 43
    _globals["_DOWNLOADINFO"]._serialized_end = 276
    _globals["_DOWNLOADINFO_STATUS"]._serialized_start = 193
    _globals["_DOWNLOADINFO_STATUS"]._serialized_end = 276
    _globals["_DOWNLOADLISTRESULTSYNC"]._serialized_start = 279
    _globals["_DOWNLOADLISTRESULTSYNC"]._serialized_end = 723
    _globals["_DOWNLOADLISTRESULTSYNC_ADDLISTRESULT"]._serialized_start = 532
    _globals["_DOWNLOADLISTRESULTSYNC_ADDLISTRESULT"]._serialized_end = 609
    _globals["_DOWNLOADLISTRESULTSYNC_DOWNLOADERROR"]._serialized_start = 611
    _globals["_DOWNLOADLISTRESULTSYNC_DOWNLOADERROR"]._serialized_end = 723
# @@protoc_insertion_point(module_scope)
