# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: get_flowstate_enable.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x1aget_flowstate_enable.proto\x12\x11insta360.messages"\x14\n\x12GetFlowstateEnable"(\n\x16GetFlowstateEnableResp\x12\x0e\n\x06\x65nable\x18\x01 \x01(\rB\x08\xa2\x02\x05INSPBb\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(
    DESCRIPTOR, "get_flowstate_enable_pb2", _globals
)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"\242\002\005INSPB"
    _globals["_GETFLOWSTATEENABLE"]._serialized_start = 49
    _globals["_GETFLOWSTATEENABLE"]._serialized_end = 69
    _globals["_GETFLOWSTATEENABLERESP"]._serialized_start = 71
    _globals["_GETFLOWSTATEENABLERESP"]._serialized_end = 111
# @@protoc_insertion_point(module_scope)
