# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bt_central_notification.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from bluetooth_pb2 import *

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x1d\x62t_central_notification.proto\x12\x11insta360.messages\x1a\x0f\x62luetooth.proto"X\n NotificatoinDiscoverBTPeripheral\x12\x34\n\x0bperipherals\x18\x01 \x03(\x0b\x32\x1f.insta360.messages.BTPeripheral"X\n!NotificatoinConnectedToPeripheral\x12\x33\n\nperipheral\x18\x01 \x01(\x0b\x32\x1f.insta360.messages.BTPeripheral"Y\n"NotificatoinDisconnectedPeripheral\x12\x33\n\nperipheral\x18\x01 \x01(\x0b\x32\x1f.insta360.messages.BTPeripheralB\x08\xa2\x02\x05INSPBP\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(
    DESCRIPTOR, "bt_central_notification_pb2", _globals
)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"\242\002\005INSPB"
    _globals["_NOTIFICATOINDISCOVERBTPERIPHERAL"]._serialized_start = 69
    _globals["_NOTIFICATOINDISCOVERBTPERIPHERAL"]._serialized_end = 157
    _globals["_NOTIFICATOINCONNECTEDTOPERIPHERAL"]._serialized_start = 159
    _globals["_NOTIFICATOINCONNECTEDTOPERIPHERAL"]._serialized_end = 247
    _globals["_NOTIFICATOINDISCONNECTEDPERIPHERAL"]._serialized_start = 249
    _globals["_NOTIFICATOINDISCONNECTEDPERIPHERAL"]._serialized_end = 338
# @@protoc_insertion_point(module_scope)
