# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: editinfo_list.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x13\x65\x64itinfo_list.proto\x12\x11insta360.messages"F\n\x0c\x46\x61voriteInfo\x12\x1c\n\x14playback_is_favorite\x18\x01 \x01(\x08\x12\x18\n\x10modify_timestamp\x18\x02 \x01(\x03"Y\n\x0c\x45\x64itFileInfo\x12\x11\n\tfile_path\x18\x01 \x01(\t\x12\x36\n\rfavorite_info\x18\x02 \x01(\x0b\x32\x1f.insta360.messages.FavoriteInfo"P\n\x10\x45\x64itFileInfoList\x12<\n\x13\x65\x64it_file_info_list\x18\x01 \x03(\x0b\x32\x1f.insta360.messages.EditFileInfoB\x08\xa2\x02\x05INSPBb\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "editinfo_list_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"\242\002\005INSPB"
    _globals["_FAVORITEINFO"]._serialized_start = 42
    _globals["_FAVORITEINFO"]._serialized_end = 112
    _globals["_EDITFILEINFO"]._serialized_start = 114
    _globals["_EDITFILEINFO"]._serialized_end = 203
    _globals["_EDITFILEINFOLIST"]._serialized_start = 205
    _globals["_EDITFILEINFOLIST"]._serialized_end = 285
# @@protoc_insertion_point(module_scope)
