# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: fw_upgrade_state.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x16\x66w_upgrade_state.proto\x12\x11insta360.messages"\xbb\x08\n\x13UpgradeStateOptions\x12\x43\n\x05state\x18\x01 \x01(\x0e\x32\x34.insta360.messages.UpgradeStateOptions.Upgrage_State\x12H\n\nerror_code\x18\x02 \x01(\x0e\x32\x34.insta360.messages.UpgradeStateOptions.Upgrage_State"\x94\x07\n\rUpgrage_State\x12\x16\n\x12UPGRADE_STATE_IDLE\x10\x00\x12\x1c\n\x18UPGRADE_STATE_PRE_NOFILE\x10\x01\x12%\n!UPGRADE_STATE_GET_FILE_LIST_ERROR\x10\x02\x12"\n\x1eUPGRADE_STATE_PRE_CAME_NOPOWER\x10\x03\x12"\n\x1eUPGRADE_STATE_PRE_CASE_NOPOWER\x10\x04\x12\x1c\n\x18UPGRADE_STATE_ING_UNPACK\x10\x05\x12"\n\x1eUPGRADE_STATE_ING_UNPACK_ERROR\x10\x06\x12%\n!UPGRADE_STATE_ING_CHECK_MD5_ERROR\x10\x07\x12#\n\x1fUPGRADE_STATE_ING_CASE_FW_START\x10\x08\x12#\n\x1fUPGRADE_STATE_ING_CASE_FW_ERROR\x10\t\x12&\n"UPGRADE_STATE_ING_CASE_BT_FW_START\x10\n\x12&\n"UPGRADE_STATE_ING_CASE_BT_FW_ERROR\x10\x0b\x12&\n"UPGRADE_STATE_ING_CAME_BT_FW_START\x10\x0c\x12&\n"UPGRADE_STATE_ING_CAME_BT_FW_ERROR\x10\r\x12#\n\x1fUPGRADE_STATE_ING_CAME_FW_START\x10\x0e\x12\'\n#UPGRADE_STATE_VERSION_CHECK_SUCCESS\x10\x0f\x12&\n"UPGRADE_STATE_VERSION_CHECK_FAILED\x10\x10\x12\x1f\n\x1bUPGRADE_STATE_ING_FW_UPLOAD\x10\x11\x12"\n\x1eUPGRADE_STATE_FW_UPLOAD_FAILED\x10\x12\x12#\n\x1fUPGRADE_STATE_FW_UPLOAD_SUCCESS\x10\x13\x12)\n%UPGRADE_STATE_PRE_USB_SHAKEHANDS_FAIL\x10\x14\x12(\n$UPGRADE_STATE_PRE_BT_SHAKEHANDS_FAIL\x10\x15\x12\'\n#UPGRADE_STATE_CAME_AND_CASE_NOPOWER\x10\x16\x12-\n)UPGRADE_STATE_ING_CAME_BT_FW_DOUBLE_START\x10\x17\x42\x08\xa2\x02\x05INSPBb\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "fw_upgrade_state_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"\242\002\005INSPB"
    _globals["_UPGRADESTATEOPTIONS"]._serialized_start = 46
    _globals["_UPGRADESTATEOPTIONS"]._serialized_end = 1129
    _globals["_UPGRADESTATEOPTIONS_UPGRAGE_STATE"]._serialized_start = 213
    _globals["_UPGRADESTATEOPTIONS_UPGRAGE_STATE"]._serialized_end = 1129
# @@protoc_insertion_point(module_scope)
