# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: live_stream_params_update.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from options_pb2 import *
from window_crop_info_pb2 import *

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x1flive_stream_params_update.proto\x12\x11insta360.messages\x1a\roptions.proto\x1a\x16window_crop_info.proto"\xb5\x02\n\x16LiveStreamParamsUpdate\x12\x45\n\x11video_encode_type\x18\x01 \x01(\x0e\x32*.insta360.messages.Options.VideoEncodeType\x12\x11\n\tres_width\x18\x02 \x01(\r\x12\x12\n\nres_height\x18\x03 \x01(\r\x12\x0f\n\x07res_fps\x18\x04 \x01(\r\x12\x1d\n\x15\x66lowstate_base_enable\x18\x05 \x01(\x08\x12;\n\x10window_crop_info\x18\x06 \x01(\x0b\x32!.insta360.messages.WindowCropInfo\x12@\n\x15half_window_crop_info\x18\x07 \x01(\x0b\x32!.insta360.messages.WindowCropInfoB\x08\xa2\x02\x05INSPBP\x00P\x01\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(
    DESCRIPTOR, "live_stream_params_update_pb2", _globals
)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"\242\002\005INSPB"
    _globals["_LIVESTREAMPARAMSUPDATE"]._serialized_start = 94
    _globals["_LIVESTREAMPARAMSUPDATE"]._serialized_end = 403
# @@protoc_insertion_point(module_scope)
