# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: error.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x0b\x65rror.proto\x12\x11insta360.messages"\xda\x01\n\x05\x45rror\x12\x30\n\x04\x63ode\x18\x01 \x01(\x0e\x32".insta360.messages.Error.ErrorCode\x12\x0f\n\x07message\x18\x02 \x01(\t"\x8d\x01\n\tErrorCode\x12\x11\n\rUNKNOWN_ERROR\x10\x00\x12\x14\n\x10UNKNOWN_MSG_CODE\x10\x01\x12\x17\n\x13UNKNOWN_MSG_PAYLOAD\x10\x02\x12\x11\n\rEXECUTE_ERROR\x10\x03\x12\x1a\n\x16OVER_FILE_NUMBER_LIMIT\x10\x04\x12\x0f\n\x0bSYSTEM_BUSY\x10\x05\x42\x08\xa2\x02\x05INSPBb\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "error_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"\242\002\005INSPB"
    _globals["_ERROR"]._serialized_start = 35
    _globals["_ERROR"]._serialized_end = 253
    _globals["_ERROR_ERRORCODE"]._serialized_start = 112
    _globals["_ERROR_ERRORCODE"]._serialized_end = 253
# @@protoc_insertion_point(module_scope)
