# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sensor.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x0csensor.proto\x12\x11insta360.messages"\xcb\x01\n\x06Sensor\x12\x0f\n\x07serials\x18\x01 \x03(\t\x12,\n\x04type\x18\x02 \x01(\x0e\x32\x1e.insta360.messages.Sensor.Type\x12\n\n\x02id\x18\x03 \x03(\t"v\n\x04Type\x12\x0c\n\x08PANO_577\x10\x00\x12\x0c\n\x08WIDE_577\x10\x01\x12\x0c\n\x08WIDE_283\x10\x02\x12\x0c\n\x08WIDE_586\x10\x03\x12\n\n\x06\x41\x46_586\x10\x04\x12\x0c\n\x08PANO_283\x10\x05\x12\x0c\n\x08PANO_586\x10\x06\x12\x0e\n\nACTION_577\x10\x07*q\n\x0cSensorDevice\x12\x19\n\x15SENSOR_DEVICE_UNKNOWN\x10\x00\x12\x17\n\x13SENSOR_DEVICE_FRONT\x10\x01\x12\x16\n\x12SENSOR_DEVICE_REAR\x10\x02\x12\x15\n\x11SENSOR_DEVICE_ALL\x10\x03*\xb8\x02\n\x07\x46ovType\x12\x0c\n\x08\x46OV_WIDE\x10\x00\x12\x0e\n\nFOV_LINEAR\x10\x01\x12\x11\n\rFOV_ULTRAWIDE\x10\x02\x12\x0e\n\nFOV_NARROW\x10\x03\x12\x0b\n\x07\x46OV_POV\x10\x04\x12\x13\n\x0f\x46OV_LINEAR_PLUS\x10\x05\x12\x18\n\x14\x46OV_LINEAR_45HORIZON\x10\x06\x12\x10\n\x0c\x46OV_TYPE_FPV\x10\x07\x12\x12\n\x0e\x46OV_TYPE_SUPER\x10\x08\x12\x17\n\x13\x46OV_TYPE_TINYPLANET\x10\t\x12\x19\n\x15\x46OV_TYPE_INFINITYWIDE\x10\n\x12\x19\n\x15\x46OV_LINEAR_360HORIZON\x10\x0b\x12\x18\n\x14\x46OV_LINEAR_22HORIZON\x10\x0c\x12\x0e\n\nFOV_DEWARP\x10\r\x12\x11\n\rFOV_TYPE_MEGA\x10\x0e\x42\x08\xa2\x02\x05INSPBb\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "sensor_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"\242\002\005INSPB"
    _globals["_SENSORDEVICE"]._serialized_start = 241
    _globals["_SENSORDEVICE"]._serialized_end = 354
    _globals["_FOVTYPE"]._serialized_start = 357
    _globals["_FOVTYPE"]._serialized_end = 669
    _globals["_SENSOR"]._serialized_start = 36
    _globals["_SENSOR"]._serialized_end = 239
    _globals["_SENSOR_TYPE"]._serialized_start = 121
    _globals["_SENSOR_TYPE"]._serialized_end = 239
# @@protoc_insertion_point(module_scope)
