# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: file_type.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b"\n\x0f\x66ile_type.proto\x12\x11insta360.messages*N\n\x08\x46ileType\x12\x10\n\x0cUNKNOWN_FILE\x10\x00\x12\x0c\n\x08\x45TK_FILE\x10\x01\x12\x0c\n\x08LOG_FILE\x10\x02\x12\x14\n\x10PARAMS_JSON_FILE\x10\x03\x42\x08\xa2\x02\x05INSPBb\x06proto3"
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "file_type_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"\242\002\005INSPB"
    _globals["_FILETYPE"]._serialized_start = 38
    _globals["_FILETYPE"]._serialized_end = 116
# @@protoc_insertion_point(module_scope)
