# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: set_photography_options.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from photography_options_pb2 import *
from options_pb2 import *

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x1dset_photography_options.proto\x12\x11insta360.messages\x1a\x19photography_options.proto\x1a\roptions.proto"\xc5\x01\n\x15SetPhotographyOptions\x12>\n\x0coption_types\x18\x01 \x03(\x0e\x32(.insta360.messages.PhotographyOptionType\x12\x34\n\x05value\x18\x02 \x01(\x0b\x32%.insta360.messages.PhotographyOptions\x12\x36\n\rfunction_mode\x18\x03 \x01(\x0e\x32\x1f.insta360.messages.FunctionMode"\\\n\x19SetPhotographyOptionsResp\x12?\n\rsuccess_types\x18\x01 \x03(\x0e\x32(.insta360.messages.PhotographyOptionTypeB\x08\xa2\x02\x05INSPBP\x00P\x01\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(
    DESCRIPTOR, "set_photography_options_pb2", _globals
)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"\242\002\005INSPB"
    _globals["_SETPHOTOGRAPHYOPTIONS"]._serialized_start = 95
    _globals["_SETPHOTOGRAPHYOPTIONS"]._serialized_end = 292
    _globals["_SETPHOTOGRAPHYOPTIONSRESP"]._serialized_start = 294
    _globals["_SETPHOTOGRAPHYOPTIONSRESP"]._serialized_end = 386
# @@protoc_insertion_point(module_scope)
